<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Author:
    TPLA / IDS Scheer
    
    Description:
    this stylesheet performs the AML file creation
    
    this stylesheet transforms the filtered and checked Portal Content File to the AML. 
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output encoding="ISO-8859-1" method="xml" doctype-system="ARIS-Export.dtd"/>

    <xsl:param name="LocaleID"/>
    <xsl:param name="CodePage"/>
    
    <xsl:param name="EmbeddedGroupGUID" />
    <xsl:param name="EmbeddedGroupOID" />
    <xsl:param name="EmbeddedGroupName" />
    
    <xsl:param name="TemplateGUID" />

    <xsl:include href="common_for_check.xsl"/>
    <xsl:include href="common_for_portal.xsl"/>
    <xsl:include href="common_for_aris.xsl"/>

    <xsl:variable name="DOT" select="'.'"/>
    <xsl:variable name="SLASH" select="'/'"/>
    <xsl:variable name="CONTENT_IN_CONTENT_SUFFIX" select="'CONTENT_IN_CONTENT'"/>
    <xsl:variable name="BUTTON_SUFFIX" select="'AS_BUTTON'"/>
    <xsl:variable name="FROM_CONTENT_TO_CONTENT" select="'FROM_CONTENT_TO_CONTENT'"/>
    <xsl:variable name="FROM_CONTENT_TO_BUTTON" select="'FROM_CONTENT_TO_BUTTON'"/>
    <xsl:variable name="FROM_BUTTON_TO_CONTENT" select="'FROM_BUTTON_TO_CONTENT'"/>
    
    <xsl:variable name="MODE_NEW" select="'newObjects'"/>
    <xsl:variable name="MODE_REUSE" select="'reuseObjects'"/>
    <xsl:variable name="MODE_VARIANT" select="'variantObjects'"/>
    
    <!--
        Description:
        handles the root-XML Element. all attributes are reused. Child-Elements which are no Context-Elements will be copied. Otherwise the element has to
        be processed recursively (adding arisTemplate if necessary; adding arisPortalNamespace).
    -->
    <xsl:template match="GenericCreator">
        <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.AML}">
            <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.HEADER_INFO}">
                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.HEADER_INFO.ARIS_EXE_VERSION}">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.HEADER_INFO.ARIS_EXE_VERSION"
                    />
                </xsl:attribute>
            </xsl:element>
            <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.LANGUAGE}">
                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.LANGUAGE.LOCALE_ID}">
                    <xsl:call-template name="determineLocaleID"/>
                </xsl:attribute>
                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.LANGUAGE.CODEPAGE}">
                    <xsl:call-template name="determineCodePage"/>
                </xsl:attribute>
            </xsl:element>

            <xsl:variable name="tempArisLocale">
                <xsl:call-template name="determineLocaleID"/>
            </xsl:variable>

            <xsl:variable name="tempPortalLocale">
                <xsl:call-template name="mapLocaleIdToPortalLocale">
                    <xsl:with-param name="varArisLocale" select="$tempArisLocale"/>
                </xsl:call-template>
            </xsl:variable>

            <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.GROUP}">
                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.GROUP.GROUP_ID}">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.GROUP.MAIN_GROUP.GROUP_ID"/>
                </xsl:attribute>
                
                <xsl:choose>
                    <!-- if  a group was specified it has to be defined as parent-group -->
                    <xsl:when test="string-length($EmbeddedGroupGUID)>0">
                        <xsl:call-template name="printGroupAndApplyTemplate">
                            <xsl:with-param name="varArisLocale" select="$tempArisLocale" />
                            <xsl:with-param name="varPortalLocale" select="$tempPortalLocale" />
                            <xsl:with-param name="varGroupPath" select="substring-after($EmbeddedGroupName, '/')" />
                            <xsl:with-param name="varGUIDPath" select="substring-after($EmbeddedGroupGUID, '/')" />
                            <xsl:with-param name="varOIDPath" select="substring-after($EmbeddedGroupOID, '/')" />
                        </xsl:call-template>
                    </xsl:when>
                    <!-- otherwise the main group is the parent-group -->
                    <xsl:otherwise>
                        <xsl:for-each select="child::*">
                            <xsl:choose>
                                <xsl:when test="name()='Context'">
                                    <xsl:apply-templates select="self::node()">
                                        <xsl:with-param name="varArisLocale" select="$tempArisLocale"/>
                                        <xsl:with-param name="varPortalLocale" select="$tempPortalLocale"/>
                                        <xsl:with-param name="varMode" select="$MODE_NEW"/>
                                    </xsl:apply-templates>
                                </xsl:when>
                            </xsl:choose>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>                

            </xsl:element>

        </xsl:element>
    </xsl:template>
    
    <!--
        Description:
        this template prints recursively the group structure into the result tree and calls apply-template for Context-Elements
    -->
    <xsl:template name="printGroupAndApplyTemplate">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>        
        <xsl:param name="varGroupPath"/>
        <xsl:param name="varGUIDPath"/>
        <xsl:param name="varOIDPath"/>
        
        <xsl:choose>
            <xsl:when test="string-length($varGroupPath)>0">
                <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.GROUP}">
                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.GROUP.GROUP_ID}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.GROUP.GROUP_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:choose>
                            <xsl:when test="contains($varOIDPath, '/')">
                                <xsl:value-of select="substring-before($varOIDPath, '/')"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$varOIDPath"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        
                    </xsl:attribute>
                    <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.GUID}">
                        <xsl:choose>
                            <xsl:when test="contains($varGUIDPath, '/')">
                                <xsl:value-of select="substring-before($varGUIDPath, '/')"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$varGUIDPath"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:element>
                    <xsl:variable name="tempGroupName">
                        <xsl:choose>
                            <xsl:when test="contains($varGroupPath, '/')">
                                <xsl:value-of select="substring-before($varGroupPath, '/')"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$varGroupPath"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>
                    
                    <!-- AT_NAME -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName"
                            select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
                        <xsl:with-param name="varAttrValue"
                            select="$tempGroupName"/>
                        <xsl:with-param name="varLocale" select="$varArisLocale"/>
                    </xsl:call-template>
                    
                    <xsl:call-template name="printGroupAndApplyTemplate">
                        <xsl:with-param name="varArisLocale" select="$varArisLocale" />
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale" />
                        <xsl:with-param name="varGroupPath" select="substring-after($varGroupPath, '/')" />
                        <xsl:with-param name="varGUIDPath" select="substring-after($varGUIDPath, '/')" />
                        <xsl:with-param name="varOIDPath" select="substring-after($varOIDPath, '/')" />
                    </xsl:call-template>
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="child::*">
                    <xsl:choose>
                        <xsl:when test="name()='Context'">
                            <xsl:apply-templates select="self::node()">
                                <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varMode" select="$MODE_NEW"/>
                            </xsl:apply-templates>
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:template>

    <!--
        Description:
        handles the content of the portal file. 
    -->
    <xsl:template match="Context">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varMode"/>
        <xsl:param name="varNoRecursion"/>

        <xsl:variable name="tempIsGroup">
            <xsl:call-template name="common_for_check.isGroup">
                <xsl:with-param name="varObjectClass" select="@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsPage">
            <xsl:call-template name="common_for_check.isPage">
                <xsl:with-param name="varObjectClass" select="@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsiView">
            <xsl:call-template name="common_for_check.isiView">
                <xsl:with-param name="varObjectClass" select="@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWorkset">
            <xsl:call-template name="common_for_check.isWorkset">
                <xsl:with-param name="varObjectClass" select="@objectClass"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:choose>
            <!-- if it is a portal group then transform to aris group -->
            <xsl:when test="$tempIsGroup='true'">
                <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.GROUP}">
                    <xsl:call-template name="transformGroup">
                        <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                    </xsl:call-template>
                    <xsl:for-each select="child::*">
                        <xsl:choose>
                            <xsl:when test="name()='Context'">
                                <xsl:apply-templates select="self::node()">
                                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varMode" select="$MODE_NEW"/>
                                </xsl:apply-templates>
                            </xsl:when>
                        </xsl:choose>
                    </xsl:for-each>
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <!-- it is content; create a ObjDef, ObjOcc for  it -->
                <xsl:choose>
                    <xsl:when test="$tempIsRole='true'">
                        <xsl:call-template name="transformRole">
                            <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varMode" select="$varMode"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:when test="$tempIsiView='true'">
                        <xsl:call-template name="transformiView">
                            <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varMode" select="$varMode"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:when test="$tempIsPage='true'">
                        <xsl:call-template name="transformPage">
                            <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varMode" select="$varMode"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:when test="$tempIsWorkset='true'">
                        <xsl:call-template name="transformWorkset">
                            <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varMode" select="$varMode"/>
                        </xsl:call-template>
                    </xsl:when>
                </xsl:choose>

                <xsl:if test="not($varNoRecursion='true')">
                    <!-- before creating a model create ObjDefs, ObjOccs and Models for content which is embedded inside other content as copy (not as delta-link) -->
                    <xsl:variable name="tempHasContentInContent">
                        <xsl:choose>
                            <xsl:when test="count(child::Context)>0">
                                <xsl:for-each select="child::Context">
                                    <xsl:call-template name="determineIsContentInContent">
                                        <xsl:with-param name="varCurrentNode" select="self::node()"
                                        />
                                    </xsl:call-template>
                                </xsl:for-each>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="false()"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>
                    <xsl:if test="starts-with($tempHasContentInContent, 'true')">
                        <!-- create ObjDefs first -->
                        <xsl:for-each select="child::*">
                            <xsl:choose>
                                <xsl:when test="name()='Context'">
                                    <xsl:call-template name="createObjDefsForContentInContent">
                                        <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                                        <xsl:with-param name="varPortalLocale"
                                            select="$varPortalLocale"/>
                                        <xsl:with-param name="varCurrentNode" select="self::node()"
                                        />
                                    </xsl:call-template>
                                </xsl:when>
                            </xsl:choose>
                        </xsl:for-each>
                        <!-- then create Models and ObjOccs -->
                        <xsl:for-each select="child::*">
                            <xsl:choose>
                                <xsl:when test="name()='Context'">
                                    <xsl:call-template name="createModelsAndOccsForContentInContent">
                                        <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                                        <xsl:with-param name="varPortalLocale"
                                            select="$varPortalLocale"/>
                                        <xsl:with-param name="varCurrentNode" select="self::node()"
                                        />
                                    </xsl:call-template>
                                </xsl:when>
                            </xsl:choose>
                        </xsl:for-each>
                    </xsl:if>
                    
                    <xsl:if test="$varMode=$MODE_NEW and $tempIsiView='false'">
                        <!-- before creating the model the button-objects have to created -->
                        <xsl:call-template name="printButtonDefs">
                            <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale" />
                            <xsl:with-param name="varParent" select="self::node()" />
                            <xsl:with-param name="varCxnDefType" select="$COMMON_FOR_ARIS.CT_TYPE.CT_CALLS_1" />
                        </xsl:call-template>
                        
                        <!-- now create a model for content which is not an iView; iViews do not have an assigned model -->
                        <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.MODEL}">
                            <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.MODEL.MODEL_ID}">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.MODEL.MODEL_PREFIX"/>
                                <xsl:value-of select="$DOT"/>
                                <xsl:call-template name="normalizeValue">
                                    <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"
                                    />
                                </xsl:call-template>
                            </xsl:attribute>
                            <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.MODEL.MODEL_TYPE}">
                                <xsl:value-of select="$COMMON_FOR_ARIS.MT_TYPE.MT_SCREEN_NAV"/>
                            </xsl:attribute>
    
                            <xsl:variable name="tempArisPortalNamespaceAttrValue">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName"
                                        select="$COMMON_FOR_PORTAL.CONTENT.TITLE"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                </xsl:call-template>
                            </xsl:variable>

                            <!-- Template GUID -->
                            <xsl:call-template name="addTemplateGuidIfRequired" />
    
                            <!-- AT_NAME -->
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName"
                                    select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
                                <xsl:with-param name="varAttrValue"
                                    select="$tempArisPortalNamespaceAttrValue"/>
                                <xsl:with-param name="varLocale" select="$varArisLocale"/>
                            </xsl:call-template>
                            <!-- AT_SAP_PORTAL_ID -->
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName"
                                    select="$COMMON_FOR_ARIS.ATTR.AT_SAP_PORTAL_ID"/>
                                <xsl:with-param name="varAttrValue"
                                    select="@name"/>
                                <xsl:with-param name="varLocale" select="$varArisLocale"/>
                            </xsl:call-template>
                            
                            <!-- ObjOcc -->
                            <xsl:variable name="tempSymbolForOcc">
                                <xsl:choose>
                                    <xsl:when test="$tempIsRole='true'">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_ROLE"/>
                                    </xsl:when>
                                    <xsl:when test="$tempIsiView='true'">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_IVIEW"/>
                                    </xsl:when>
                                    <xsl:when test="$tempIsPage='true'">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_PAGE"/>
                                    </xsl:when>
                                    <xsl:when test="$tempIsWorkset='true'">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_WORKSET"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:variable>
                            
                            <xsl:call-template name="printObjOcc">
                                <xsl:with-param name="varSymbol"
                                    select="$tempSymbolForOcc"/>
                                <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                <xsl:with-param name="varWithCxnContentToButton" select="true()" />
                            </xsl:call-template>
                            
                            <xsl:for-each select="child::*">
                                <xsl:choose>
                                    <xsl:when test="name()='Context'">
                                        <xsl:apply-templates select="self::node()">
                                            <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                                            <xsl:with-param name="varPortalLocale"
                                                select="$varPortalLocale"/>
                                            <xsl:with-param name="varMode" select="$MODE_REUSE"/>
                                            <xsl:with-param name="varNoRecursion" select="true()"/>
                                        </xsl:apply-templates>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                        </xsl:element>
                        
                    </xsl:if>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!--
        Description:
        for content which is embedded (and is not a deltalink) in other content the objDefs have to be created in the current ARIS group.
    -->
    <xsl:template name="createObjDefsForContentInContent">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varCurrentNode"/>

        <xsl:variable name="tempIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWorkset">
            <xsl:call-template name="common_for_check.isWorkset">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsTemplateiView">
            <xsl:call-template name="common_for_check.isTemplateiView">
                <xsl:with-param name="varTemplate" select="$varCurrentNode/@template"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsTemplatePage">
            <xsl:call-template name="common_for_check.isTemplatePage">
                <xsl:with-param name="varTemplate" select="$varCurrentNode/@template"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:choose>
            <xsl:when test="$tempIsRole='true' and $varCurrentNode/@create_as='0'">
                <xsl:call-template name="transformRole">
                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                    <xsl:with-param name="varMode" select="$MODE_VARIANT"/>
                </xsl:call-template>
                
                <xsl:call-template name="printButtonDefs">
                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale" />
                    <xsl:with-param name="varParent" select="self::node()" />
                    <xsl:with-param name="varCxnDefType" select="$COMMON_FOR_ARIS.CT_TYPE.CT_CALLS_1" />
                </xsl:call-template>
            </xsl:when>
            <xsl:when test="$tempIsWorkset='true' and $varCurrentNode/@create_as='0'">
                <xsl:call-template name="transformWorkset">
                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                    <xsl:with-param name="varMode" select="$MODE_VARIANT"/>
                </xsl:call-template>
                
                <xsl:call-template name="printButtonDefs">
                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale" />
                    <xsl:with-param name="varParent" select="self::node()" />
                    <xsl:with-param name="varCxnDefType" select="$COMMON_FOR_ARIS.CT_TYPE.CT_CALLS_1" />
                </xsl:call-template>
            </xsl:when>
            <xsl:when test="$tempIsTemplatePage='true'">
                <xsl:call-template name="transformPage">
                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                    <xsl:with-param name="varMode" select="$MODE_VARIANT"/>
                </xsl:call-template>
                
                <xsl:call-template name="printButtonDefs">
                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale" />
                    <xsl:with-param name="varParent" select="self::node()" />
                    <xsl:with-param name="varCxnDefType" select="$COMMON_FOR_ARIS.CT_TYPE.CT_CALLS_1" />
                </xsl:call-template>
            </xsl:when>
            <xsl:when test="$tempIsTemplateiView='true'">
                <xsl:call-template name="transformiView">
                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                    <xsl:with-param name="varMode" select="$MODE_VARIANT"/>
                </xsl:call-template>
                
                <xsl:call-template name="printButtonDefs">
                    <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale" />
                    <xsl:with-param name="varParent" select="self::node()" />
                    <xsl:with-param name="varCxnDefType" select="$COMMON_FOR_ARIS.CT_TYPE.CT_CALLS_1" />
                </xsl:call-template>
            </xsl:when>
        </xsl:choose>

        <xsl:for-each select="child::*">
            <xsl:choose>
                <xsl:when test="name()='Context'">
                    <xsl:call-template name="createObjDefsForContentInContent">
                        <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                        <xsl:with-param name="varCurrentNode" select="self::node()"/>
                    </xsl:call-template>
                </xsl:when>
            </xsl:choose>
        </xsl:for-each>

    </xsl:template>

    <!--
        Description:
        after creating all ObjDefs for content which is embedded in other content (and is not a delta link) Models and Occs have to be created.
    -->
    <xsl:template name="createModelsAndOccsForContentInContent">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varCurrentNode"/>
        
        <xsl:variable name="tempIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsPage">
            <xsl:call-template name="common_for_check.isPage">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsiView">
            <xsl:call-template name="common_for_check.isiView">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWorkset">
            <xsl:call-template name="common_for_check.isWorkset">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempSymbolForOcc">
            <xsl:choose>
                <xsl:when test="$tempIsRole='true'">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_ROLE"/>
                </xsl:when>
                <xsl:when test="$tempIsiView='true'">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_IVIEW"/>
                </xsl:when>
                <xsl:when test="$tempIsPage='true'">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_PAGE"/>
                </xsl:when>
                <xsl:when test="$tempIsWorkset='true'">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_WORKSET"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="tempCreateModel">
            <xsl:call-template name="common_for_check.isNotADeltaLink">
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode" />
            </xsl:call-template>
        </xsl:variable>

        <xsl:if test="$tempCreateModel='true'">
            <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.MODEL}">
                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.MODEL.MODEL_ID}">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.MODEL.MODEL_PREFIX"/>
                    <xsl:value-of select="$DOT"/>
                    <xsl:call-template name="normalizeValue">
                        <xsl:with-param name="varCurrentValue"
                            select="$varCurrentNode/@arisPortalNamespace"/>
                    </xsl:call-template>
                </xsl:attribute>
                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.MODEL.MODEL_TYPE}">
                    <xsl:value-of select="$COMMON_FOR_ARIS.MT_TYPE.MT_SCREEN_NAV"/>
                </xsl:attribute>

                <xsl:variable name="tempArisPortalNamespaceAttrValue">
                    <xsl:call-template name="determineAttrInLocale">
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.TITLE"/>
                        <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                    </xsl:call-template>
                </xsl:variable>

                <!-- Template GUID -->
                <xsl:call-template name="addTemplateGuidIfRequired" />

                <!-- AT_NAME -->
                <xsl:call-template name="common_for_aris.printAttrElement">
                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
                    <xsl:with-param name="varAttrValue" select="$tempArisPortalNamespaceAttrValue"/>
                    <xsl:with-param name="varLocale" select="$varArisLocale"/>
                </xsl:call-template>
                <!-- AT_SAP_PORTAL_ID -->
                <xsl:call-template name="common_for_aris.printAttrElement">
                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_PORTAL_ID"/>
                    <xsl:with-param name="varAttrValue" select="$varCurrentNode/@name"/>
                    <xsl:with-param name="varLocale" select="$varArisLocale"/>
                </xsl:call-template>
                
                <!-- ObjOcc -->
                <xsl:call-template name="printObjOcc">
                    <xsl:with-param name="varSymbol" select="$tempSymbolForOcc"/>
                    <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                    <xsl:with-param name="varWithContentInContentSuffix" select="true()"/>
                    <xsl:with-param name="varWithCxnContentToButton" select="true()" />
                </xsl:call-template>

                <xsl:for-each select="child::*">
                    <xsl:choose>
                        <xsl:when test="name()='Context'">
                            <xsl:apply-templates select="self::node()">
                                <xsl:with-param name="varArisLocale" select="$varArisLocale"/>
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varMode" select="$MODE_REUSE"/>
                                <xsl:with-param name="varNoRecursion" select="true()"/>
                            </xsl:apply-templates>
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
            </xsl:element>
        </xsl:if>
    </xsl:template>

    <!-- 
        Description:
        creates AML-representation of the portal group    
    -->
    <xsl:template name="transformGroup">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>

        <xsl:variable name="tempGroupName">
            <xsl:call-template name="determineAttrInLocale">
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.GROUP.TITLE"/>
                <xsl:with-param name="varCurrentNode" select="self::node()"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="tempUniqueGroupName">
            <xsl:call-template name="determineUniqueGroupName">
                <xsl:with-param name="varGroupName" select="$tempGroupName"/>
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varPrecedingSiblings" select="preceding-sibling::Context"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.GROUP.GROUP_ID}">
            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.GROUP.GROUP_PREFIX"/>
            <xsl:value-of select="$DOT"/>
            <xsl:call-template name="normalizeValue">
                <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
            </xsl:call-template>
        </xsl:attribute>
        <!-- AT_NAME -->
        <xsl:call-template name="common_for_aris.printAttrElement">
            <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
            <xsl:with-param name="varAttrValue" select="$tempUniqueGroupName"/>
            <xsl:with-param name="varLocale" select="$varArisLocale"/>
        </xsl:call-template>
        <!-- AT_PORTAL_ID -->
        <xsl:call-template name="common_for_aris.printAttrElement">
            <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_PORTAL_ID" />
            <xsl:with-param name="varAttrValue" select="@name" />
            <xsl:with-param name="varLocale" select="$varArisLocale" />
        </xsl:call-template>

    </xsl:template>


    <!-- 
        Description:
        creates AML-representation of the portal role    
    -->
    <xsl:template name="transformRole">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varMode"/>
        <xsl:param name="varWithContentInContentSuffix"/>

        <xsl:choose>
            <xsl:when test="$varMode=$MODE_NEW or $varMode=$MODE_VARIANT">
                <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.OBJDEF}">
                    <xsl:variable name="tempArisPortalNamespaceAttrValue">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName"
                                select="$COMMON_FOR_PORTAL.GROUP.TITLE"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                        </xsl:call-template>
                    </xsl:variable>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.OBJDEF_ID}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:call-template name="normalizeValue">
                            <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                        </xsl:call-template>
                    </xsl:attribute>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.TYPENUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.OT_TYPE.OT_SCRN"/>
                    </xsl:attribute>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.SYMBOLNUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_ROLE"/>
                    </xsl:attribute>
                    
                    <!-- Assigned Model -->
                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.LINKEDMODELS_ID_REFS}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.MODEL.MODEL_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:call-template name="normalizeValue">
                            <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                        </xsl:call-template>
                    </xsl:attribute>
                    
                    <!-- AT_NAME -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
                        <xsl:with-param name="varAttrValue"
                            select="$tempArisPortalNamespaceAttrValue"/>
                        <xsl:with-param name="varLocale" select="$varArisLocale"/>
                    </xsl:call-template>
                    <!-- AT_PORTAL_ID -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_PORTAL_ID" />
                        <xsl:with-param name="varAttrValue" select="@name" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_MERGE_ID -->
                    <xsl:variable name="tempMergeId">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.MERGE_ID"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                            <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                        </xsl:call-template>   
                    </xsl:variable>
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_MERGE_ID" />
                        <xsl:with-param name="varAttrValue" select="$tempMergeId" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_SRC_PORTAL_ID -->
                    <xsl:choose>
                        <xsl:when test="$varMode=$MODE_VARIANT">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SRC_PORTAL_ID" />
                                <xsl:with-param name="varAttrValue" select="@arisTemplate" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SRC_PORTAL_ID" />
                                <xsl:with-param name="varAttrValue" select="@arisPortalNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:otherwise>
                    </xsl:choose>
                    
                    <!-- CxnDef -->
                    
                    <xsl:call-template name="printCxnDefs">
                        <xsl:with-param name="varCurrentNode" select="self::node()" />
                        <xsl:with-param name="varCxnDefType" select="$COMMON_FOR_ARIS.CT_TYPE.CT_CONTAINS_2" />
                    </xsl:call-template>
                    
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="printObjOcc">
                    <xsl:with-param name="varSymbol" select="$COMMON_FOR_ARIS.ST_TYPE.FOR_ROLE"/>
                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                    <xsl:with-param name="varWithCxnButtonToContent" select="true()" />
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>

    <!-- 
        Description:
        creates AML-representation of the portal iView
    -->
    <xsl:template name="transformiView">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varMode"/>
        <xsl:param name="varWithContentInContentSuffix"/>
        
        <xsl:variable name="tempIsTransactioniView">
            <xsl:call-template name="common_for_check.isTransactioniView">
                <xsl:with-param name="varTemplate" select="@template" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsURLiView">
            <xsl:call-template name="common_for_check.isURLiView">
                <xsl:with-param name="varTemplate" select="@template" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsBSPiView">
            <xsl:call-template name="common_for_check.isBSPiView">
                <xsl:with-param name="varTemplate" select="@template" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsIACiView">
            <xsl:call-template name="common_for_check.isIACiView">
                <xsl:with-param name="varTemplate" select="@template" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWebDynproiView">
            <xsl:call-template name="common_for_check.isWebDynproiView">
                <xsl:with-param name="varTemplate" select="@template" />
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="$varMode=$MODE_NEW or $varMode=$MODE_VARIANT">
                <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.OBJDEF}">
                    <xsl:variable name="tempArisPortalNamespaceAttrValue">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName"
                                select="$COMMON_FOR_PORTAL.GROUP.TITLE"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                        </xsl:call-template>
                    </xsl:variable>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.OBJDEF_ID}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:call-template name="normalizeValue">
                            <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                        </xsl:call-template>
                    </xsl:attribute>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.TYPENUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.OT_TYPE.OT_SCRN"/>
                    </xsl:attribute>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.SYMBOLNUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_IVIEW"/>
                    </xsl:attribute>
                    
                    <!-- AT_NAME -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
                        <xsl:with-param name="varAttrValue"
                            select="$tempArisPortalNamespaceAttrValue"/>
                        <xsl:with-param name="varLocale" select="$varArisLocale"/>
                    </xsl:call-template>
                    <!-- AT_PORTAL_ID -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_PORTAL_ID" />
                        <xsl:with-param name="varAttrValue" select="@name" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_MERGE_ID -->
                    <xsl:variable name="tempMergeId">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.MERGE_ID"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                            <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                        </xsl:call-template>   
                    </xsl:variable>
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_MERGE_ID" />
                        <xsl:with-param name="varAttrValue" select="$tempMergeId" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_SRC_PORTAL_ID -->
                    <xsl:choose>
                        <xsl:when test="$varMode=$MODE_VARIANT">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SRC_PORTAL_ID" />
                                <xsl:with-param name="varAttrValue" select="@arisTemplate" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SRC_PORTAL_ID" />
                                <xsl:with-param name="varAttrValue" select="@arisPortalNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:otherwise>
                    </xsl:choose>
                    <!-- AT_SAP_TEMPLATE_ID -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_TEMPLATE_ID" />
                        <xsl:with-param name="varAttrValue" select="@arisTemplate" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_IVIEW_TYPE -->
                    <xsl:variable name="tempiViewType">
                        <xsl:choose>
                            <xsl:when test="$tempIsTransactioniView='true'">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_TRANSACTION"/>
                            </xsl:when>
                            <xsl:when test="$tempIsURLiView='true'">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_URL"/>
                            </xsl:when>
                            <xsl:when test="$tempIsBSPiView='true'">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_BSP"/>
                            </xsl:when>
                            <xsl:when test="$tempIsIACiView='true'">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_IAC"/>
                            </xsl:when>
                            <xsl:when test="$tempIsWebDynproiView='true'">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_WEB_DYNPRO"/>
                            </xsl:when>
                        </xsl:choose>
                    </xsl:variable>
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_IVIEW_TYPE" />
                        <xsl:with-param name="varAttrValue" select="$tempiViewType" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_SYSTEM -->
                    <xsl:variable name="tempSystem">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.SYSTEM"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                            <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                        </xsl:call-template>   
                    </xsl:variable>
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SYSTEM" />
                        <xsl:with-param name="varAttrValue" select="$tempSystem" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_APPL_PARAM -->
                    <xsl:variable name="tempApplicationParameter">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.APPLICATION_PARAMETER"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                            <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                        </xsl:call-template>   
                    </xsl:variable>
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_APPL_PARAM" />
                        <xsl:with-param name="varAttrValue" select="$tempApplicationParameter" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    
                    <xsl:choose>
                        <xsl:when test="$tempIsIACiView='true'">
                            <!-- IAC -->
                            <!-- AT_SAP_IAC -->
                            <xsl:variable name="tempIAC">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.IAC"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_IAC" />
                                <xsl:with-param name="varAttrValue" select="$tempIAC" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:when test="$tempIsTransactioniView='true'">
                            <!-- TRANS_CODE -->
                            <!-- AT_TRANS_CODE -->
                            <xsl:variable name="tempTCode">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.TCODE"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_TRANS_CODE" />
                                <xsl:with-param name="varAttrValue" select="$tempTCode" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                            <!-- AT_SAP_GUI_TYPE -->
                            <xsl:variable name="tempGuiTypeToCalculate">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.GUI_TYPE"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:variable name="tempGuiType">
                                <xsl:choose>
                                    <xsl:when test="$tempGuiTypeToCalculate=$COMMON_FOR_PORTAL.CONTENT.GUI_TYPE.WIN">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_GUI_WIN"/>
                                    </xsl:when>
                                    <xsl:when test="$tempGuiTypeToCalculate=$COMMON_FOR_PORTAL.CONTENT.GUI_TYPE.JAVA">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_GUI_JAVA"/>
                                    </xsl:when>
                                    <xsl:when test="$tempGuiTypeToCalculate=$COMMON_FOR_PORTAL.CONTENT.GUI_TYPE.WEB">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_GUI_HTML"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_GUI_TYPE" />
                                <xsl:with-param name="varAttrValue" select="$tempGuiType" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:when test="$tempIsBSPiView='true'">
                            <!-- BSP -->
                            <!-- AT_SAP_APPL_NAMESPACE -->
                            <xsl:variable name="tempApplicationNamespace">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.NAMESPACE"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_APPL_NAMESPACE" />
                                <xsl:with-param name="varAttrValue" select="$tempApplicationNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                            <!-- AT_SAP_CUSTOMER_NAMESPACE -->
                            <xsl:variable name="tempCustomerNamespace">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.CUSTOMER_NAMESPACE"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_CUSTOMER_NAMESPACE" />
                                <xsl:with-param name="varAttrValue" select="$tempCustomerNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                            <!-- AT_SAP_BSP_DEF_TYPE -->
                            <xsl:variable name="tempDefinitionTypeToCalculate">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.DEFINITION_TYPE"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:variable name="tempDefinitionType">
                                <xsl:choose>
                                    <xsl:when test="$tempDefinitionTypeToCalculate=$COMMON_FOR_PORTAL.CONTENT.DEFINITION_TYPE.BSP">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_BSP_APPL"/>
                                    </xsl:when>
                                    <xsl:when test="$tempDefinitionTypeToCalculate=$COMMON_FOR_PORTAL.CONTENT.DEFINITION_TYPE.BSP_ALIAS">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_BSP_ALIAS"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_BSP_DEF_TYPE" />
                                <xsl:with-param name="varAttrValue" select="$tempDefinitionType" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                            <!-- AT_SAP_BSP_START_PAGE -->
                            <xsl:variable name="tempStartPage">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.PAGE_ID"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_BSP_START_PAGE" />
                                <xsl:with-param name="varAttrValue" select="$tempStartPage" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:when test="$tempIsWebDynproiView='true'">
                            <!-- WebDynpro -->
                            <!-- AT_SAP_WEB_DYNPRO_DEF_TYPE -->
                            <xsl:variable name="tempDefinitionTypeToCalculate">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_DEFINITION_TYPE"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:variable name="tempDefinitionType">
                                <xsl:choose>
                                    <xsl:when test="$tempDefinitionTypeToCalculate=$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_DEFINITION_TYPE.ABAP">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_WEB_DYNPRO_ABAP"/>
                                    </xsl:when>
                                    <xsl:when test="$tempDefinitionTypeToCalculate=$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_DEFINITION_TYPE.JAVA">
                                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_WEB_DYNPRO_JAVA"/>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_WEB_DYNPRO_DEF_TYPE" />
                                <xsl:with-param name="varAttrValue" select="$tempDefinitionType" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                            <!-- AT_SAP_APPL_NAME -->
                            <xsl:variable name="tempWebDynproApp">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_APPLICATION"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_APPL_NAME" />
                                <xsl:with-param name="varAttrValue" select="$tempWebDynproApp" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                            <!-- AT_SAP_NAMESPACE -->
                            <xsl:variable name="tempWebDynproNamespace">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_NAMESPACE"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_NAMESPACE" />
                                <xsl:with-param name="varAttrValue" select="$tempWebDynproNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:when test="$tempIsURLiView='true'">
                            <!-- URL -->
                            <!-- AT_EXT_1 -->
                            <xsl:variable name="tempURL">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.URL"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_EXT_1" />
                                <xsl:with-param name="varAttrValue" select="$tempURL" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                            <!-- AT_PARM_1 -->
                            <xsl:variable name="tempURLParam">
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.URL_PARAM"/>
                                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                                </xsl:call-template>   
                            </xsl:variable>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_PARM_1" />
                                <xsl:with-param name="varAttrValue" select="$tempURLParam" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        
                        
                    </xsl:choose>
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="printObjOcc">
                    <xsl:with-param name="varSymbol" select="$COMMON_FOR_ARIS.ST_TYPE.FOR_IVIEW"/>
                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                    <xsl:with-param name="varWithCxnButtonToContent" select="true()" />
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- 
        Description:
        creates AML-representation of the portal page
    -->
    <xsl:template name="transformPage">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varMode"/>
        <xsl:param name="varWithContentInContentSuffix"/>

        <xsl:choose>
            <xsl:when test="$varMode=$MODE_NEW or $varMode=$MODE_VARIANT">
                <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.OBJDEF}">
                    <xsl:variable name="tempArisPortalNamespaceAttrValue">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName"
                                select="$COMMON_FOR_PORTAL.GROUP.TITLE"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                        </xsl:call-template>
                    </xsl:variable>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.OBJDEF_ID}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:call-template name="normalizeValue">
                            <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                        </xsl:call-template>
                    </xsl:attribute>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.TYPENUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.OT_TYPE.OT_SCRN"/>
                    </xsl:attribute>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.SYMBOLNUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_PAGE"/>
                    </xsl:attribute>
                    
                    <!-- Assigned Model -->
                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.LINKEDMODELS_ID_REFS}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.MODEL.MODEL_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:call-template name="normalizeValue">
                            <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                        </xsl:call-template>
                    </xsl:attribute>
                    
                    <!-- AT_NAME -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
                        <xsl:with-param name="varAttrValue"
                            select="$tempArisPortalNamespaceAttrValue"/>
                        <xsl:with-param name="varLocale" select="$varArisLocale"/>
                    </xsl:call-template>
                    <!-- AT_PORTAL_ID -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_PORTAL_ID" />
                        <xsl:with-param name="varAttrValue" select="@name" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_MERGE_ID -->
                    <xsl:variable name="tempMergeId">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.MERGE_ID"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                            <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                        </xsl:call-template>   
                    </xsl:variable>
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_MERGE_ID" />
                        <xsl:with-param name="varAttrValue" select="$tempMergeId" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_SRC_PORTAL_ID -->
                    <xsl:choose>
                        <xsl:when test="$varMode=$MODE_VARIANT">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SRC_PORTAL_ID" />
                                <xsl:with-param name="varAttrValue" select="@arisTemplate" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SRC_PORTAL_ID" />
                                <xsl:with-param name="varAttrValue" select="@arisPortalNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:otherwise>
                    </xsl:choose>
                    
                    <!-- CxnDef -->
                    
                    <xsl:call-template name="printCxnDefs">
                        <xsl:with-param name="varCurrentNode" select="self::node()" />
                        <xsl:with-param name="varCxnDefType" select="$COMMON_FOR_ARIS.CT_TYPE.CT_CONTAINS_2" />
                    </xsl:call-template>
                    
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="printObjOcc">
                    <xsl:with-param name="varSymbol" select="$COMMON_FOR_ARIS.ST_TYPE.FOR_PAGE"/>
                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                    <xsl:with-param name="varWithCxnButtonToContent" select="true()" />
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- 
        Description:
        creates AML-representation of the portal workset    
    -->
    <xsl:template name="transformWorkset">
        <xsl:param name="varArisLocale"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varMode"/>
        <xsl:param name="varWithContentInContentSuffix"/>

        <xsl:choose>
            <xsl:when test="$varMode=$MODE_NEW or $varMode=$MODE_VARIANT">
                <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.OBJDEF}">
                    <xsl:variable name="tempArisPortalNamespaceAttrValue">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName"
                                select="$COMMON_FOR_PORTAL.GROUP.TITLE"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                        </xsl:call-template>
                    </xsl:variable>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.OBJDEF_ID}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:call-template name="normalizeValue">
                            <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                        </xsl:call-template>
                    </xsl:attribute>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.TYPENUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.OT_TYPE.OT_SCRN"/>
                    </xsl:attribute>

                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.SYMBOLNUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_WORKSET"/>
                    </xsl:attribute>
                    
                    <!-- Assigned Model -->
                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.LINKEDMODELS_ID_REFS}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.MODEL.MODEL_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:call-template name="normalizeValue">
                            <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                        </xsl:call-template>
                    </xsl:attribute>
                    
                    <!-- AT_NAME -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
                        <xsl:with-param name="varAttrValue"
                            select="$tempArisPortalNamespaceAttrValue"/>
                        <xsl:with-param name="varLocale" select="$varArisLocale"/>
                    </xsl:call-template>
                    <!-- AT_PORTAL_ID -->
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_PORTAL_ID" />
                        <xsl:with-param name="varAttrValue" select="@name" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_MERGE_ID -->
                    <xsl:variable name="tempMergeId">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.MERGE_ID"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                            <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                        </xsl:call-template>   
                    </xsl:variable>
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_MERGE_ID" />
                        <xsl:with-param name="varAttrValue" select="$tempMergeId" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                    <!-- AT_SAP_SRC_PORTAL_ID -->
                    <xsl:choose>
                        <xsl:when test="$varMode=$MODE_VARIANT">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SRC_PORTAL_ID" />
                                <xsl:with-param name="varAttrValue" select="@arisTemplate" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SRC_PORTAL_ID" />
                                <xsl:with-param name="varAttrValue" select="@arisPortalNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:otherwise>
                    </xsl:choose>
                    
                    <!-- CxnDef -->
                    
                    <xsl:call-template name="printCxnDefs">
                        <xsl:with-param name="varCurrentNode" select="self::node()" />
                        <xsl:with-param name="varCxnDefType" select="$COMMON_FOR_ARIS.CT_TYPE.CT_CONTAINS_2" />
                    </xsl:call-template>
                    
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="printObjOcc">
                    <xsl:with-param name="varSymbol" select="$COMMON_FOR_ARIS.ST_TYPE.FOR_WORKSET"/>
                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                    <xsl:with-param name="varWithCxnButtonToContent" select="true()" />
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- 
        Description:
        determines a unique group name. ARIS group names must be unique.
    -->
    <xsl:template name="determineUniqueGroupName">
        <xsl:param name="varGroupName"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varPrecedingSiblings"/>

        <xsl:variable name="tempGroupNameUnique">
            <xsl:call-template name="isGroupNameUnique">
                <xsl:with-param name="varGroupName" select="$varGroupName"/>
                <xsl:with-param name="varPrecedingSiblings" select="$varPrecedingSiblings"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:choose>
            <xsl:when test="$tempGroupNameUnique='true'">
                <xsl:value-of select="$varGroupName"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="tempNextGroupName">
                    <xsl:value-of select="$varGroupName"/>
                    <xsl:value-of select="' (1)'"/>
                </xsl:variable>

                <xsl:call-template name="determineUniqueGroupName">
                    <xsl:with-param name="varGroupName" select="$tempNextGroupName"/>
                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                    <xsl:with-param name="varPrecedingSiblings" select="$varPrecedingSiblings"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>

    <!--
        Description:
        checks if group name would be unique
    -->
    <xsl:template name="isGroupNameUnique">
        <xsl:param name="varGroupName"/>
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varPrecedingSiblings"/>

        <xsl:variable name="tempResult">
            <xsl:for-each select="$varPrecedingSiblings">
                <xsl:variable name="tempIsGroup">
                    <xsl:call-template name="common_for_check.isGroup">
                        <xsl:with-param name="varObjectClass" select="@objectClass"/>
                    </xsl:call-template>
                </xsl:variable>
                <xsl:if test="$tempIsGroup='true'">
                    <xsl:variable name="tempCurrentName">
                        <xsl:call-template name="determineAttrInLocale">
                            <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                            <xsl:with-param name="varAttrName"
                                select="$COMMON_FOR_PORTAL.CONTENT.TITLE"/>
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                        </xsl:call-template>
                    </xsl:variable>

                    <xsl:if test="$varGroupName=$tempCurrentName">
                        <xsl:value-of select="true()"/>
                    </xsl:if>
                </xsl:if>
            </xsl:for-each>
        </xsl:variable>

        <xsl:choose>
            <xsl:when test="starts-with($tempResult, 'true')">
                <xsl:value-of select="false()"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="true()"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    
    <!-- 
        Description:
        this template writes CxnDef-Elements and is used by transform<Portal Object Type> templates
    -->
    <xsl:template name="printCxnDefs">
        <xsl:param name="varCurrentNode" />
        <xsl:param name="varCxnDefType" />
       
        <xsl:variable name="tempParentIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:for-each select="child::Context">
            <xsl:variable name="tempResolvedObjDefID">
                <xsl:call-template name="determineObjDefID">
                    <xsl:with-param name="varCurrentNode" select="self::node()"/>
                </xsl:call-template>
            </xsl:variable>
            
            <xsl:variable name="tempIsRole">
                <xsl:call-template name="common_for_check.isRole">
                    <xsl:with-param name="varObjectClass" select="@objectClass"/>
                </xsl:call-template>
            </xsl:variable>
            
            <xsl:choose>
                <xsl:when test="not($tempParentIsRole='true' and $tempIsRole='true')">
                    <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.CXNDEF}">
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.CXNDEF_ID}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNDEF.CXNDEF_PREFIX"/>
                            <xsl:value-of select="$DOT"/>
                            <xsl:call-template name="normalizeValue">
                                <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                            </xsl:call-template>
                            <xsl:value-of select="$DOT"/>
                            <xsl:value-of select="$FROM_CONTENT_TO_BUTTON"/>
                        </xsl:attribute>
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.CXNDEF_TYPE}">
                            <xsl:value-of select="$varCxnDefType"/>
                        </xsl:attribute>
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.TO_OBJDEF_ID_REF}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                            <xsl:value-of select="$DOT"/>
                            <xsl:call-template name="normalizeValue">
                                <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                            </xsl:call-template>
                            <xsl:value-of select="$DOT"/>
                            <xsl:value-of select="$BUTTON_SUFFIX"/>
                        </xsl:attribute>
                    </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="tempNextObjDefId">
                        <xsl:call-template name="determineNextObjDefID">
                            <xsl:with-param name="varCurrentNode" select="self::node()" />
                        </xsl:call-template>
                    </xsl:variable>
                    
                    <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.CXNDEF}">
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.CXNDEF_ID}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNDEF.CXNDEF_PREFIX"/>
                            <xsl:value-of select="$DOT"/>
                            <xsl:call-template name="normalizeValue">
                                <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                            </xsl:call-template>
                            <xsl:value-of select="$DOT"/>
                            <xsl:value-of select="$FROM_CONTENT_TO_CONTENT"/>
                        </xsl:attribute>
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.CXNDEF_TYPE}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.CT_TYPE.CT_CONS_OF_1"/>
                        </xsl:attribute>
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.TO_OBJDEF_ID_REF}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                            <xsl:value-of select="$DOT"/>
                            <xsl:call-template name="normalizeValue">
                                <xsl:with-param name="varCurrentValue" select="$tempNextObjDefId"/>
                            </xsl:call-template>
                        </xsl:attribute>
                    </xsl:element>
                </xsl:otherwise>
            </xsl:choose>
            
        </xsl:for-each>
    </xsl:template>
    
    <!-- 
        Description:
        this template writes ButtonDef-Elements for child elements
    -->
    <xsl:template name="printButtonDefs">
        <xsl:param name="varArisLocale" />
        <xsl:param name="varPortalLocale" />
        <xsl:param name="varParent" />
        <xsl:param name="varCxnDefType" />
        
        <xsl:variable name="tempParentIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varParent/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>        
        
        <xsl:for-each select="child::Context">
            <xsl:variable name="tempIsRole">
                <xsl:call-template name="common_for_check.isRole">
                    <xsl:with-param name="varObjectClass" select="@objectClass"/>
                </xsl:call-template>
            </xsl:variable>
            
            <xsl:if test="not($tempParentIsRole = 'true' and $tempIsRole = 'true')">
                <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.OBJDEF}">                
                    
                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.OBJDEF_ID}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                        <xsl:value-of select="$DOT"/>
                        <xsl:call-template name="normalizeValue">
                            <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                        </xsl:call-template>
                        <xsl:value-of select="$DOT"/>
                        <xsl:value-of select="$BUTTON_SUFFIX"/>
                    </xsl:attribute>
                    
                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.TYPENUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.OT_TYPE.OT_BUTTON"/>
                    </xsl:attribute>
                    
                    <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJDEF.SYMBOLNUM}">
                        <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_BUTTON"/>
                    </xsl:attribute>
                    
                    <xsl:call-template name="printButtonAttr">
                        <xsl:with-param name="varArisLocale" select="$varArisLocale" />
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale" />
                        <xsl:with-param name="varCurrentNode" select="self::node()" />
                    </xsl:call-template>
                    
                    <!-- CxnDef  from Button to Content-Object -->
                    <xsl:variable name="tempResolvedObjDefID">
                        <xsl:call-template name="determineObjDefID">
                            <xsl:with-param name="varCurrentNode" select="self::node()"/>
                        </xsl:call-template>
                    </xsl:variable>
                    
                    <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.CXNDEF}">
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.CXNDEF_ID}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNDEF.CXNDEF_PREFIX"/>
                            <xsl:value-of select="$DOT"/>
                            <xsl:call-template name="normalizeValue">
                                <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                            </xsl:call-template>
                            <xsl:value-of select="$DOT"/>
                            <xsl:value-of select="$FROM_BUTTON_TO_CONTENT"/>
                        </xsl:attribute>
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.CXNDEF_TYPE}">
                            <xsl:value-of select="$varCxnDefType"/>
                        </xsl:attribute>
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNDEF.TO_OBJDEF_ID_REF}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                            <xsl:value-of select="$DOT"/>
                            <xsl:call-template name="normalizeValue">
                                <xsl:with-param name="varCurrentValue" select="$tempResolvedObjDefID"/>
                            </xsl:call-template>
                        </xsl:attribute>
                    </xsl:element>
                    
                </xsl:element>
            </xsl:if>
            
            
        </xsl:for-each>
    </xsl:template>
    
    <!-- 
        Description:
        this template writes Attributes for the ButtonDef-Elements
    -->
    <xsl:template name="printButtonAttr">
        <xsl:param name="varArisLocale" />
        <xsl:param name="varPortalLocale" />
        <xsl:param name="varCurrentNode" />
                
        <xsl:variable name="tempIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsPage">
            <xsl:call-template name="common_for_check.isPage">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsiView">
            <xsl:call-template name="common_for_check.isiView">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWorkset">
            <xsl:call-template name="common_for_check.isWorkset">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:variable name="tempName">
            <xsl:call-template name="determineAttrInLocale">
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.TITLE"/>
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode" />
                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
            </xsl:call-template>   
        </xsl:variable>
        
        <!-- AT_NAME -->
        <xsl:call-template name="common_for_aris.printAttrElement">
            <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_NAME"/>
            <xsl:with-param name="varAttrValue"
                select="$tempName"/>
            <xsl:with-param name="varLocale" select="$varArisLocale"/>
        </xsl:call-template>
        
        <!-- AT_SAP_MERGE_ID -->
        <xsl:variable name="tempMergeIdUnresolved">
            <xsl:call-template name="determineAttrInLocale">
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.MERGE_ID"/>
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
            </xsl:call-template>   
        </xsl:variable>
        <xsl:variable name="tempMergeId">
            <xsl:call-template name="determineAttrInLocale">
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.MERGE_ID"/>
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
            </xsl:call-template>   
        </xsl:variable>
        <xsl:if test="$tempMergeIdUnresolved!='' and $tempMergeIdUnresolved!=$tempMergeId">
            <xsl:call-template name="common_for_aris.printAttrElement">
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_MERGE_ID" />
                <xsl:with-param name="varAttrValue" select="$tempMergeId" />
                <xsl:with-param name="varLocale" select="$varArisLocale" />
            </xsl:call-template>
        </xsl:if>
        
        <!-- AT_SAP_ENTRY_POINT -->
        <xsl:variable name="tempEntryPoint">
            <xsl:call-template name="determineAttrInLocale">
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.ENTRY_POINT"/>
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
            </xsl:call-template>   
        </xsl:variable>
        <xsl:if test="$tempEntryPoint='false' or $tempEntryPoint='true'">
            <xsl:call-template name="common_for_aris.printAttrElement">
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_ENTRY_POINT" />
                <xsl:with-param name="varAttrValue" select="$tempEntryPoint" />
                <xsl:with-param name="varLocale" select="$varArisLocale" />
            </xsl:call-template>
        </xsl:if>
        <!-- AT_SAP_INVISIBLE_IN_NAVIG_AREA -->
        <xsl:variable name="tempInvisibleInNavigation">
            <xsl:call-template name="determineAttrInLocale">
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.INVISBLE_IN_NAVIGATION"/>
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
            </xsl:call-template>   
        </xsl:variable>
        <xsl:if test="$tempInvisibleInNavigation='false' or $tempInvisibleInNavigation='true'">
            <xsl:call-template name="common_for_aris.printAttrElement">
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_INVISIBLE_IN_NAVIG_AREA" />
                <xsl:with-param name="varAttrValue" select="$tempInvisibleInNavigation" />
                <xsl:with-param name="varLocale" select="$varArisLocale" />
            </xsl:call-template>
        </xsl:if>
        <!-- AVT_SAP_LAUNCH_IN_SEPARATE_PORTAL_WINDOW -->
        <xsl:variable name="tempLaunchInSeparateWindow">
            <xsl:call-template name="determineAttrInLocale">
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.NAVIGATION_PANEL_STATUS"/>
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
            </xsl:call-template>   
        </xsl:variable>
        <xsl:variable name="tempLaunchInSeparateWindowValue">
            <xsl:choose>
                <xsl:when test="$tempLaunchInSeparateWindow=$COMMON_FOR_PORTAL.CONTENT.NAVIGATION_PANEL_STATUS.AUTOMATIC">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_NAVIG_PANEL_INIT_STATE_AUTO"/>
                </xsl:when>
                <xsl:when test="$tempLaunchInSeparateWindow=$COMMON_FOR_PORTAL.CONTENT.NAVIGATION_PANEL_STATUS.OPEN">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_NAVIG_PANEL_INIT_STATE_OPEN"/>
                </xsl:when>
                <xsl:when test="$tempLaunchInSeparateWindow=$COMMON_FOR_PORTAL.CONTENT.NAVIGATION_PANEL_STATUS.CLOSE">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_NAVIG_PANEL_INIT_STATE_CLOSED"/>
                </xsl:when>
                <xsl:when test="$tempLaunchInSeparateWindow=$COMMON_FOR_PORTAL.CONTENT.NAVIGATION_PANEL_STATUS.ALWAYS_CLOSE">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_NAVIG_PANEL_INIT_STATE_ALWAYS_CLOSED"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_NAVIG_PANEL_INIT_STATE_AUTO"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:call-template name="common_for_aris.printAttrElement">
            <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_INITIAL_STATE_OF_NAVIG_PANEL" />
            <xsl:with-param name="varAttrValue" select="$tempLaunchInSeparateWindowValue" />
            <xsl:with-param name="varLocale" select="$varArisLocale" />
        </xsl:call-template>
        <!-- COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_LAUNCH_IN_SEPARATE_HEADERL_PORTAL_WIN -->
        <xsl:variable name="tempLaunchInNewWindow">
            <xsl:call-template name="determineAttrInLocale">
                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.SHOW_TYPE"/>
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
            </xsl:call-template>   
        </xsl:variable>
        <xsl:variable name="tempLaunchInNewWindowValue">
            <xsl:choose>
                <xsl:when test="$tempLaunchInNewWindow=$COMMON_FOR_PORTAL.CONTENT.SHOW_TYPE.IN_PORTAL_CONTENT_AREA">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_LAUNCH_IN_CONTENT_AREA"/>
                </xsl:when>
                <xsl:when test="$tempLaunchInNewWindow=$COMMON_FOR_PORTAL.CONTENT.SHOW_TYPE.IN_OWN_WINDOW">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_LAUNCH_IN_SEPARATE_WINDOW"/>
                </xsl:when>
                <xsl:when test="$tempLaunchInNewWindow=$COMMON_FOR_PORTAL.CONTENT.SHOW_TYPE.IN_NEW_PORTAL_WINDOW">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_LAUNCH_IN_SEPARATE_PORTAL_WINDOW"/>
                </xsl:when>
                <xsl:when test="$tempLaunchInNewWindow=$COMMON_FOR_PORTAL.CONTENT.SHOW_TYPE.IN_NEW_PORTAL_WINDOW_WO_HEAD">
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_LAUNCH_IN_SEPARATE_HEADERL_PORTAL_WIN"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_TYPE.AVT_SAP_LAUNCH_IN_CONTENT_AREA"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:call-template name="common_for_aris.printAttrElement">
            <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_LAUNCH_IN_NEW_WINDOW" />
            <xsl:with-param name="varAttrValue" select="$tempLaunchInNewWindowValue" />
            <xsl:with-param name="varLocale" select="$varArisLocale" />
        </xsl:call-template>
        
        <xsl:choose>
            <xsl:when test="$tempIsiView='true'">
                <xsl:variable name="tempObjDefId">
                    <xsl:call-template name="determineObjDefID">
                        <xsl:with-param name="varCurrentNode" select="$varCurrentNode" />
                    </xsl:call-template>
                </xsl:variable>
                
                <xsl:variable name="tempIsTransactioniView">
                    <xsl:call-template name="common_for_check.isTransactioniView">
                        <xsl:with-param name="varTemplate" select="/descendant::*/Context[@arisPortalNamespace=$tempObjDefId]/@template" />
                    </xsl:call-template>
                </xsl:variable>
                <xsl:variable name="tempIsURLiView">
                    <xsl:call-template name="common_for_check.isURLiView">
                        <xsl:with-param name="varTemplate" select="/descendant::*/Context[@arisPortalNamespace=$tempObjDefId]/@template" />
                    </xsl:call-template>
                </xsl:variable>
                <xsl:variable name="tempIsBSPiView">
                    <xsl:call-template name="common_for_check.isBSPiView">
                        <xsl:with-param name="varTemplate" select="/descendant::*/Context[@arisPortalNamespace=$tempObjDefId]/@template" />
                    </xsl:call-template>
                </xsl:variable>
                <xsl:variable name="tempIsIACiView">
                    <xsl:call-template name="common_for_check.isIACiView">
                        <xsl:with-param name="varTemplate" select="/descendant::*/Context[@arisPortalNamespace=$tempObjDefId]/@template" />
                    </xsl:call-template>
                </xsl:variable>
                <xsl:variable name="tempIsWebDynproiView">
                    <xsl:call-template name="common_for_check.isWebDynproiView">
                        <xsl:with-param name="varTemplate" select="/descendant::*/Context[@arisPortalNamespace=$tempObjDefId]/@template" />
                    </xsl:call-template>
                </xsl:variable>
                
                <!-- AT_SAP_SYSTEM -->
                <xsl:variable name="tempSystemUnresolved">
                    <xsl:call-template name="determineAttrInLocale">
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.SYSTEM"/>
                        <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                        <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                    </xsl:call-template>   
                </xsl:variable>
                <xsl:variable name="tempSystem">
                    <xsl:call-template name="determineAttrInLocale">
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.SYSTEM"/>
                        <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                        <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                    </xsl:call-template>   
                </xsl:variable>
                <xsl:if test="$tempSystemUnresolved!='' and $tempSystemUnresolved!=$tempSystem">
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_SYSTEM" />
                        <xsl:with-param name="varAttrValue" select="$tempSystem" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                </xsl:if>
                <!-- AT_SAP_APPL_PARAM -->
                <xsl:variable name="tempApplicationParameterUnresolved">
                    <xsl:call-template name="determineAttrInLocale">
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.APPLICATION_PARAMETER"/>
                        <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                        <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                    </xsl:call-template>   
                </xsl:variable>
                <xsl:variable name="tempApplicationParameter">
                    <xsl:call-template name="determineAttrInLocale">
                        <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.APPLICATION_PARAMETER"/>
                        <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                        <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                    </xsl:call-template>   
                </xsl:variable>
                <xsl:if test="$tempApplicationParameterUnresolved!='' and $tempApplicationParameterUnresolved!=$tempApplicationParameter">
                    <xsl:call-template name="common_for_aris.printAttrElement">
                        <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_APPL_PARAM" />
                        <xsl:with-param name="varAttrValue" select="$tempApplicationParameter" />
                        <xsl:with-param name="varLocale" select="$varArisLocale" />
                    </xsl:call-template>
                </xsl:if>
                
                <xsl:choose>
                    <xsl:when test="$tempIsIACiView='true'">
                        <!-- IAC -->
                        <!-- AT_SAP_IAC -->
                        <xsl:variable name="tempIACUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.IAC"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempIAC">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.IAC"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempIACUnresolved!='' and $tempIACUnresolved!=$tempIAC">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_IAC" />
                                <xsl:with-param name="varAttrValue" select="$tempIAC" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:when>
                    <xsl:when test="$tempIsTransactioniView='true'">
                        <!-- TRANS_CODE -->
                        <!-- AT_TRANS_CODE -->
                        <xsl:variable name="tempTCodeUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.TCODE"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempTCode">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.TCODE"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempTCodeUnresolved!='' and $tempTCodeUnresolved!=$tempTCode">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_TRANS_CODE" />
                                <xsl:with-param name="varAttrValue" select="$tempTCode" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:when>
                    <xsl:when test="$tempIsBSPiView='true'">
                        <!-- BSP -->
                        <!-- AT_SAP_APPL_NAMESPACE -->
                        <xsl:variable name="tempApplicationNamespaceUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.NAMESPACE"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempApplicationNamespace">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.NAMESPACE"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempApplicationNamespaceUnresolved!='' and $tempApplicationNamespaceUnresolved!=$tempApplicationNamespace">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_APPL_NAMESPACE" />
                                <xsl:with-param name="varAttrValue" select="$tempApplicationNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                        <!-- AT_SAP_CUSTOMER_NAMESPACE -->
                        <xsl:variable name="tempCustomerNamespaceUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.CUSTOMER_NAMESPACE"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempCustomerNamespace">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.CUSTOMER_NAMESPACE"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempCustomerNamespaceUnresolved!='' and $tempCustomerNamespaceUnresolved!=$tempCustomerNamespace">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_CUSTOMER_NAMESPACE" />
                                <xsl:with-param name="varAttrValue" select="$tempCustomerNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                        <!-- AT_SAP_BSP_START_PAGE -->
                        <xsl:variable name="tempStartPageUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.PAGE_ID"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempStartPage">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.PAGE_ID"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempStartPageUnresolved!='' and $tempStartPageUnresolved!=$tempStartPage">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_BSP_START_PAGE" />
                                <xsl:with-param name="varAttrValue" select="$tempStartPage" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:when>
                    <xsl:when test="$tempIsWebDynproiView='true'">
                        <!-- WebDynpro -->
                        <!-- AT_SAP_APPL_NAME -->
                        <xsl:variable name="tempWebDynproAppUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_APPLICATION"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempWebDynproApp">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_APPLICATION"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempWebDynproAppUnresolved!='' and $tempWebDynproAppUnresolved!=$tempWebDynproApp">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_APPL_NAME" />
                                <xsl:with-param name="varAttrValue" select="$tempWebDynproApp" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                        <!-- AT_SAP_NAMESPACE -->
                        <xsl:variable name="tempWebDynproNamespaceUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_NAMESPACE"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempWebDynproNamespace">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_NAMESPACE"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempWebDynproNamespaceUnresolved!='' and $tempWebDynproNamespaceUnresolved!=$tempWebDynproNamespace">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_SAP_NAMESPACE" />
                                <xsl:with-param name="varAttrValue" select="$tempWebDynproNamespace" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:when>
                    <xsl:when test="$tempIsURLiView='true'">
                        <!-- URL -->
                        <!-- AT_EXT_1 -->
                        <xsl:variable name="tempURLUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.URL"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempURL">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.URL"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempURLUnresolved!='' and $tempURLUnresolved!=$tempURL">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_EXT_1" />
                                <xsl:with-param name="varAttrValue" select="$tempURL" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                        <!-- AT_PARM_1 -->
                        <xsl:variable name="tempURLParamUnresolved">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.URL_PARAM"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="false()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:variable name="tempURLParam">
                            <xsl:call-template name="determineAttrInLocale">
                                <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_PORTAL.CONTENT.URL_PARAM"/>
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
                                <xsl:with-param name="varResolveDeltaLinkIfRequired" select="true()" />
                            </xsl:call-template>   
                        </xsl:variable>
                        <xsl:if test="$tempURLParamUnresolved!='' and $tempURLParamUnresolved!=$tempURLParam">
                            <xsl:call-template name="common_for_aris.printAttrElement">
                                <xsl:with-param name="varAttrName" select="$COMMON_FOR_ARIS.ATTR.AT_PARM_1" />
                                <xsl:with-param name="varAttrValue" select="$tempURLParam" />
                                <xsl:with-param name="varLocale" select="$varArisLocale" />
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:when>
                </xsl:choose>
                
            </xsl:when>
        </xsl:choose>
        
    </xsl:template>
    
    <!-- 
        Description:
        this template creates a ObjOcc-XML Element.
    -->
    <xsl:template name="printObjOcc">
        <xsl:param name="varSymbol"/>
        <xsl:param name="varCurrentNode"/>
        <xsl:param name="varWithContentInContentSuffix"/>
        <xsl:param name="varWithCxnContentToButton" />
        <xsl:param name="varWithCxnButtonToContent" />
        
        <xsl:variable name="tempParentIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:variable name="tempResolvedObjDefID">
            <xsl:call-template name="determineObjDefID">
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
            </xsl:call-template>
        </xsl:variable>

        <!-- ObjOcc XML-Element -->
        <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.OBJOCC}">
            <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJOCC.OBJOCC_ID}">
                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJOCC.OBJOCC_PREFIX"/>
                <xsl:value-of select="$DOT"/>
                <xsl:call-template name="normalizeValue">
                    <xsl:with-param name="varCurrentValue"
                        select="$varCurrentNode/@arisPortalNamespace"/>
                </xsl:call-template>
                <xsl:if test="$varWithContentInContentSuffix='true'">
                    <xsl:value-of select="$DOT"/>
                    <xsl:value-of select="$CONTENT_IN_CONTENT_SUFFIX"/>
                </xsl:if>
            </xsl:attribute>
            <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJOCC.OBJDEF_ID_REF}">
                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                <xsl:value-of select="$DOT"/>
                <xsl:call-template name="normalizeValue">
                    <xsl:with-param name="varCurrentValue" select="$tempResolvedObjDefID"/>
                </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJOCC.SYMBOLNUM}">
                <xsl:value-of select="$varSymbol"/>
            </xsl:attribute>
            
            <xsl:if test="$varWithCxnContentToButton='true'">
                <xsl:for-each select="$varCurrentNode/child::Context">
                    <xsl:variable name="tempIsRole">
                        <xsl:call-template name="common_for_check.isRole">
                            <xsl:with-param name="varObjectClass" select="@objectClass"/>
                        </xsl:call-template>
                    </xsl:variable>
                    
                    <xsl:choose>
                        <xsl:when test="not($tempParentIsRole='true' and $tempIsRole='true')">
                            <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.CXNOCC}">
                                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.CXNOCC_ID}">
                                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNOCC.CXNOCC_PREFIX"/>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:call-template name="normalizeValue">
                                        <xsl:with-param name="varCurrentValue" select="$varCurrentNode/@arisPortalNamespace"/>
                                    </xsl:call-template>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:value-of select="$FROM_CONTENT_TO_BUTTON"/>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:value-of select="position()"/>
                                </xsl:attribute>
                                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.CXNDEF_ID_REF}">
                                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNDEF.CXNDEF_PREFIX"/>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:call-template name="normalizeValue">
                                        <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                                    </xsl:call-template>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:value-of select="$FROM_CONTENT_TO_BUTTON"/>
                                </xsl:attribute>
                                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.TO_OBJOCC_ID_REF}">
                                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJOCC.OBJOCC_PREFIX"/>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:call-template name="normalizeValue">
                                        <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                                    </xsl:call-template>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:value-of select="$BUTTON_SUFFIX"/>
                                </xsl:attribute>
                            </xsl:element>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.CXNOCC}">
                                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.CXNOCC_ID}">
                                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNOCC.CXNOCC_PREFIX"/>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:call-template name="normalizeValue">
                                        <xsl:with-param name="varCurrentValue" select="$varCurrentNode/@arisPortalNamespace"/>
                                    </xsl:call-template>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:value-of select="$FROM_CONTENT_TO_CONTENT"/>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:value-of select="position()"/>
                                </xsl:attribute>
                                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.CXNDEF_ID_REF}">
                                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNDEF.CXNDEF_PREFIX"/>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:call-template name="normalizeValue">
                                        <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                                    </xsl:call-template>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:value-of select="$FROM_CONTENT_TO_CONTENT"/>
                                </xsl:attribute>
                                <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.TO_OBJOCC_ID_REF}">
                                    <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJOCC.OBJOCC_PREFIX"/>
                                    <xsl:value-of select="$DOT"/>
                                    <xsl:call-template name="normalizeValue">
                                        <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                                    </xsl:call-template>
                                </xsl:attribute>
                            </xsl:element>
                        </xsl:otherwise>
                    </xsl:choose>
                    
                </xsl:for-each>
            </xsl:if>
                
            <!-- AttrOcc -->
            <xsl:call-template name="common_for_aris.printAttrOcc"/>
        </xsl:element>
        
        <!-- ObjOcc for Button and CxnDef -->
        <xsl:if test="$varWithCxnButtonToContent='true'">
            <xsl:variable name="tempIsRole">
                <xsl:call-template name="common_for_check.isRole">
                    <xsl:with-param name="varObjectClass" select="$varCurrentNode/parent::node()/@objectClass"/>
                </xsl:call-template>
            </xsl:variable>
            
            <xsl:choose>
                <xsl:when test="not($tempIsRole='true' and $tempParentIsRole='true')">
                    <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.OBJOCC}">
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJOCC.OBJOCC_ID}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJOCC.OBJOCC_PREFIX"/>
                            <xsl:value-of select="$DOT"/>
                            <xsl:call-template name="normalizeValue">
                                <xsl:with-param name="varCurrentValue"
                                    select="$varCurrentNode/@arisPortalNamespace"/>
                            </xsl:call-template>
                            <xsl:value-of select="$DOT"/>
                            <xsl:value-of select="$BUTTON_SUFFIX"/>
                        </xsl:attribute>
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJOCC.OBJDEF_ID_REF}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJDEF.OBJDEF_PREFIX"/>
                            <xsl:value-of select="$DOT"/>
                            <xsl:call-template name="normalizeValue">
                                <xsl:with-param name="varCurrentValue" select="$varCurrentNode/@arisPortalNamespace"/>
                            </xsl:call-template>
                            <xsl:value-of select="$DOT"/>
                            <xsl:value-of select="$BUTTON_SUFFIX"/>
                        </xsl:attribute>
                        <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.OBJOCC.SYMBOLNUM}">
                            <xsl:value-of select="$COMMON_FOR_ARIS.ST_TYPE.FOR_BUTTON"/>
                        </xsl:attribute>
                        
                        <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.CXNOCC}">
                            <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.CXNOCC_ID}">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNOCC.CXNOCC_PREFIX"/>
                                <xsl:value-of select="$DOT"/>
                                <xsl:call-template name="normalizeValue">
                                    <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                                </xsl:call-template>
                                <xsl:value-of select="$DOT"/>
                                <xsl:value-of select="$FROM_BUTTON_TO_CONTENT"/>
                            </xsl:attribute>
                            <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.CXNDEF_ID_REF}">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.CXNDEF.CXNDEF_PREFIX"/>
                                <xsl:value-of select="$DOT"/>
                                <xsl:call-template name="normalizeValue">
                                    <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                                </xsl:call-template>
                                <xsl:value-of select="$DOT"/>
                                <xsl:value-of select="$FROM_BUTTON_TO_CONTENT"/>
                            </xsl:attribute>
                            <xsl:attribute name="{$COMMON_FOR_ARIS.ATTR_NAME.CXNOCC.TO_OBJOCC_ID_REF}">
                                <xsl:value-of select="$COMMON_FOR_ARIS.ATTR_VALUE.OBJOCC.OBJOCC_PREFIX"/>
                                <xsl:value-of select="$DOT"/>
                                <xsl:call-template name="normalizeValue">
                                    <xsl:with-param name="varCurrentValue" select="@arisPortalNamespace"/>
                                </xsl:call-template>
                            </xsl:attribute>
                        </xsl:element>
                        <xsl:call-template name="common_for_aris.printAttrOcc"/>
                    </xsl:element>            
                </xsl:when>
            </xsl:choose>
        </xsl:if>
        
    </xsl:template>

    <!--
        Description:
        this template resolves the ID of a "ObjDef". content which is embedded (as delta link) in other content is created as ObjOcc. The attribute arisPortalNamespace cannot be used as
        ObjDef-OID as such a ID does not exist.
    -->
    <xsl:template name="determineObjDefID">
        <xsl:param name="varCurrentNode"/>

        <xsl:variable name="tempNextArisPortalNamespace">
            <xsl:call-template name="determineNextObjDefID">
                <xsl:with-param name="varCurrentNode" select="$varCurrentNode"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="$tempNextArisPortalNamespace=$varCurrentNode/@arisPortalNamespace">
                <xsl:value-of select="$varCurrentNode/@arisPortalNamespace"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="determineObjDefID">
                    <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=$tempNextArisPortalNamespace]"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:template>
    
    <xsl:template name="determineNextObjDefID">
        <xsl:param name="varCurrentNode"/>
        
        <xsl:variable name="tempIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsPage">
            <xsl:call-template name="common_for_check.isPage">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsiView">
            <xsl:call-template name="common_for_check.isiView">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWorkset">
            <xsl:call-template name="common_for_check.isWorkset">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="$tempIsRole='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:value-of select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]/@arisPortalNamespace" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$varCurrentNode/@arisPortalNamespace"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsWorkset='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:value-of select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]/@arisPortalNamespace" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$varCurrentNode/@arisPortalNamespace"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsPage='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:variable name="tempIsSapPage">
                            <xsl:call-template name="common_for_check.isTemplatePage">
                                <xsl:with-param name="varTemplate"
                                    select="$varCurrentNode/@template"/>
                            </xsl:call-template>
                        </xsl:variable>
                        
                        <xsl:choose>
                            <xsl:when test="$tempIsSapPage='true'">
                                <xsl:value-of select="$varCurrentNode/@arisPortalNamespace"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:if test="count(/descendant::*/Context[@arisPortalNamespace=string($varCurrentNode/@arisTemplate)])=1">
                                    <xsl:value-of select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]/@arisPortalNamespace" />
                                </xsl:if>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsiView='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:variable name="tempIsSapiView">
                            <xsl:call-template name="common_for_check.isTemplateiView">
                                <xsl:with-param name="varTemplate"
                                    select="$varCurrentNode/@template"/>
                            </xsl:call-template>
                        </xsl:variable>
                        
                        <xsl:choose>
                            <xsl:when test="$tempIsSapiView='true'">
                                <xsl:value-of select="$varCurrentNode/@arisPortalNamespace"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:if test="count(/descendant::*/Context[@arisPortalNamespace=string($varCurrentNode/@arisTemplate)])=1">
                                    <xsl:value-of select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]/@arisPortalNamespace" />
                                </xsl:if>                                
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                </xsl:choose>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
        
     <xsl:template name="addTemplateGuidIfRequired">
         <xsl:choose>
             <xsl:when test="$TemplateGUID and not($TemplateGUID='00000000-0000-0000-0000-000000000000')">
                 <xsl:element name="{$COMMON_FOR_ARIS.ELEMENT.TEMPLATE_GUID}">
                     <xsl:value-of select="$TemplateGUID"/>
                 </xsl:element>
             </xsl:when>
         </xsl:choose>
     </xsl:template>

    <!--
        Description:
        for content which is embedded (as delta link) in other content Portal-ID consists of the "name" and the arisPortalNamespace of the
        parent group
    -->
    <!--
    <xsl:template name="determineARISIdOfNextParentGroup">
        <xsl:param name="varCurrentNode"/>

        <xsl:variable name="tempIsGroup">
            <xsl:call-template name="common_for_check.isGroup">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:choose>
            <xsl:when test="$tempIsGroup='true'">
                <xsl:value-of select="$varCurrentNode/@arisPortalNamespace"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test="count($varCurrentNode/parent::node())>0">
                    <xsl:call-template name="determineARISIdOfNextParentGroup">
                        <xsl:with-param name="varCurrentNode"
                            select="$varCurrentNode/parent::node()"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>
    -->
    
    <!--
        Description:
        this template determines if content is embedded (not as delta-link) in other content.
    -->
    <xsl:template name="determineIsContentInContent">
        <xsl:param name="varCurrentNode"/>

        <xsl:choose>
            <xsl:when test="$varCurrentNode/@create_as='0'">
                <xsl:value-of select="true()"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="tempIsSapPage">
                    <xsl:call-template name="common_for_check.isTemplatePage">
                        <xsl:with-param name="varTemplate" select="$varCurrentNode/@template"/>
                    </xsl:call-template>
                </xsl:variable>
                <xsl:variable name="tempIsSapiView">
                    <xsl:call-template name="common_for_check.isTemplateiView">
                        <xsl:with-param name="varTemplate" select="$varCurrentNode/@template"/>
                    </xsl:call-template>
                </xsl:variable>

                <xsl:variable name="tempIsContentInContent">
                    <xsl:if test="$tempIsSapPage='true' or $tempIsSapiView='true'">
                        <xsl:value-of select="true()"/>
                    </xsl:if>
                </xsl:variable>

                <xsl:choose>
                    <xsl:when test="$tempIsContentInContent='true'">
                        <xsl:value-of select="true()"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="count($varCurrentNode/child::Context)>0">
                            <xsl:call-template name="determineIsContentInContent">
                                <xsl:with-param name="varCurrentNode"
                                    select="$varCurrentNode/child::Context"/>
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>

            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>


    <!-- 
        Description:
        normalizes the given string for attribute XML-IDs
    -->
    <xsl:template name="normalizeValue">
        <xsl:param name="varCurrentValue"/>

        <xsl:value-of select="translate(translate($varCurrentValue, '/' , '_'), ':', '_' )"/>
    </xsl:template>

    <!--
        Description:
        determines the value of attribute in consideration of the locale Id. If the value in the locale id is empty the default
        value (default locale) will be returned.
    -->
    <xsl:template name="determineAttrInLocale">
        <xsl:param name="varPortalLocale"/>
        <xsl:param name="varAttrName"/>
        <xsl:param name="varCurrentNode"/>
        <xsl:param name="varResolveDeltaLinkIfRequired" />
        
        <xsl:variable name="tempResult">
            <xsl:for-each
                select="$varCurrentNode/Attributes/descendant-or-self::*/Attribute[@name=$varAttrName]/AttributeValue">
                <xsl:choose>
                    <xsl:when test="@locale=$varPortalLocale">
                        <xsl:value-of select="@value"/>
                    </xsl:when>
                </xsl:choose>
            </xsl:for-each>
        </xsl:variable>

        <xsl:variable name="tempResultDefault">
            <xsl:for-each
                select="$varCurrentNode/Attributes/descendant-or-self::*/Attribute[@name=$varAttrName]/AttributeValue">
                <xsl:choose>
                    <xsl:when test="@locale=$COMMON_FOR_PORTAL.LANGUAGE.DEFAULT">
                        <xsl:value-of select="@value"/>
                    </xsl:when>
                </xsl:choose>
            </xsl:for-each>
        </xsl:variable>

        <xsl:variable name="tempFallback">
            <xsl:if test="count($varCurrentNode/Attributes/descendant-or-self::*/Attribute[@name=$varAttrName]/AttributeValue)=1">
                <xsl:value-of select="$varCurrentNode/Attributes/descendant-or-self::*/Attribute[@name=$varAttrName]/AttributeValue/@value"/>
            </xsl:if>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="string-length(string($tempResult))>0">
                <xsl:value-of select="$tempResult"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="string-length($tempResultDefault)=0 and $varResolveDeltaLinkIfRequired='true'">
                        <xsl:variable name="tempNextObjDefId">
                            <xsl:call-template name="determineNextObjDefID">
                                <xsl:with-param name="varCurrentNode" select="$varCurrentNode" />
                            </xsl:call-template>
                        </xsl:variable>
                        
                        <xsl:choose>
                            <xsl:when test="$varCurrentNode/@arisPortalNamespace=$tempNextObjDefId">
                                <xsl:choose>
                                    <xsl:when test="string-length($tempResultDefault)=0 and string-length($tempFallback)>0">
                                        <xsl:value-of select="$tempFallback"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="$tempResultDefault"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:call-template name="determineAttrInLocale">
                                    <xsl:with-param name="varPortalLocale" select="$varPortalLocale"/>
                                    <xsl:with-param name="varAttrName" select="$varAttrName"/>
                                    <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=$tempNextObjDefId]"/>
                                    <xsl:with-param name="varResolveDeltaLinkIfRequired" select="$varResolveDeltaLinkIfRequired" />
                                </xsl:call-template>
                            </xsl:otherwise>
                        </xsl:choose>
                        
                    </xsl:when>
                    <xsl:when test="string-length($tempResultDefault)=0 and string-length($tempFallback)>0">
                        <xsl:value-of select="$tempFallback"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$tempResultDefault"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>

    <!--
        Description:
        maps the specified (or default) locale Id to the portal locale id
    -->
    <xsl:template name="mapLocaleIdToPortalLocale">
        <xsl:param name="varArisLocale"/>

        <xsl:choose>
            <xsl:when test="$COMMON_FOR_ARIS.LOCALE.DE=$varArisLocale">
                <xsl:value-of select="$COMMON_FOR_PORTAL.LANGUAGE.DE"/>
            </xsl:when>
            <xsl:when test="$COMMON_FOR_ARIS.LOCALE.EN=$varArisLocale">
                <xsl:value-of select="$COMMON_FOR_PORTAL.LANGUAGE.EN"/>
            </xsl:when>
            <xsl:when test="$COMMON_FOR_ARIS.LOCALE.FR=$varArisLocale">
                <xsl:value-of select="$COMMON_FOR_PORTAL.LANGUAGE.FR"/>
            </xsl:when>
            <xsl:when test="$COMMON_FOR_ARIS.LOCALE.ES=$varArisLocale">
                <xsl:value-of select="$COMMON_FOR_PORTAL.LANGUAGE.ES"/>
            </xsl:when>
            <xsl:when test="$COMMON_FOR_ARIS.LOCALE.JA=$varArisLocale">
                <xsl:value-of select="$COMMON_FOR_PORTAL.LANGUAGE.JA"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$COMMON_FOR_PORTAL.LANGUAGE.DEFAULT"/>
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>

    <!--
        Description:
        returns the defined Locale Id. If no Locale Id was specified the default ARIS Locale Id will be used.
    -->
    <xsl:template name="determineLocaleID">
        <xsl:choose>
            <xsl:when test="$LocaleID">
                <xsl:value-of select="$LocaleID"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$COMMON_FOR_ARIS.LOCALE.DEFAULT"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!--
        Description:
        returns the defined code page. If no code page was specified the default ARIS Codepage will be used.
    -->
    <xsl:template name="determineCodePage">
        <xsl:choose>
            <xsl:when test="CodePage">
                <xsl:value-of select="$CodePage"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$COMMON_FOR_ARIS.CODEPAGE.DEFAULT"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>
