<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Author:
    TPLA / IDS Scheer
    
    Description:
    this stylesheet offers templates which should be used to determine their identity.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

    <xsl:variable name="COMMON_FOR_CHECK.OBJECT.IVIEW" select="'com.sapportals.portal.iview'" />
    <xsl:variable name="COMMON_FOR_CHECK.OBJECT.ROLE" select="'com.sapportals.portal.role'" />
    <xsl:variable name="COMMON_FOR_CHECK.OBJECT.WORKSET" select="'com.sapportals.portal.workset'" />
    <xsl:variable name="COMMON_FOR_CHECK.OBJECT.PAGE" select="'com.sapportals.portal.page'" />
    <xsl:variable name="COMMON_FOR_CHECK.OBJECT.GROUP" select="'com.sap.portal.pcd.gl.GlContext'" />
    
    <xsl:variable name="COMMON_FOR_CHECK.SAP_TEMPLATE.PAGE" select="'pcd:portal_content/templates/pages/portalpagetemplate'"/>
    
    <xsl:variable name="COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.URL" select="'pcd:portal_content/templates/iviews/urliview'" />
    <xsl:variable name="COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.TRANSACTION" select="'pcd:portal_content/templates/iviews/sap_transaction_iview'" />
    <xsl:variable name="COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.WEB_DYNPRO" select="'pcd:portal_content/templates/iviews/sap_webdynpro_iview'" />
    <xsl:variable name="COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.IAC" select="'pcd:portal_content/templates/iviews/sap_iac_iview'" />
    <xsl:variable name="COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.BSP" select="'pcd:portal_content/templates/iviews/sap_bsp_iview'" />
    
    
    <!--
        Description:
        checks if the object class is supported.
        Parameter:
        - varObjectClass is the object class of a xml element
    -->
    <xsl:template name="common_for_check.isSupportedObjectClass">
        <xsl:param name="varObjectClass" />
        
        <xsl:choose>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.IVIEW">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.ROLE">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.WORKSET">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.PAGE">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.GROUP">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a role.
        Parameter:
        - varObjectClass is the object class of a xml element
    -->
    <xsl:template name="common_for_check.isRole">
        <xsl:param name="varObjectClass" />
        
        <xsl:choose>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.ROLE">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a workset.
        Parameter:
        - varObjectClass is the object class of a xml element
    -->
    <xsl:template name="common_for_check.isWorkset">
        <xsl:param name="varObjectClass" />
        
        <xsl:choose>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.WORKSET">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a page.
        Parameter:
        - varObjectClass is the object class of a xml element
    -->
    <xsl:template name="common_for_check.isPage">
        <xsl:param name="varObjectClass" />
        
        <xsl:choose>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.PAGE">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a SAP-templated page.
        Parameter:
        - varTemplate is the template value of a xml element
    -->
    <xsl:template name="common_for_check.isTemplatePage">
        <xsl:param name="varTemplate" />
        
        <xsl:choose>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.PAGE">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    
    <!--
        Description:
        checks if the object class is a group.
        Parameter:
        - varObjectClass is the object class of a xml element
    -->
    <xsl:template name="common_for_check.isGroup">
        <xsl:param name="varObjectClass" />
        
        <xsl:choose>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.GROUP">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is an iView.
        Parameter:
        - varObjectClass is the object class of a xml element
    -->
    <xsl:template name="common_for_check.isiView">
        <xsl:param name="varObjectClass" />
        
        <xsl:choose>
            <xsl:when test="$varObjectClass=$COMMON_FOR_CHECK.OBJECT.IVIEW">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a SAP-templated iView.
        Parameter:
        - varTemplate is the template value of a xml element
    -->
    <xsl:template name="common_for_check.isTemplateiView">
        <xsl:param name="varTemplate" />
        
        <xsl:choose>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.URL">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.TRANSACTION">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.WEB_DYNPRO">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.IAC">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.BSP">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a SAP-Transaction iView:
        Parameter:
        - varTemplate is the template value of a xml element
    -->
    <xsl:template name="common_for_check.isTransactioniView">
        <xsl:param name="varTemplate" />
        
        <xsl:choose>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.TRANSACTION">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a URL iView:
        Parameter:
        - varTemplate is the template value of a xml element
    -->
    <xsl:template name="common_for_check.isURLiView">
        <xsl:param name="varTemplate" />
        
        <xsl:choose>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.URL">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a Web Dynpro iView:
        Parameter:
        - varTemplate is the template value of a xml element
    -->
    <xsl:template name="common_for_check.isWebDynproiView">
        <xsl:param name="varTemplate" />
        
        <xsl:choose>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.WEB_DYNPRO">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a IAC iView:
        Parameter:
        - varTemplate is the template value of a xml element
    -->
    <xsl:template name="common_for_check.isIACiView">
        <xsl:param name="varTemplate" />
        
        <xsl:choose>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.IAC">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    <!--
        Description:
        checks if the object class is a BSP iView:
        Parameter:
        - varTemplate is the template value of a xml element
    -->
    <xsl:template name="common_for_check.isBSPiView">
        <xsl:param name="varTemplate" />
        
        <xsl:choose>
            <xsl:when test="$varTemplate=$COMMON_FOR_CHECK.SAP_TEMPLATE.IVIEW.BSP">
                <xsl:value-of select="true()" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()" />
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    <!-- 
        Description:
        this template determines if the given node is a real object (not a delta-link)
    -->
    <xsl:template name="common_for_check.isNotADeltaLink">
        <xsl:param name="varCurrentNode"/>
        
        <xsl:variable name="tempIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWorkset">
            <xsl:call-template name="common_for_check.isWorkset">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsTemplateiView">
            <xsl:call-template name="common_for_check.isTemplateiView">
                <xsl:with-param name="varTemplate" select="$varCurrentNode/@template"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsTemplatePage">
            <xsl:call-template name="common_for_check.isTemplatePage">
                <xsl:with-param name="varTemplate" select="$varCurrentNode/@template"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="$tempIsRole='true' and $varCurrentNode/@create_as='0'">
                <xsl:value-of select="true()"/>
            </xsl:when>
            <xsl:when test="$tempIsWorkset='true' and $varCurrentNode/@create_as='0'">
                <xsl:value-of select="true()"/>
            </xsl:when>
            <xsl:when test="$tempIsTemplatePage='true'">
                <xsl:value-of select="true()"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()"/>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:template>
    

</xsl:stylesheet>
