<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Author:
    TPLA / IDS Scheer
    
    Description:
    this stylesheet is the counterpart to filter_with_messages.xsl and generates a xml file.
    
    this stylesheet filters elements which are not supported. Delta-Links on not supported elements are filtered out.
    the result is a xml-file where not supported elements are filtered out.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output encoding="ISO-8859-1"
    method="xml"/>
    
    <xsl:include href="common_for_check.xsl"/>
    
    <!--
        Description:
        handles the root-XML Element. all attributes are reused. Child-Elements which are no Context-Elements will be copied. Otherwise the element has to
        be processed recursively (adding arisTemplate if necessary; adding arisPortalNamespace).
    -->
    <xsl:template match="GenericCreator">
        <xsl:element name="{name()}">
            <xsl:for-each select="attribute::*">
                <xsl:attribute name="{name()}"><xsl:value-of select="current()"/></xsl:attribute>
            </xsl:for-each>
            
            <xsl:for-each select="child::*">
            <xsl:choose>
                <xsl:when test="name()='Context'">
                    <xsl:apply-templates select="self::node()"></xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:copy-of select="self::node()" />
                </xsl:otherwise>
            </xsl:choose>
            </xsl:for-each>
        </xsl:element>
    </xsl:template>
    
    <!--
        Description:
        handles Context-XML Elements. all attributes are reused. If the element is supported the element will be added to the result.
        child-context elements are handled by calling this stylesheet again. child-elements which are not context-elements will be copied
        to the result
    -->
    <xsl:template match="Context">
        <xsl:variable name="tempIsSupportedObjectClass">
            <xsl:call-template name="common_for_check.isSupportedObjectClass">
                <xsl:with-param name="varObjectClass" select="@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
                <xsl:when test="$tempIsSupportedObjectClass='false'">
                    <!-- is handled in filter_with_messages.xsl -->
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="tempIsGroup">
                        <xsl:call-template name="common_for_check.isGroup">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsRole">
                        <xsl:call-template name="common_for_check.isRole">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsPage">
                        <xsl:call-template name="common_for_check.isPage">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsiView">
                        <xsl:call-template name="common_for_check.isiView">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsWorkset">
                        <xsl:call-template name="common_for_check.isWorkset">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsTemplateiView">
                        <xsl:call-template name="common_for_check.isTemplateiView">
                            <xsl:with-param name="varTemplate" select="@template" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsTemplatePage">
                        <xsl:call-template name="common_for_check.isTemplatePage">
                            <xsl:with-param name="varTemplate" select="@template" />
                        </xsl:call-template>
                    </xsl:variable>
                    
                    <xsl:variable name="tempGoOn">
                        <xsl:choose>
                            <xsl:when test="$tempIsGroup='true'">
                                <xsl:value-of select="true()" />
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:choose>
                                    <xsl:when test="@template">
                                        <xsl:call-template name="isTargetSupported">
                                            <xsl:with-param name="varCurrentNode" select="self::node()" />
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:choose>
                                            <xsl:when test="$tempIsRole='true'">
                                                <xsl:value-of select="true()" />
                                            </xsl:when>
                                            <xsl:when test="$tempIsWorkset='true'">
                                                <xsl:value-of select="true()" />
                                            </xsl:when>
                                            <xsl:when test="$tempIsPage='true'">
                                                <xsl:value-of select="false()" />
                                            </xsl:when>
                                            <xsl:when test="$tempIsiView='true'">
                                                <xsl:value-of select="false()" />
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="false()" />
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                            </xsl:otherwise>
                        </xsl:choose>
                        
                    </xsl:variable>
                    
                    <xsl:choose>
                        <xsl:when test="$tempGoOn='true'">
                            <xsl:element name="{name()}">
                                <xsl:for-each select="attribute::*">
                                    <xsl:attribute name="{name()}"><xsl:value-of select="current()"/></xsl:attribute>
                                </xsl:for-each>
        
                                <xsl:for-each select="child::*">
                                    <xsl:choose>
                                        <xsl:when test="name()='Context'">
                                            <xsl:apply-templates select="self::node()"></xsl:apply-templates>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:copy-of select="self::node()" />
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:for-each>
                            </xsl:element>   
                        </xsl:when>
                    </xsl:choose>
                </xsl:otherwise>
                
        </xsl:choose>
    </xsl:template>

    <!--
        Description:
        checks recursively if an element is supported. if an element has a template-attribute which is not a SAP-template
        the check is done on the referenced element
    -->
    <xsl:template name="isTargetSupported">
        <xsl:param name="varCurrentNode" />
        
        <xsl:variable name="tempIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsPage">
            <xsl:call-template name="common_for_check.isPage">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsiView">
            <xsl:call-template name="common_for_check.isiView">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWorkset">
            <xsl:call-template name="common_for_check.isWorkset">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="$tempIsRole='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:call-template name="isTargetSupported">
                            <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]" />
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="true()"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsWorkset='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:call-template name="isTargetSupported">
                            <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]" />
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="true()"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsPage='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:variable name="tempIsSapPage">
                            <xsl:call-template name="common_for_check.isTemplatePage">
                                <xsl:with-param name="varTemplate" select="$varCurrentNode/@template" />
                            </xsl:call-template>
                        </xsl:variable>
                        
                        <xsl:choose>
                            <xsl:when test="$tempIsSapPage='true'">
                                <xsl:value-of select="true()"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:variable name="tempCount" select="count(/descendant::*/Context[@arisPortalNamespace=string($varCurrentNode/@arisTemplate)])" />
                                
                                <xsl:choose>
                                    <xsl:when test="$tempCount=0">
                                        <xsl:value-of select="false()"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="isTargetSupported">
                                            <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]" />
                                        </xsl:call-template>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="false()"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsiView='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:variable name="tempIsSapiView">
                            <xsl:call-template name="common_for_check.isTemplateiView">
                                <xsl:with-param name="varTemplate" select="$varCurrentNode/@template" />
                            </xsl:call-template>
                        </xsl:variable>
                        
                        <xsl:choose>
                            <xsl:when test="$tempIsSapiView='true'">
                                <xsl:value-of select="true()"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:variable name="tempCount" select="count(/descendant::*/Context[@arisPortalNamespace=string($varCurrentNode/@arisTemplate)])" />
                                
                                <xsl:choose>
                                    <xsl:when test="$tempCount=0">
                                        <xsl:value-of select="false()"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="isTargetSupported">
                                            <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=string($varCurrentNode/@arisTemplate)]" />
                                        </xsl:call-template>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="false()"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    
</xsl:stylesheet>
