<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Author:
    TPLA / IDS Scheer
    
    Description:
    this stylesheet filters elements which are not supported. Delta-Links on not supported elements are filtered out.
    the result is a text-stream with status-messages
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output encoding="ISO-8859-1"
    method="text"/>
    
    <xsl:include href="common_for_text.xsl"/>
    <xsl:include href="common_for_check.xsl"/>
    
    <xsl:variable name="ACTION.FILTER" select="'FILTER_WITH_MSG_FILTER'" />
    
    <xsl:variable name="ACTION_RESULT.FILTER.SUCCESS" select="'FILTER_SUCCESS'" />
    <xsl:variable name="ACTION_RESULT.FILTER.UNSUPPORTED_OBJECT" select="'FILTER_UNSUPPORTED_OBJECT'" />
    <xsl:variable name="ACTION_RESULT.FILTER.UNSUPPORTED_IVIEW" select="'FILTER_UNSUPPORTED_IVIEW'" />
    <xsl:variable name="ACTION_RESULT.FILTER.UNSUPPORTED_PAGE" select="'FILTER_UNSUPPORTED_PAGE'" />
    <xsl:variable name="ACTION_RESULT.FILTER.IVIEW_WITHOUT_TEMPLATE" select="'FILTER_IVIEW_WITHOUT_TEMPLATE'" />
    <xsl:variable name="ACTION_RESULT.FILTER.PAGE_WITHOUT_TEMPLATE" select="'FILTER_PAGE_WITHOUT_TEMPLATE'" />
    <xsl:variable name="ACTION_RESULT.FILTER.INTERNAL_ERROR" select="'FILTER_INTERNAL_ERROR'" />
    
    <!--
        Description:
        handles the root xml-element
    -->
    <xsl:template match="GenericCreator">
        <xsl:for-each select="child::*">
            <xsl:choose>
                <xsl:when test="name()='Context'">
                    <xsl:apply-templates select="self::node()"></xsl:apply-templates>
                </xsl:when>
            </xsl:choose>
        </xsl:for-each>
    </xsl:template>
    
    <!--
        Description:
        handles context-elements. these will be checked if they are supported. If they are not they will be filtered out. 
        References (Delta-Links) are disbanded and filtered out if the target is not supported. Supported 
        content will be added to result.
    -->
    <xsl:template match="Context">
        <xsl:variable name="tempIsSupportedObjectClass">
            <xsl:call-template name="common_for_check.isSupportedObjectClass">
                <xsl:with-param name="varObjectClass" select="@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
                <xsl:when test="$tempIsSupportedObjectClass='false'">
                    <xsl:call-template name="common_for_txt.doOutputMessage">
                        <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.WARN_MESSAGE" />
                        <xsl:with-param name="messageAction" select="$ACTION.FILTER" />
                        <xsl:with-param name="messageResult" select="$ACTION_RESULT.FILTER.UNSUPPORTED_OBJECT" />
                        <xsl:with-param name="name" select="@name" />
                        <xsl:with-param name="type" select="@objectClass" />
                    </xsl:call-template>
                    <xsl:call-template name="common_for_txt.doNewLine" />
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="tempIsGroup">
                        <xsl:call-template name="common_for_check.isGroup">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsRole">
                        <xsl:call-template name="common_for_check.isRole">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsPage">
                        <xsl:call-template name="common_for_check.isPage">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsiView">
                        <xsl:call-template name="common_for_check.isiView">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsWorkset">
                        <xsl:call-template name="common_for_check.isWorkset">
                            <xsl:with-param name="varObjectClass" select="@objectClass" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsTemplateiView">
                        <xsl:call-template name="common_for_check.isTemplateiView">
                            <xsl:with-param name="varTemplate" select="@template" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="tempIsTemplatePage">
                        <xsl:call-template name="common_for_check.isTemplatePage">
                            <xsl:with-param name="varTemplate" select="@template" />
                        </xsl:call-template>
                    </xsl:variable>
                    
                    <xsl:variable name="tempGoOn">
                        <xsl:choose>
                            <xsl:when test="$tempIsGroup='true'">
                                <xsl:value-of select="true()" />
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:choose>
                                    <xsl:when test="@template">
                                        <xsl:call-template name="isTargetSupported">
                                            <xsl:with-param name="varCurrentNode" select="self::node()" />
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:choose>
                                            <xsl:when test="$tempIsRole='true'">
                                                <xsl:value-of select="true()" />
                                            </xsl:when>
                                            <xsl:when test="$tempIsWorkset='true'">
                                                <xsl:value-of select="true()" />
                                            </xsl:when>
                                            <xsl:when test="$tempIsPage='true'">
                                                <xsl:value-of select="false()" />
                                                
                                                <xsl:call-template name="common_for_txt.doOutputMessage">
                                                    <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.ERROR_MESSAGE" />
                                                    <xsl:with-param name="messageAction" select="$ACTION.FILTER" />
                                                    <xsl:with-param name="messageResult" select="$ACTION_RESULT.FILTER.PAGE_WITHOUT_TEMPLATE" />
                                                    <xsl:with-param name="name" select="@name" />
                                                    <xsl:with-param name="type" select="@objectClass" />
                                                </xsl:call-template>
                                                <xsl:call-template name="common_for_txt.doNewLine" />
                                            </xsl:when>
                                            <xsl:when test="$tempIsiView='true'">
                                                <xsl:value-of select="false()" />
                                                
                                                <xsl:call-template name="common_for_txt.doOutputMessage">
                                                    <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.ERROR_MESSAGE" />
                                                    <xsl:with-param name="messageAction" select="$ACTION.FILTER" />
                                                    <xsl:with-param name="messageResult" select="$ACTION_RESULT.FILTER.IVIEW_WITHOUT_TEMPLATE" />
                                                    <xsl:with-param name="name" select="@name" />
                                                    <xsl:with-param name="type" select="@objectClass" />
                                                </xsl:call-template>
                                                <xsl:call-template name="common_for_txt.doNewLine" />
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="false()" />
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                            </xsl:otherwise>
                        </xsl:choose>
                        
                    </xsl:variable>
                    
                    <xsl:choose>
                        <xsl:when test="starts-with($tempGoOn, 'true')">
                            <xsl:variable name="tempAfterResult">
                                <xsl:value-of select="substring-after($tempGoOn, 'true')"/>
                            </xsl:variable>
                            
                            <xsl:if test="string-length($tempAfterResult)>0">
                                <xsl:value-of select="$tempAfterResult"/>
                            </xsl:if>
                            
                            <xsl:for-each select="child::*">
                                <xsl:choose>
                                    <xsl:when test="name()='Context'">
                                        <xsl:apply-templates select="self::node()"></xsl:apply-templates>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                        </xsl:when>
                        <xsl:when test="starts-with($tempGoOn, 'false')">
                            <xsl:value-of select="substring-after($tempGoOn, 'false')"/>
                        </xsl:when>
                    </xsl:choose>
                </xsl:otherwise>
                
        </xsl:choose>
    </xsl:template>    

    <!--
        Description:
        checks recursively if an element is supported. if an element has a template-attribute which is not a SAP-template
        the check is done on the referenced element
    -->
    <xsl:template name="isTargetSupported">
        <xsl:param name="varCurrentNode" />
        
        <xsl:variable name="tempIsRole">
            <xsl:call-template name="common_for_check.isRole">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsPage">
            <xsl:call-template name="common_for_check.isPage">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsiView">
            <xsl:call-template name="common_for_check.isiView">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="tempIsWorkset">
            <xsl:call-template name="common_for_check.isWorkset">
                <xsl:with-param name="varObjectClass" select="$varCurrentNode/@objectClass" />
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="$tempIsRole='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:call-template name="isTargetSupported">
                            <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]" />
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="true()"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsWorkset='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:call-template name="isTargetSupported">
                            <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]" />
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="true()"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsPage='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:variable name="tempIsSapPage">
                            <xsl:call-template name="common_for_check.isTemplatePage">
                                <xsl:with-param name="varTemplate" select="$varCurrentNode/@template" />
                            </xsl:call-template>
                        </xsl:variable>
                        
                        <xsl:choose>
                            <xsl:when test="$tempIsSapPage='true'">
                                <xsl:value-of select="true()"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:variable name="tempCount" select="count(/descendant::*/Context[@arisPortalNamespace=string($varCurrentNode/@arisTemplate)])" />
                                
                                <xsl:choose>
                                    <xsl:when test="$tempCount=0">
                                        <xsl:value-of select="false()"/>
                                        
                                        <xsl:call-template name="common_for_txt.doOutputMessage">
                                            <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.WARN_MESSAGE" />
                                            <xsl:with-param name="messageAction" select="$ACTION.FILTER" />
                                            <xsl:with-param name="messageResult" select="$ACTION_RESULT.FILTER.UNSUPPORTED_PAGE" />
                                            <xsl:with-param name="name" select="$varCurrentNode/@name" />
                                            <xsl:with-param name="type" select="$varCurrentNode/@objectClass" />
                                        </xsl:call-template>
                                        <xsl:call-template name="common_for_txt.doNewLine" />
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="isTargetSupported">
                                            <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=$varCurrentNode/@arisTemplate]" />
                                        </xsl:call-template>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="false()"/>
                        
                        <xsl:call-template name="common_for_txt.doOutputMessage">
                            <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.ERROR_MESSAGE" />
                            <xsl:with-param name="messageAction" select="$ACTION.FILTER" />
                            <xsl:with-param name="messageResult" select="$ACTION_RESULT.FILTER.PAGE_WITHOUT_TEMPLATE" />
                            <xsl:with-param name="name" select="$varCurrentNode/@name" />
                            <xsl:with-param name="type" select="$varCurrentNode/@objectClass" />
                        </xsl:call-template>
                        <xsl:call-template name="common_for_txt.doNewLine" />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$tempIsiView='true'">
                <xsl:choose>
                    <xsl:when test="$varCurrentNode/@template">
                        <xsl:variable name="tempIsSapiView">
                            <xsl:call-template name="common_for_check.isTemplateiView">
                                <xsl:with-param name="varTemplate" select="$varCurrentNode/@template" />
                            </xsl:call-template>
                        </xsl:variable>
                        
                        <xsl:choose>
                            <xsl:when test="$tempIsSapiView='true'">
                                <xsl:value-of select="true()"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:variable name="tempCount" select="count(/descendant::*/Context[@arisPortalNamespace=string($varCurrentNode/@arisTemplate)])" />
                                
                                <xsl:choose>
                                    <xsl:when test="$tempCount=0">
                                        <xsl:value-of select="false()"/>
                                        
                                        <xsl:call-template name="common_for_txt.doOutputMessage">
                                            <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.WARN_MESSAGE" />
                                            <xsl:with-param name="messageAction" select="$ACTION.FILTER" />
                                            <xsl:with-param name="messageResult" select="$ACTION_RESULT.FILTER.UNSUPPORTED_IVIEW" />
                                            <xsl:with-param name="name" select="$varCurrentNode/@name" />
                                            <xsl:with-param name="type" select="$varCurrentNode/@objectClass" />
                                        </xsl:call-template>
                                        <xsl:call-template name="common_for_txt.doNewLine" />
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="isTargetSupported">
                                            <xsl:with-param name="varCurrentNode" select="/descendant::*/Context[@arisPortalNamespace=string($varCurrentNode/@arisTemplate)]" />
                                        </xsl:call-template>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="false()"/>
                        
                        <xsl:call-template name="common_for_txt.doOutputMessage">
                            <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.ERROR_MESSAGE" />
                            <xsl:with-param name="messageAction" select="$ACTION.FILTER" />
                            <xsl:with-param name="messageResult" select="$ACTION_RESULT.FILTER.PAGE_WITHOUT_TEMPLATE" />
                            <xsl:with-param name="name" select="$varCurrentNode/@name" />
                            <xsl:with-param name="type" select="$varCurrentNode/@objectClass" />
                        </xsl:call-template>
                        <xsl:call-template name="common_for_txt.doNewLine" />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="false()"/>
                
                <xsl:call-template name="common_for_txt.doOutputMessage">
                    <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.WARN_MESSAGE" />
                    <xsl:with-param name="messageAction" select="$ACTION.FILTER" />
                    <xsl:with-param name="messageResult" select="$ACTION_RESULT.FILTER.UNSUPPORTED_OBJECT" />
                    <xsl:with-param name="name" select="$varCurrentNode/@name" />
                    <xsl:with-param name="type" select="$varCurrentNode/@objectClass" />
                </xsl:call-template>
                <xsl:call-template name="common_for_txt.doNewLine" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    
</xsl:stylesheet>
