<?xml version="1.0" encoding="ISO-8859-1"?>
<!-- 
    Author:
    TPLA / IDS Scheer
    
    Description:
    this stylesheet performs a normalization of the given content. every xml-element which has a template-attribute will have an arisTemplate-attribute which
    is the disbanded template-attribute. Disbanded value means that if the template-attribute contains a relation to a property this value will be replaced with the
    property-value.
    Furthermore each Context-XML Element will have a further attribute called arisPortalNamespace which is the concatenated name of the Object ID and the
    parent-Object IDs.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output encoding="ISO-8859-1"
    method="xml"/>
    
    <xsl:include href="common_for_portal.xsl"/>
    
    <!--
        Description:
        handles the root-XML Element. all attributes are reused. Child-Elements which are no Context-Elements will be copied. Otherwise the element has to
        be processed recursively (adding arisTemplate if necessary; adding arisPortalNamespace).
    -->
    <xsl:template match="GenericCreator">
         
           <xsl:element name="{name()}">
               <xsl:for-each select="attribute::*">
                   <xsl:attribute name="{name()}"><xsl:value-of select="current()"/></xsl:attribute>
               </xsl:for-each>
               
                <xsl:for-each select="child::*">
                    <xsl:choose>
                        <xsl:when test="name()='Context'">
                            <xsl:apply-templates select="self::node()"></xsl:apply-templates>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:copy-of select="self::node()" />
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:for-each>
        </xsl:element>
    </xsl:template>
    
    <!--
        Description:
        handles Context-XML Elements. all attributes are reused. If the element has a template-attribute a further attribute (arisTemplate) will be added which
        is the disbanded template-attribute. Furthermore a arisPortalNamespace-attribute will be added to allow an direct access through a XPath-expression.
        All Sub-Elements which are no Context-Elements will be copied. Context-Elements are processed recursively by calling this template again.
    -->
    <xsl:template match="Context">
        <xsl:variable name="tempArisTemplateValue" select="@template" />
        <xsl:element name="{name()}">
            <xsl:for-each select="attribute::*">
                <xsl:choose>
                    <xsl:when test="name()='template'">
                        <xsl:choose>
                            <xsl:when test="../@parent">
                                <xsl:variable name="tempParent" select="../@parent" />
                                
                                <xsl:variable name="tempPropertyValue">
                                    <xsl:for-each select="/GenericCreator/Property">
                                        <xsl:variable name="tempConcat" select="concat('${', @name, '}')" />
                                        
                                        <xsl:if test="string($tempParent )=$tempConcat">
                                            <xsl:value-of select="@value"/>
                                        </xsl:if>
                                    </xsl:for-each>
                                </xsl:variable>
                                <xsl:variable name="tempPropertyName">
                                    <xsl:for-each select="/GenericCreator/Property">
                                        <xsl:variable name="tempConcat" select="concat('${', @name, '}')" />
                                        
                                        <xsl:if test="string($tempParent )=$tempConcat">
                                            <xsl:value-of select="@name"/>
                                        </xsl:if>
                                    </xsl:for-each>
                                </xsl:variable>
                                
                                <xsl:choose>
                                    <xsl:when test="starts-with(string($tempArisTemplateValue), concat('${', $tempPropertyName, '}'))">
                                        <xsl:attribute name="arisTemplate">
                                            <xsl:call-template name="normalizeForAris">
                                                <xsl:with-param name="varValue" select="concat($tempPropertyValue, '/', @value)" />
                                            </xsl:call-template>
                                        </xsl:attribute>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="arisTemplate">
                                            <xsl:call-template name="normalizeForAris">
                                                <xsl:with-param name="varValue" select="current()" />
                                            </xsl:call-template>
                                        </xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:variable name="tempPropertyReplaced">
                                    <xsl:call-template name="propertyReplace">
                                        <xsl:with-param name="varStartsWith" select="../@template" />
                                    </xsl:call-template>
                                </xsl:variable>
                                
                                <xsl:attribute name="arisTemplate">
                                    <xsl:call-template name="normalizeForAris">
                                        <xsl:with-param name="varValue" select="$tempPropertyReplaced" />
                                    </xsl:call-template>
                                </xsl:attribute>
                            </xsl:otherwise>
                        </xsl:choose>
                       <xsl:attribute name="{name()}"><xsl:value-of select="current()"/></xsl:attribute>
                    </xsl:when>
                    <xsl:when test="name()='name'">
                        <xsl:attribute name="{name()}">
                            <xsl:call-template name="normalizeForAris">
                                <xsl:with-param name="varValue" select="current()" />
                            </xsl:call-template>
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:attribute name="{name()}"><xsl:value-of select="current()"/></xsl:attribute>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <xsl:attribute name="arisPortalNamespace">
                <xsl:call-template name="determinePortalNamespace" />
            </xsl:attribute>
        <xsl:for-each select="child::*">
            <xsl:choose>
                <xsl:when test="name()='Context'">
                    <xsl:apply-templates select="self::node()"></xsl:apply-templates>
                </xsl:when>
                <xsl:when test="name()='Attributes'">
                    <xsl:element name="{name()}">
                        <xsl:for-each select="child::*">
                           <xsl:if test="@name=$COMMON_FOR_PORTAL.GROUP.TITLE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.TITLE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.MERGE_ID or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.SYSTEM or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.APPLICATION_PARAMETER or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.IAC or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.TCODE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.GUI_TYPE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.GUI_TYPE.WIN or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.GUI_TYPE.JAVA or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.GUI_TYPE.WEB or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.NAMESPACE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.CUSTOMER_NAMESPACE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.DEFINITION_TYPE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.PAGE_ID or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.DEFINITION_TYPE.BSP or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.DEFINITION_TYPE.BSP_ALIAS or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_DEFINITION_TYPE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_APPLICATION or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_NAMESPACE or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_DEFINITION_TYPE.ABAP or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.WEB_DYNPRO_DEFINITION_TYPE.JAVA or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.URL or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.URL_PARAM or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.ENTRY_POINT or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.INVISBLE_IN_NAVIGATION or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.NAVIGATION_PANEL_STATUS or
                                         @name=$COMMON_FOR_PORTAL.CONTENT.SHOW_TYPE">
                                <xsl:element name="{name()}">
                                
                                   <xsl:for-each select="attribute::*">
                                      <xsl:attribute name="{name()}"><xsl:value-of select="current()"/></xsl:attribute>                
                                   </xsl:for-each>

                                   <xsl:for-each select="child::*">
                                       <xsl:if test="name()='AttributeValue'">
                                         <xsl:copy-of select="self::node()" />
                                      </xsl:if>
                                   </xsl:for-each>


                                </xsl:element>
                            </xsl:if>
                        </xsl:for-each>

                    </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:copy-of select="self::node()" />
                </xsl:otherwise>
            </xsl:choose>

        </xsl:for-each>
            
            </xsl:element>
    </xsl:template>

    <!--
        Description:
        this template determines the absolute object id (parent object IDs+object ID) of a Context-Element.
    -->
    <xsl:template name="determinePortalNamespace">
        <xsl:choose>
            <xsl:when test="count(ancestor::Context) > 0">
                <xsl:for-each select="ancestor::Context">
                        <xsl:variable name="tempParentValue">
                            <xsl:if test="@parent">
                                <xsl:variable name="tempParent" select="@parent" />
                                
                                <xsl:for-each select="/GenericCreator/Property">
                                    <xsl:variable name="tempConcat" select="concat('${', @name, '}')" />
                                    
                                    <xsl:if test="string($tempParent)=$tempConcat">
                                        <xsl:value-of select="@value"/>
                                    </xsl:if>
                                </xsl:for-each>
                            </xsl:if>
                        </xsl:variable>
                        
                        <xsl:choose>
                            <xsl:when test="@parent and string-length($tempParentValue)=0">
                                <xsl:value-of select="@parent"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$tempParentValue"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        
                        <xsl:text>/</xsl:text>
                    
                        <xsl:call-template name="normalizeForAris">
                            <xsl:with-param name="varValue" select="@name" />
                        </xsl:call-template>
                </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="tempParentValue">
                    <xsl:if test="@parent">
                        <xsl:variable name="tempParent" select="@parent" />
                        
                        <xsl:for-each select="/GenericCreator/Property">
                            <xsl:variable name="tempConcat" select="concat('${', @name, '}')" />
                            
                            <xsl:if test="string($tempParent)=$tempConcat">
                                <xsl:value-of select="@value"/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                </xsl:variable>
                
                <xsl:choose>
                    <xsl:when test="@parent and string-length($tempParentValue)=0">
                        <xsl:value-of select="@parent"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$tempParentValue"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
        
        
        <xsl:text>/</xsl:text>
        
        <xsl:call-template name="normalizeForAris">
            <xsl:with-param name="varValue" select="@name" />
        </xsl:call-template>
        
    </xsl:template>
    
    <!--
        Description:
        this template checks if the given argument contains a defined property.
    -->
    <xsl:template name="propertyExists">
        <xsl:param name="varStartsWith" />
        
        <xsl:for-each select="/GenericCreator/Property">
            <xsl:choose>
                <xsl:when test="starts-with($varStartsWith, concat('${', @name, '}'))">
                    <xsl:value-of select="true()"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="false()"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
    </xsl:template>
    
    <!--
        Description:
        this template replaces a property in an argument. if the attribute does not contain a property the argument itself will be returned.  
    -->
    <xsl:template name="propertyReplace">
        <xsl:param name="varStartsWith" />
        
        <xsl:variable name="tempPropertyExists">
            <xsl:call-template name="propertyExists">
                <xsl:with-param name="varStartsWith" select="$varStartsWith" />
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="contains($tempPropertyExists, 'true')">
                <xsl:for-each select="/GenericCreator/Property">
                    <xsl:choose>
                        <xsl:when test="starts-with($varStartsWith, concat('${', @name, '}'))">
                            <xsl:value-of select="concat(@value, substring-after($varStartsWith, concat('${', @name, '}')))"/>
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$varStartsWith"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--
        Description:
        this template replaces valid portal characters like ( and ) to _ as the value is used as NCName  
    -->
    <xsl:template name="normalizeForAris">
        <xsl:param name="varValue" />
        
        <xsl:variable name="firstTranslated" select="translate($varValue, '(', '_')" />
        <xsl:variable name="secondTranslated" select="translate($firstTranslated, ')', '_')" />
        
        <xsl:value-of select="$secondTranslated"/>
    </xsl:template>
    
</xsl:stylesheet>
