<?xml version="1.0" encoding="ISO-8859-1"?>
<!-- 
    Author:
    TPLA / IDS Scheer
    
    Description:
    this stylesheet performs a check on a xml-file. every Context-XML element which has a template-attribute has to be checked
    if there exists another xml element where the arisPortalNamespace matches the arisTemplate-attribute.
    this stylesheet can be run in two modes (parameter 'externalParamOnlyCheck').
    In the check mode (externalParamOnlyCheck = true) failed elements will be logged as warning.
    In the other mode failed elements will be logged as errors.
    result of this stylesheet is a text-stream containing checked elements.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output encoding="ISO-8859-1"
    method="text"/>
    
    <xsl:param name="externalParamOnlyCheck" />
    
    <xsl:include href="common_for_text.xsl"/>
    <xsl:include href="common_for_check.xsl"/>
    
    <xsl:variable name="ACTION.ROOT_CHECK" select="'ROOT_CHECK_ROOT_CHECK'" />
    <xsl:variable name="ACTION.NAMESPACE_CHECK" select="'ROOT_CHECK_NAMESPACE_CHECK'" />
    
    <xsl:variable name="ACTION_RESULT.ROOT_CHECK.SUCCESS" select="'ROOT_CHECK_CHECK_SUCCESS'" />
    <xsl:variable name="ACTION_RESULT.ROOT_CHECK.NOT_FOUND" select="'ROOT_CHECK_ROOT_CHECK_NOT_FOUND'" />
    <xsl:variable name="ACTION_RESULT.ROOT_CHECK.TOO_MANY" select="'ROOT_CHECK_ROOT_CHECK_TOO_MANY'" />
    
    <xsl:variable name="ACTION_RESULT.NAMESPACE_CHECK.SUCCESS" select="'ROOT_CHECK_NAMESPACE_CHECK_SUCCESS'" />
    <xsl:variable name="ACTION_RESULT.NAMESPACE_CHECK.TOO_MANY" select="'ROOT_CHECK_NAMESPACE_CHECK_TOO_MANY'" />
    
    <!--
        Description:
        performs the check recursively on Context elements.  
    -->
    <xsl:template match="Context">
        <xsl:variable name="tempArisTemplateValue" select="@arisTemplate" />
        <xsl:variable name="tempArisPortalNamespace" select="@arisPortalNamespace" />
        <xsl:variable name="tempTemplateValue" select="@template" />
        <xsl:for-each select="attribute::*">
            <xsl:choose>
                <xsl:when test="name()='arisTemplate'">
                    <xsl:variable name="tempRootCount" select="count(/descendant::*/Context[@arisPortalNamespace=$tempArisTemplateValue])" />
                    
                    <xsl:choose>
                        <xsl:when test="$tempRootCount=0">
                            <xsl:variable name="tempIsSapiViewTemplate">
                                <xsl:call-template name="common_for_check.isTemplateiView">
                                    <xsl:with-param name="varTemplate" select="string($tempTemplateValue)" />
                                </xsl:call-template>
                            </xsl:variable>
                            <xsl:variable name="tempIsSapPageTemplate">
                                <xsl:call-template name="common_for_check.isTemplatePage">
                                    <xsl:with-param name="varTemplate" select="string($tempTemplateValue)" />
                                </xsl:call-template>
                            </xsl:variable>
                            
                            <xsl:choose>
                                <xsl:when test="$tempIsSapiViewTemplate='true'">
                                    <xsl:call-template name="common_for_txt.doOutputMessage">
                                        <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.INFO_MESSAGE" />
                                        <xsl:with-param name="messageAction" select="$ACTION.ROOT_CHECK" />
                                        <xsl:with-param name="messageResult" select="$ACTION_RESULT.ROOT_CHECK.SUCCESS" />
                                        <xsl:with-param name="name" select="parent::node()/@name" />
                                        <xsl:with-param name="type" select="parent::node()/@objectClass" />
                                    </xsl:call-template>
                                    <xsl:call-template name="common_for_txt.doNewLine" />
                                </xsl:when>
                                <xsl:when test="$tempIsSapPageTemplate='true'">
                                    <xsl:call-template name="common_for_txt.doOutputMessage">
                                        <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.INFO_MESSAGE" />
                                        <xsl:with-param name="messageAction" select="$ACTION.ROOT_CHECK" />
                                        <xsl:with-param name="messageResult" select="$ACTION_RESULT.ROOT_CHECK.SUCCESS" />
                                        <xsl:with-param name="name" select="parent::node()/@name" />
                                        <xsl:with-param name="type" select="parent::node()/@objectClass" />
                                    </xsl:call-template>
                                    <xsl:call-template name="common_for_txt.doNewLine" />
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:choose>
                                        <xsl:when test="$externalParamOnlyCheck='true'">
                                            <xsl:call-template name="common_for_txt.doOutputMessage">
                                                <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.WARN_MESSAGE" />
                                                <xsl:with-param name="messageAction" select="$ACTION.ROOT_CHECK" />
                                                <xsl:with-param name="messageResult" select="$ACTION_RESULT.ROOT_CHECK.NOT_FOUND" />
                                                <xsl:with-param name="name" select="parent::node()/@name" />
                                                <xsl:with-param name="type" select="parent::node()/@objectClass" />
                                            </xsl:call-template>
                                            <xsl:call-template name="common_for_txt.doNewLine" />
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:call-template name="common_for_txt.doOutputMessage">
                                                <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.ERROR_MESSAGE" />
                                                <xsl:with-param name="messageAction" select="$ACTION.ROOT_CHECK" />
                                                <xsl:with-param name="messageResult" select="$ACTION_RESULT.ROOT_CHECK.NOT_FOUND" />
                                                <xsl:with-param name="name" select="parent::node()/@name" />
                                                <xsl:with-param name="type" select="parent::node()/@objectClass" />
                                            </xsl:call-template>
                                            <xsl:call-template name="common_for_txt.doNewLine" />
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:when test="$tempRootCount>1">
                            <xsl:call-template name="common_for_txt.doOutputMessage">
                                <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.ERROR_MESSAGE" />
                                <xsl:with-param name="messageAction" select="$ACTION.ROOT_CHECK" />
                                <xsl:with-param name="messageResult" select="$ACTION_RESULT.ROOT_CHECK.TOO_MANY" />
                                <xsl:with-param name="name" select="parent::node()/@name" />
                                <xsl:with-param name="type" select="parent::node()/@objectClass" />
                            </xsl:call-template>
                            <xsl:call-template name="common_for_txt.doNewLine" />
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="common_for_txt.doOutputMessage">
                                <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.INFO_MESSAGE" />
                                <xsl:with-param name="messageAction" select="$ACTION.ROOT_CHECK" />
                                <xsl:with-param name="messageResult" select="$ACTION_RESULT.ROOT_CHECK.SUCCESS" />
                                <xsl:with-param name="name" select="parent::node()/@name" />
                                <xsl:with-param name="type" select="parent::node()/@objectClass" />
                            </xsl:call-template>
                            <xsl:call-template name="common_for_txt.doNewLine" />
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:when test="name()='arisPortalNamespace'">
                    <xsl:variable name="tempGlobalCount" select="count(/descendant::*/Context[@arisPortalNamespace=$tempArisPortalNamespace])" />
                    
                    <xsl:choose>
                        <xsl:when test="$tempGlobalCount=1">
                            <xsl:call-template name="common_for_txt.doOutputMessage">
                                <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.INFO_MESSAGE" />
                                <xsl:with-param name="messageAction" select="$ACTION.NAMESPACE_CHECK" />
                                <xsl:with-param name="messageResult" select="$ACTION_RESULT.NAMESPACE_CHECK.SUCCESS" />
                                <xsl:with-param name="name" select="parent::node()/@name" />
                                <xsl:with-param name="type" select="parent::node()/@objectClass" />
                            </xsl:call-template>
                            <xsl:call-template name="common_for_txt.doNewLine" />
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="common_for_txt.doOutputMessage">
                                <xsl:with-param name="messageType" select="$COMMON_FOR_TXT.ERROR_MESSAGE" />
                                <xsl:with-param name="messageAction" select="$ACTION.NAMESPACE_CHECK" />
                                <xsl:with-param name="messageResult" select="$ACTION_RESULT.NAMESPACE_CHECK.TOO_MANY" />
                                <xsl:with-param name="name" select="parent::node()/@name" />
                                <xsl:with-param name="type" select="parent::node()/@objectClass" />
                            </xsl:call-template>
                            <xsl:call-template name="common_for_txt.doNewLine" />
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
            </xsl:choose>
        </xsl:for-each>

        <xsl:for-each select="child::*">
            <xsl:choose>
                <xsl:when test="name()='Context'">
                    <xsl:apply-templates select="self::node()"></xsl:apply-templates>
                </xsl:when>
            </xsl:choose>
        </xsl:for-each>
        
    </xsl:template>
</xsl:stylesheet>
