<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output
   encoding="ISO-8859-1"
   indent="yes"
   method="xml"
   omit-xml-declaration="yes"
/>

<xsl:param name="LocaleID" select="1031" />

<xsl:template match="text()"/>

<!-- ############################################# -->
<!-- Diese XSLT dient zur Erzeugung der ObjDef     -->
<!-- der Objekte von den SolutionMaps              -->
<!-- (BusinessScenario-Gruppen, BusinessScenarien, -->
<!-- BusinessScenario-Prozessen)                   -->
<!-- ############################################# -->
<xsl:template match="/folder[@contentElementType='enterprise-service']">
   <xsl:variable name="blanksToPrint">
      <xsl:value-of select="12" />
   </xsl:variable>
   
   <xsl:call-template name="newLine" />
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$blanksToPrint" />
   </xsl:call-template>
   
   <!--
      Hier wird das Tag <Group> ohne das End-Tag </Group> geschrieben.
      Der Grund ist, dass die Modelle in die <Group> geschrieben werden
      muessen, zu der sie gehoeren. Wuerden diese stattdessen in einer
      "anderen" <Group> (mit gleicher ID) liegen, wuerde ARIS das nicht
      zulassen, da die ID eingeutig sein muss.
      Die Option disable-output-escaping="yes" ist ziemlich
      wichtig, da sonst "&lt;" statt "<" ausgegeben wird.
      **Das schliessende Tag wird in [processStep.xsl]< geschrieben**
   -->
   <xsl:text disable-output-escaping="yes">&lt;Group Group.ID="</xsl:text><xsl:value-of select="concat('EnterpriseServices.Group.', self::node()/@ID)" /><xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
   
   <xsl:call-template name="newLine" />
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
   </xsl:call-template>
   
   <xsl:element name="AttrDef">
      <xsl:attribute name="AttrDef.Type">
         <xsl:value-of select="'AT_NAME'" />
      </xsl:attribute>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 6" />
      </xsl:call-template>
   
      <xsl:element name="AttrValue">
         <xsl:attribute name="LocaleId">
            <xsl:value-of select="$LocaleID" />
         </xsl:attribute>
         
         <xsl:value-of select="self::node()/title" />
      </xsl:element>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
      </xsl:call-template>
   </xsl:element>
   
   <xsl:for-each select="self::node()/enterprise-service">
      <!--
      <xsl:element name="Group">
         <xsl:attribute name="Group.ID">
            <xsl:value-of select="concat('EnterpriseService.Group.', @ID)" />
         </xsl:attribute>
         
         <xsl:call-template name="newLine" />
         <xsl:call-template name="loop">
            <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
         </xsl:call-template>
         
         <xsl:element name="AttrDef">
            <xsl:attribute name="AttrDef.Type">
               <xsl:value-of select="'AT_NAME'" />
            </xsl:attribute>
            
            <xsl:call-template name="newLine" />
            <xsl:call-template name="loop">
               <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 6" />
            </xsl:call-template>
         
            <xsl:element name="AttrValue">
               <xsl:attribute name="LocaleId">
                  <xsl:value-of select="$LocaleID" />
               </xsl:attribute>
               
               <xsl:value-of select="./title" />
            </xsl:element>
            
            <xsl:call-template name="newLine" />
            <xsl:call-template name="loop">
               <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
            </xsl:call-template>
         </xsl:element>
      -->   
         
         <xsl:call-template name="printEnterpriseService">
            <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
         </xsl:call-template>
         
         <xsl:for-each select="self::node()[service-operation]">
            <xsl:call-template name="printServiceOperation">
               <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
            </xsl:call-template>
         </xsl:for-each>
         
         <!--
         <xsl:call-template name="newLine" />
         <xsl:call-template name="loop">
            <xsl:with-param name="blanksToPrint" select="$blanksToPrint" />
         </xsl:call-template>
         -->
      <!--
      </xsl:element>
      -->
   </xsl:for-each>
</xsl:template>

<xsl:template name="printEnterpriseService">
   <xsl:param name="blanksToPrint" />
      
   <xsl:call-template name="printObjDef" >
      <xsl:with-param name="attrObjDefID.Value" select="concat('ObjDefEnterpriseService.', @ID)" />
      <xsl:with-param name="attrTypeNum.Value" select="'OT_IS_FUNC'" />
      <xsl:with-param name="attrSymbolNum.Value" select="'ST_IS_FUNC'" />
      <xsl:with-param name="GUID" select="./@ID" />
      <xsl:with-param name="attrLocalID.Value" select="$LocaleID" />
      <!--
      <xsl:with-param name="AT_LAST_CHNG_2.Value" select="'15:25:32.000;11/07/2005'" />
      -->
      <!--
      <xsl:with-param name="AT_LUSER.Value" select="'system'" />
      <xsl:with-param name="AT_CREATOR.Value" select="'system'" />
      <xsl:with-param name="AT_CREAT_TIME_STMP.Value" select="'15:25:18.000;11/07/2005'" />
      -->
      <xsl:with-param name="AT_NAME.Value" select="title" />
      <xsl:with-param name="actualBlanksToPrint" select="$blanksToPrint" />
   </xsl:call-template>
</xsl:template>

<xsl:template name="printServiceOperation">
   <xsl:param name="blanksToPrint" />
      
   <!-- ################################################## -->
   <!-- ############################################ -->
   <!-- Erzeugung der ObjDefs fuer die 'Management & -->
   <!-- Support'-Prozessen                           -->
   <!-- (level1-item/process)                        -->
   <!-- ############################################ -->
   <xsl:for-each select="self::node()/service-operation">
      <!--
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$blanksToPrint" />
      </xsl:call-template>
      -->
      
      <xsl:call-template name="printObjDef" >
         <xsl:with-param name="attrObjDefID.Value" select="concat('ObjDefESAOperation.', @ID)" />
         <xsl:with-param name="attrTypeNum.Value" select="'OT_FUNC'" />
         <xsl:with-param name="attrSymbolNum.Value" select="'ST_OP_1'" />
         <xsl:with-param name="GUID" select="./@ID" />
         <xsl:with-param name="attrLocalID.Value" select="$LocaleID" />
         <!--
         <xsl:with-param name="AT_LAST_CHNG_2.Value" select="'15:25:32.000;11/07/2005'" />
         -->
         <!--
         <xsl:with-param name="AT_LUSER.Value" select="'system'" />
         <xsl:with-param name="AT_CREATOR.Value" select="'system'" />
         <xsl:with-param name="AT_CREAT_TIME_STMP.Value" select="'15:25:18.000;11/07/2005'" />
         -->
         <xsl:with-param name="AT_NAME.Value" select="title" />
         <xsl:with-param name="actualBlanksToPrint" select="$blanksToPrint" />
      </xsl:call-template>
   </xsl:for-each>
</xsl:template>


<!-- ###################################### -->
<!-- Dieses Template dient zur Ausgabe von  -->
<!-- ObjDefs.                               -->
<!-- Es werden aber auch die Tags <CxnDef>  -->
<!-- fuer die KPIs erzeugt. Diese gehoeren  -->
<!-- aber nur zu den BusinessScenarien      -->
<!-- ###################################### -->
<xsl:template name="printObjDef">
   <xsl:param name="attrObjDefID.Value" />
   <xsl:param name="attrTypeNum.Value" />
   <xsl:param name="attrLinkedModelsIdRefs.Value" />
   <xsl:param name="attrSymbolNum.Value" />
   <xsl:param name="attrLocalID.Value" />
   
   <xsl:param name="GUID" />
   
   <!--
   <xsl:param name="AT_LAST_CHNG_2.Value" />
   -->
   <xsl:param name="AT_LUSER.Value" />
   <xsl:param name="AT_CREATOR.Value" />
   <xsl:param name="AT_CREAT_TIME_STMP.Value" />
   <xsl:param name="AT_NAME.Value" />
   
   <xsl:param name="actualBlanksToPrint" />
   
   <xsl:call-template name="newLine" />
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
   </xsl:call-template>
   
   <!-- Erzeugung des ObjDef-Elements -->
   <xsl:element name="ObjDef">
      <!-- ObjDef.ID -->
      <xsl:attribute name="ObjDef.ID">
         <xsl:value-of select="$attrObjDefID.Value" />
      </xsl:attribute>
      
      <!-- TypeNum -->
      <xsl:attribute name="TypeNum">
         <xsl:value-of select="$attrTypeNum.Value" />
      </xsl:attribute>
      
      <!-- ############### -->
      <!-- SymbolNum       -->
      <!-- ############### -->
      <xsl:attribute name="SymbolNum">
         <xsl:value-of select="$attrSymbolNum.Value" />
      </xsl:attribute>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ############### -->
      <!-- GUID            -->
      <!-- ############### -->
      <xsl:element name="GUID">
         <xsl:value-of select="$GUID" />
      </xsl:element>
      
      <!-- ############### -->
      <!-- AT_LAST_CHNG_2  -->
      <!-- ############### -->
      <!--
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_LAST_CHNG_2'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_LAST_CHNG_2.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      -->
      <!-- ############### -->
      <!-- AT_LUSER        -->
      <!-- ############### -->
      <!--
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_LUSER'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_LUSER.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      -->
      <!-- ############### -->
      <!-- AT_CREATOR      -->
      <!-- ############### -->
      <!--
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_CREATOR'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_CREATOR.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      -->
      <!-- ############### -->
      <!-- AT_DESC         -->
      <!-- ############### -->
      <xsl:choose>
         <xsl:when test="not(self::node()/short-description/node()[name()='P' or name()='p'])">
            <xsl:call-template name="printAttrDef">
               <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
               <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
               <xsl:with-param name="attrValue.LocalIdValue" select="self::node()/short-description" />
               <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="self::node()/short-description/node()[name()='P' or name()='p']">
            <xsl:choose>
               <xsl:when test="count(self::node()/short-description/node()[name()='P' or name()='p']) = 1">
                  <xsl:call-template name="printAttrDef">
                     <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
                     <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
                     <xsl:with-param name="attrValue.LocalIdValue" select="self::node()/short-description/node()[name()='P' or name()='p']" />
                     <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
                  </xsl:call-template>
               </xsl:when>
               <xsl:when test="count(self::node()/short-description/node()[name()='P' or name()='p']) > 1">
                  <xsl:call-template name="printShortDescriptionWithPs">
                     <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
                     <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
                     <xsl:with-param name="description.value" select="''" />
                     <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
                     <xsl:with-param name="actualPosition" select="1" />
                     <xsl:with-param name="quantity" select="count(self::node()/short-description/node()[name()='P' or name()='p'])" />
                  </xsl:call-template>
               </xsl:when>
           </xsl:choose>
         </xsl:when>
      </xsl:choose>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ################## -->
      <!-- AT_CREAT_TIME_STMP -->
      <!-- ################## -->
      <!--
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_CREAT_TIME_STMP'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_CREAT_TIME_STMP.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      -->
      <!-- ################## -->
      <!-- AT_NAME            -->
      <!-- ################## -->
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_NAME'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_NAME.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ################################# -->
      <!-- Erzeugung der Tags <CxnDef> fuer  -->
      <!-- die KPIs.                         -->
      <!-- ################################# -->
      <xsl:if test="local-name()='enterprise-service'">
         <!--
         <xsl:call-template name="newLine" />
      	<xsl:call-template name="loop">
            <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
         </xsl:call-template>
         -->
         <xsl:for-each select="service-operation">
            <xsl:call-template name="newLine" />
         	<xsl:call-template name="loop">
               <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
            </xsl:call-template>
            
            <xsl:element name="CxnDef">
               <!-- <xsl:call-template name="newLine" /> -->
               <xsl:attribute name="CxnDef.ID">
                  <xsl:value-of select="concat('CxnDefServiceOperation.', @ID)" />
               </xsl:attribute>
               <xsl:attribute name="CxnDef.Type">
                  <xsl:value-of select="'CT_CAN_SUPP_1'" />
               </xsl:attribute>
               <xsl:attribute name="ToObjDef.IdRef">
                  <xsl:value-of select="concat('ObjDefESAOperation.', @ID)" />
               </xsl:attribute>
            </xsl:element>
         </xsl:for-each>
      </xsl:if>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
      </xsl:call-template>
   </xsl:element>
</xsl:template>

<xsl:template name="printShortDescriptionWithPs">
   <xsl:param name="attrDef.Type" />
   <xsl:param name="attrValue.LocalId" />
   <xsl:param name="description.value" />
   <xsl:param name="actualBlanksToPrint" />
   <xsl:param name="actualPosition" />
   <xsl:param name="quantity" />
   
   <xsl:choose>
      <xsl:when test="$actualPosition = 1">
         <xsl:call-template name="printShortDescriptionWithPs">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="description.value" select="self::node()/short-description/node()[name()='P' or name()='p'][$actualPosition]" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
            <xsl:with-param name="actualPosition" select="$actualPosition + 1" />
            <xsl:with-param name="quantity" select="$quantity" />
         </xsl:call-template>
      </xsl:when>
      <xsl:when test="$actualPosition &lt; $quantity">
         <xsl:call-template name="printShortDescriptionWithPs">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="description.value" select="concat($description.value, '&#10;',self::node()/short-description/node()[name()='P' or name()='p'][$actualPosition])" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
            <xsl:with-param name="actualPosition" select="$actualPosition + 1" />
            <xsl:with-param name="quantity" select="$quantity" />
         </xsl:call-template>
      </xsl:when>
      <xsl:when test="$actualPosition = $quantity">
         <xsl:call-template name="printAttrDef">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="attrValue.LocalIdValue" select="concat($description.value, '&#10;', self::node()/short-description/node()[name()='P' or name()='p'][$actualPosition])" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
         </xsl:call-template>
      </xsl:when>
   </xsl:choose>
</xsl:template>

<!-- ###################################### -->
<!-- Dieses Template dient zur Ausgabe der  -->
<!-- Tas <AttrDef>. Zu deb <AttrDef>s       -->
<!-- werden auch die zugehoerigen           -->
<!-- <AttrValue>-Tags erzeugt.              -->
<!-- ###################################### -->
<xsl:template name="printAttrDef">
   <xsl:param name="attrDef.Type" />
   <xsl:param name="attrValue.LocalId" />
   <xsl:param name="attrValue.LocalIdValue" />
   <xsl:param name="actualBlanksToPrint" />
   
   <xsl:call-template name="newLine" />
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
   </xsl:call-template>
   
   <!-- ################################# -->
   <!-- Erzeugung der Tags <AttrDef>      -->
   <!-- ################################# -->
   <xsl:element name="AttrDef">
      <xsl:attribute name="AttrDef.Type">
         <xsl:value-of select="$attrDef.Type" />
      </xsl:attribute>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ################################# -->
      <!-- Erzeugung der Tags <AttrValue>    -->
      <!-- ################################# -->
      <xsl:element name="AttrValue">
         <xsl:attribute name="LocaleId">
            <xsl:value-of select="$attrValue.LocalId" />
         </xsl:attribute>
         <xsl:value-of select="$attrValue.LocalIdValue" />
      </xsl:element>
      
		<xsl:call-template name="newLine"/>
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
      </xsl:call-template>
   </xsl:element>
</xsl:template>

<!-- ###################################### -->
<!-- Dieses Template dient zur Ausgabe      -->
<!-- einer neuen Zeile                      -->
<!-- ###################################### -->
<xsl:template name="newLine">
   <xsl:text>&#10;</xsl:text>
</xsl:template>

<!-- ###################################### -->
<!-- Dieses Template dient zur Ausgabe von  -->
<!-- Leerzeichen. (Dient zum Einruecken)    -->
<!-- ###################################### -->
<xsl:template name="loop">
   <xsl:param name="blanksToPrint" />
   
   <xsl:choose>
      <xsl:when test="$blanksToPrint &gt; 0">
         <xsl:text> </xsl:text>
         <xsl:call-template name="loop">
            <xsl:with-param name="blanksToPrint" select="$blanksToPrint - 1" />
         </xsl:call-template>
      </xsl:when>
   </xsl:choose>
</xsl:template>

</xsl:stylesheet>