<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output
   encoding="ISO-8859-1"
   indent="yes"
   method="xml"
   omit-xml-declaration="yes"
/>

<xsl:param name="LocaleID" select="1031" />

<xsl:template match="text()"/>

<!-- ############################################# -->
<!-- Diese XSLT dient zur Erzeugung der ObjDef     -->
<!-- der Objekte von den SolutionMaps              -->
<!-- (BusinessScenario-Gruppen, BusinessScenarien, -->
<!-- BusinessScenario-Prozessen)                   -->
<!-- ############################################# -->
<xsl:template match="/solutionmap[folder/level0-item]">
   <xsl:variable name="blanksToPrint">
      <xsl:value-of select="18" />
   </xsl:variable>
   
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$blanksToPrint" />
   </xsl:call-template>
   
   <!--
      Hier wird das Tag <Group> ohne das End-Tag </Group> geschrieben.
      Der Grund ist, dass die Modelle in die <Group> geschrieben werden
      muessen, zu der sie gehoeren. Wuerden diese stattdessen in einer
      "anderen" <Group> (mit gleicher ID) liegen, wuerde ARIS das nicht
      zulassen, da die ID eingeutig sein muss.
      Die Option disable-output-escaping="yes" ist ziemlich
      wichtig, da sonst "&lt;" statt "<" ausgegeben wird.
      **Das schliessende Tag wird in [processStep.xsl]< geschrieben**
   -->
   <xsl:text disable-output-escaping="yes">&lt;Group Group.ID="</xsl:text><xsl:value-of select="concat('MAS.Group.', self::node()/folder/@ID)" /><xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
   
   <xsl:call-template name="newLine" />
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
   </xsl:call-template>
   
   <!-- ############### -->
   <!-- AttrDef         -->
   <!-- ############### -->
   <xsl:element name="AttrDef">
      <xsl:attribute name="AttrDef.Type">
         <xsl:value-of select="'AT_NAME'" />
      </xsl:attribute>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 6" />
      </xsl:call-template>
      
      <!-- ############### -->
      <!-- AttrValue       -->
      <!-- ############### -->
      <xsl:element name="AttrValue">
         <xsl:attribute name="LocaleId">
            <xsl:value-of select="$LocaleID" />
         </xsl:attribute>
         
         <xsl:value-of select="concat(self::node()/title, '_EM&amp;S')" />
      </xsl:element>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
      </xsl:call-template>
   </xsl:element>
   
   <xsl:call-template name="newLine" />
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 6" />
   </xsl:call-template>
   
         
      <!-- ######################################## -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- ######################################## -->
      <xsl:for-each select="self::node()/folder/level0-item">
         <xsl:call-template name="printLevel1Group">
            <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 6" />
         </xsl:call-template>
         
      </xsl:for-each>
      
      <!--
        * Dann werden die ObjDefs fuer Management & Support erzeugt.
       -->
      <xsl:apply-templates select="self::node()/folder/level0-item"/>
      
      <xsl:for-each select="self::node()/folder/level0-item/level1-item">
         <xsl:call-template name="printObjDef" >
            <xsl:with-param name="attrObjDefID.Value" select="concat('ObjDefLevel1-Item.', @ID)" />
            <xsl:with-param name="attrTypeNum.Value" select="'OT_FUNC'" />
            <xsl:with-param name="attrLinkedModelsIdRefs.Value" select="concat('ModelMASProcess.', @ID)" />
            <xsl:with-param name="attrSymbolNum.Value" select="'ST_VAL_ADD_CHN_SML_2'" />
            <xsl:with-param name="GUID" select="./@ID" />
            <xsl:with-param name="attrLocalID.Value" select="$LocaleID" />
            <!--
            <xsl:with-param name="AT_LAST_CHNG_2.Value" select="'15:25:32.000;11/07/2005'" />
            -->
            <!--
            <xsl:with-param name="AT_LUSER.Value" select="'system'" />
            <xsl:with-param name="AT_CREATOR.Value" select="'system'" />
            <xsl:with-param name="AT_CREAT_TIME_STMP.Value" select="'15:25:18.000;11/07/2005'" />
            -->
            <xsl:with-param name="AT_NAME.Value" select="title" />
            <xsl:with-param name="AT_SAP_FUNC_TYPE.Value" select="'AVT_FOR_SAP_NW_PROC_CAT'" />
            <xsl:with-param name="actualBlanksToPrint" select="$blanksToPrint" />
         </xsl:call-template>
      </xsl:for-each>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$blanksToPrint" />
      </xsl:call-template>
<!--   </xsl:element> -->
</xsl:template>

<!-- ################################ -->
<!-- level0-item                      -->
<!-- Hier werden die ObjDefs fuer     -->
<!-- die Management & Support Objekte -->
<!-- erzeugt.                         -->
<!-- ################################ -->
<xsl:template match="/solutionmap/folder/level0-item">
   <xsl:variable name="blanksToPrint">
      <xsl:value-of select="18" />
   </xsl:variable>
   
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$blanksToPrint" />
   </xsl:call-template>
   
   <!-- ######################################## -->
   <!-- Zuerst werden die Gruppen (level0-item)  -->
   <!-- erzeugt. Anschliessend werden alle       -->
   <!-- Objekte in der Gruppe (level1-item)      -->
   <!-- erzeugt.                                 -->
   <!-- ######################################## -->
   <xsl:call-template name="printObjDef" >
      <xsl:with-param name="attrObjDefID.Value" select="concat('ObjDefLevel0-Item.', @ID)" />
      <xsl:with-param name="attrTypeNum.Value" select="'OT_FUNC'" />
      <xsl:with-param name="attrSymbolNum.Value" select="'ST_VAL_ADD_CHN_SML_2'" />
      <xsl:with-param name="GUID" select="./@ID" />
      <xsl:with-param name="attrLocalID.Value" select="$LocaleID" />
      <!--
      <xsl:with-param name="AT_LAST_CHNG_2.Value" select="'15:25:32.000;11/07/2005'" />
      -->
      <!--
      <xsl:with-param name="AT_LUSER.Value" select="'system'" />
      <xsl:with-param name="AT_CREATOR.Value" select="'system'" />
      <xsl:with-param name="AT_CREAT_TIME_STMP.Value" select="'15:25:18.000;11/07/2005'" />
      -->
      <xsl:with-param name="AT_NAME.Value" select="title" />
      <xsl:with-param name="AT_SAP_FUNC_TYPE.Value" select="'AVT_FOR_SAP_NW_MAIN_PROC'" />
      <xsl:with-param name="actualBlanksToPrint" select="$blanksToPrint" />
   </xsl:call-template>
   
</xsl:template>

<xsl:template name="printLevel1Group">
   <xsl:param name="blanksToPrint" />
   
   <!-- ######################################## -->
   <!-- Erzeugung der ObjDefs fuer level1-item   -->
   <!-- ######################################## -->
   <xsl:for-each select="level1-item">
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$blanksToPrint" />
      </xsl:call-template>
      
      <!-- ######################################## -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- **************************************   -->
      <!-- ######################################## -->
      <xsl:element name="Group">
         <xsl:attribute name="Group.ID">
            <xsl:value-of select="concat('MAS.Group.', self::node()/@ID)" />
         </xsl:attribute>
         
         <xsl:call-template name="newLine" />
         <xsl:call-template name="loop">
            <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
         </xsl:call-template>
         
         <xsl:element name="AttrDef">
            <xsl:attribute name="AttrDef.Type">
               <xsl:value-of select="'AT_NAME'" />
            </xsl:attribute>
            
            <xsl:call-template name="newLine" />
            <xsl:call-template name="loop">
               <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 6" />
            </xsl:call-template>
         
            <xsl:element name="AttrValue">
               <xsl:attribute name="LocaleId">
                  <xsl:value-of select="$LocaleID" />
               </xsl:attribute>
               
               <xsl:value-of select="self::node()/title" />
            </xsl:element>
            
            <xsl:call-template name="newLine" />
            <xsl:call-template name="loop">
               <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 3" />
            </xsl:call-template>
         </xsl:element>
         
         <xsl:call-template name="newLine" />
         <xsl:call-template name="loop">
            <xsl:with-param name="blanksToPrint" select="$blanksToPrint + 6" />
         </xsl:call-template>
         
         <!-- ################################################## -->
         <!-- ############################################ -->
         <!-- Erzeugung der ObjDefs fuer die 'Management & -->
         <!-- Support'-Prozessen                           -->
         <!-- (level1-item/process)                        -->
         <!-- ############################################ -->
         <xsl:for-each select="self::node()/process | self::node()/level2-item">
            <xsl:call-template name="newLine" />
            <xsl:call-template name="loop">
               <xsl:with-param name="blanksToPrint" select="$blanksToPrint" />
            </xsl:call-template>
            
            <xsl:call-template name="printObjDef" >
               <xsl:with-param name="attrObjDefID.Value" select="concat('ObjDefMASProcess.', @ID)" />
               <xsl:with-param name="attrTypeNum.Value" select="'OT_FUNC'" />
               <xsl:with-param name="attrSymbolNum.Value" select="'ST_VAL_ADD_CHN_SML_2'" />
               <xsl:with-param name="GUID" select="self::node()/@ID" />
               <xsl:with-param name="attrLocalID.Value" select="$LocaleID" />
               <!--
               <xsl:with-param name="AT_LAST_CHNG_2.Value" select="'15:25:32.000;11/07/2005'" />
               -->
               <!--
               <xsl:with-param name="AT_LUSER.Value" select="'system'" />
               <xsl:with-param name="AT_CREATOR.Value" select="'system'" />
               <xsl:with-param name="AT_CREAT_TIME_STMP.Value" select="'15:25:18.000;11/07/2005'" />
               -->
               <xsl:with-param name="AT_NAME.Value" select="title" />
               <xsl:with-param name="AT_SAP_FUNC_TYPE.Value" select="'AVT_FOR_SAP_NW_BUSINESS_PROC'" />
               <xsl:with-param name="actualBlanksToPrint" select="$blanksToPrint" />
            </xsl:call-template>
         </xsl:for-each>
      </xsl:element>
   </xsl:for-each>
</xsl:template>

<!-- ###################################### -->
<!-- Dieses Template dient zur Ausgabe von  -->
<!-- ObjDefs.                               -->
<!-- Es werden aber auch die Tags <CxnDef>  -->
<!-- fuer die KPIs erzeugt. Diese gehoeren  -->
<!-- aber nur zu den BusinessScenarien      -->
<!-- ###################################### -->
<xsl:template name="printObjDef">
   <xsl:param name="attrObjDefID.Value" />
   <xsl:param name="attrTypeNum.Value" />
   <xsl:param name="attrLinkedModelsIdRefs.Value" />
   <xsl:param name="attrSymbolNum.Value" />
   <xsl:param name="attrLocalID.Value" />
   
   <xsl:param name="GUID" />
   
   <!--
   <xsl:param name="AT_LAST_CHNG_2.Value" />
   -->
   <xsl:param name="AT_LUSER.Value" />
   <xsl:param name="AT_CREATOR.Value" />
   <xsl:param name="AT_CREAT_TIME_STMP.Value" />
   <xsl:param name="AT_NAME.Value" />
   <xsl:param name="AT_SAP_FUNC_TYPE.Value" />
   
   <xsl:param name="actualBlanksToPrint" />
   
   <!-- Erzeugung des ObjDef-Elements -->
   <xsl:element name="ObjDef">
      <!-- ObjDef.ID -->
      <xsl:attribute name="ObjDef.ID">
         <xsl:value-of select="$attrObjDefID.Value" />
      </xsl:attribute>
      
      <!-- TypeNum -->
      <xsl:attribute name="TypeNum">
         <xsl:value-of select="$attrTypeNum.Value" />
      </xsl:attribute>
      
      <!-- LinkedModels.IdRefs -->
      <xsl:choose>
         <!-- ################################################## -->
         <!-- Diese Abfrage ist fuer Management & Support        -->
         <!-- wichtig. Hier wird ueberprueft, ob das             -->
         <!-- level1-item Prozesse hat. Wenn keine vorhanden     -->
         <!-- sind, muessen keine Hinterlegungen erzeugt werden. -->
         <!-- ################################################## -->
         <xsl:when test="local-name()='process-ref'">
            <xsl:choose>
               <xsl:when test="self::node()[@variantOf]">
                  <xsl:if test="not($attrLinkedModelsIdRefs.Value='') and not(@Ref=@variantOf)">
                     <xsl:attribute name="LinkedModels.IdRefs">
                        <xsl:value-of select="$attrLinkedModelsIdRefs.Value" />
                     </xsl:attribute>
                  </xsl:if>
               </xsl:when>
            </xsl:choose>
         </xsl:when>
         <xsl:when test="self::node()[process|level2-item]">
            <xsl:if test="not($attrLinkedModelsIdRefs.Value='')">
               <xsl:attribute name="LinkedModels.IdRefs">
                  <xsl:value-of select="$attrLinkedModelsIdRefs.Value" />
               </xsl:attribute>
            </xsl:if>
         </xsl:when>
      </xsl:choose>
      
      <!-- ############### -->
      <!-- SymbolNum       -->
      <!-- ############### -->
      <xsl:attribute name="SymbolNum">
         <xsl:value-of select="$attrSymbolNum.Value" />
      </xsl:attribute>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ############### -->
      <!-- GUID            -->
      <!-- ############### -->
      <xsl:element name="GUID">
         <xsl:value-of select="$GUID" />
      </xsl:element>
      
      <!-- ############### -->
      <!-- AT_LAST_CHNG_2  -->
      <!-- ############### -->
      <!--
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_LAST_CHNG_2'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_LAST_CHNG_2.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      -->
      <!-- ############### -->
      <!-- AT_LUSER        -->
      <!-- ############### -->
      <!--
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_LUSER'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_LUSER.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      -->
      <!-- ############### -->
      <!-- AT_CREATOR      -->
      <!-- ############### -->
      <!--
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_CREATOR'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_CREATOR.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      -->
      <!-- ############### -->
      <!-- AT_DESC         -->
      <!-- ############### -->
      <xsl:choose>
         <xsl:when test="self::node()[content and short-description]">
            <xsl:call-template name="printContentShortDescription">
               <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
               <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
               <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="self::node()[short-description and not(content)]">
            <xsl:choose>
               <xsl:when test="not(self::node()/short-description/node()[name()='P' or name()='p'])">
                  <xsl:call-template name="printAttrDef">
                     <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
                     <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
                     <xsl:with-param name="attrValue.LocalIdValue" select="self::node()/short-description" />
                     <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
                  </xsl:call-template>
               </xsl:when>
               <xsl:when test="self::node()/short-description/node()[name()='P' or name()='p']">
                  <xsl:choose>
                     <xsl:when test="count(self::node()/short-description/node()[name()='P' or name()='p']) = 1">
                        <xsl:call-template name="printAttrDef">
                           <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
                           <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
                           <xsl:with-param name="attrValue.LocalIdValue" select="self::node()/short-description/node()[name()='P' or name()='p']" />
                           <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
                        </xsl:call-template>
                     </xsl:when>
                     <xsl:when test="count(self::node()/short-description/node()[name()='P' or name()='p']) > 1">
                        <xsl:call-template name="printShortDescriptionWithPs">
                           <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
                           <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
                           <xsl:with-param name="description.value" select="''" />
                           <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
                           <xsl:with-param name="actualPosition" select="1" />
                           <xsl:with-param name="quantity" select="count(self::node()/short-description/node()[name()='P' or name()='p'])" />
                        </xsl:call-template>
                     </xsl:when>
                 </xsl:choose>
               </xsl:when>
            </xsl:choose>
         </xsl:when>
         <xsl:when test="self::node()[not(short-description) and content]">
            <xsl:choose>
               <xsl:when test="not(self::node()/content/node()[name()='P' or name()='p'])">
                  <xsl:call-template name="printAttrDef">
                     <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
                     <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
                     <xsl:with-param name="attrValue.LocalIdValue" select="self::node()/content" />
                     <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
                  </xsl:call-template>
               </xsl:when>
               <xsl:when test="self::node()/content/node()[name()='P' or name()='p']">
                  <xsl:choose>
                     <xsl:when test="count(self::node()/content/node()[name()='P' or name()='p']) = 1">
                        <xsl:call-template name="printAttrDef">
                           <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
                           <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
                           <xsl:with-param name="attrValue.LocalIdValue" select="self::node()/content/node()[name()='P' or name()='p']" />
                           <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
                        </xsl:call-template>
                     </xsl:when>
                     <xsl:when test="count(self::node()/content/node()[name()='P' or name()='p']) > 1">
                        <xsl:call-template name="printContentPs">
                           <xsl:with-param name="attrDef.Type" select="'AT_DESC'" />
                           <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
                           <xsl:with-param name="description.value" select="''" />
                           <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
                           <xsl:with-param name="actualPosition" select="1" />
                           <xsl:with-param name="quantity" select="count(self::node()/content/node()[name()='P' or name()='p'])" />
                        </xsl:call-template>
                     </xsl:when>
                 </xsl:choose>
               </xsl:when>
            </xsl:choose>
         </xsl:when>
      </xsl:choose>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ################## -->
      <!-- AT_CREAT_TIME_STMP -->
      <!-- ################## -->
      <!--
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_CREAT_TIME_STMP'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_CREAT_TIME_STMP.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      -->
      <!-- ################## -->
      <!-- AT_NAME            -->
      <!-- ################## -->
      <xsl:call-template name="printAttrDef">
         <xsl:with-param name="attrDef.Type" select="'AT_NAME'" />
         <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
         <xsl:with-param name="attrValue.LocalIdValue" select="$AT_NAME.Value" />
         <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ################## -->
      <!-- AT_SAP_FUNC_TYPE   -->
      <!-- ################## -->
      <xsl:choose>
         <xsl:when test="not($AT_SAP_FUNC_TYPE.Value = '') and string-length($AT_SAP_FUNC_TYPE.Value) &gt; 0">
            <xsl:call-template name="printAttrDef">
               <xsl:with-param name="attrDef.Type" select="'AT_SAP_FUNC_TYPE'" />
               <xsl:with-param name="attrValue.LocalId" select="$attrLocalID.Value" />
               <xsl:with-param name="attrValue.LocalIdValue" select="$AT_SAP_FUNC_TYPE.Value" />
               <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint + 3" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
      </xsl:call-template>
   </xsl:element>
</xsl:template>

<xsl:template name="printShortDescriptionWithPs">
   <xsl:param name="attrDef.Type" />
   <xsl:param name="attrValue.LocalId" />
   <xsl:param name="description.value" />
   <xsl:param name="actualBlanksToPrint" />
   <xsl:param name="actualPosition" />
   <xsl:param name="quantity" />
   
   <xsl:choose>
      <xsl:when test="$actualPosition = 1">
         <xsl:call-template name="printShortDescriptionWithPs">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="description.value" select="self::node()/short-description/node()[name()='P' or name()='p'][$actualPosition]" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
            <xsl:with-param name="actualPosition" select="$actualPosition + 1" />
            <xsl:with-param name="quantity" select="$quantity" />
         </xsl:call-template>
      </xsl:when>
      <xsl:when test="$actualPosition &lt; $quantity">
         <xsl:call-template name="printShortDescriptionWithPs">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="description.value" select="concat($description.value, '&#10;',self::node()/short-description/node()[name()='P' or name()='p'][$actualPosition])" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
            <xsl:with-param name="actualPosition" select="$actualPosition + 1" />
            <xsl:with-param name="quantity" select="$quantity" />
         </xsl:call-template>
      </xsl:when>
      <xsl:when test="$actualPosition = $quantity">
         <xsl:call-template name="printAttrDef">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="attrValue.LocalIdValue" select="concat($description.value, '&#10;', self::node()/short-description/node()[name()='P' or name()='p'][$actualPosition])" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
         </xsl:call-template>
      </xsl:when>
   </xsl:choose>
</xsl:template>

<!-- ############################################################## -->
<!-- Dieses Template dient zur Ausgabe der Beschreibung/Definition. -->
<!-- Manche Prozesse bzw. Prozess-Schritte haben mehrere            -->
<!-- "content"-Tags. Hierfuer gibt es eine spezielle Abarbeitung.   -->
<!-- ############################################################## -->
<xsl:template name="printContentPs">
   <xsl:param name="attrDef.Type" />
   <xsl:param name="attrValue.LocalId" />
   <xsl:param name="description.value" />
   <xsl:param name="actualBlanksToPrint" />
   <xsl:param name="actualPosition" />
   <xsl:param name="quantity" />
   
   <!-- ############################################################## -->
   <!-- Wenn mehrere "P" oder "p" -Tags existieren, wird dieses        -->
   <!-- Template noch mal aufgerufen. Dabei wird der Inhalt vom Tag    -->
   <!-- "content" mitgegeben. Dabei wird ein Zeilen-Umbruch            -->
   <!-- angehangen. Dieser Vorgang wird so lange wiederholt, bis der   -->
   <!-- letzte "content"-Tag bearbeitet wurde. Beim letzten            -->
   <!-- "content" wird dann das Template "printAttrDef" aufgerufen.    -->
   <!-- ############################################################## -->
   <xsl:choose>
      <xsl:when test="$actualPosition = 1">
         <xsl:call-template name="printContentPs">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="description.value" select="self::node()/content/node()[name()='P' or name()='p'][$actualPosition]" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
            <xsl:with-param name="actualPosition" select="$actualPosition + 1" />
            <xsl:with-param name="quantity" select="$quantity" />
         </xsl:call-template>
      </xsl:when>
      <xsl:when test="$actualPosition &lt; $quantity">
         <xsl:call-template name="printContentPs">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="description.value" select="concat($description.value, '&#10;',self::node()/content/node()[name()='P' or name()='p'][$actualPosition])" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
            <xsl:with-param name="actualPosition" select="$actualPosition + 1" />
            <xsl:with-param name="quantity" select="$quantity" />
         </xsl:call-template>
      </xsl:when>
      <xsl:when test="$actualPosition = $quantity">
         <xsl:call-template name="printAttrDef">
            <xsl:with-param name="attrDef.Type" select="$attrDef.Type" />
            <xsl:with-param name="attrValue.LocalId" select="$attrValue.LocalId" />
            <xsl:with-param name="attrValue.LocalIdValue" select="concat($description.value, '&#10;', self::node()/content/node()[name()='P' or name()='p'][$actualPosition])" />
            <xsl:with-param name="actualBlanksToPrint" select="$actualBlanksToPrint" />
         </xsl:call-template>
      </xsl:when>
   </xsl:choose>
</xsl:template>

<!-- ######################################################## -->
<xsl:template name="printContentShortDescription">
   <xsl:param name="attrDef.Type" />
   <xsl:param name="attrValue.LocalId" />
   <xsl:param name="actualBlanksToPrint" />
   
   <xsl:call-template name="newLine" />
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
   </xsl:call-template>
   
   <!-- ############### -->
   <!-- AttrDef         -->
   <!-- ############### -->
   <xsl:element name="AttrDef">
      <!-- ############### -->
      <!-- AttrDef.Type    -->
      <!-- ############### -->
      <xsl:attribute name="AttrDef.Type">
         <xsl:value-of select="$attrDef.Type" />
      </xsl:attribute>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ############### -->
      <!-- AttrValue       -->
      <!-- ############### -->
      <xsl:element name="AttrValue">
         <xsl:attribute name="LocaleId">
            <xsl:value-of select="$attrValue.LocalId" />
         </xsl:attribute>
         
         <xsl:choose>
            <xsl:when test="not(self::node()/content/node()[name()='P' or name()='p'])">
               <xsl:value-of select="self::node()/short-description" />
               <xsl:text>&#10;</xsl:text>
            </xsl:when>
            <xsl:when test="self::node()/content/node()[name()='P' or name()='p']">
               <xsl:choose>
                  <xsl:when test="count(self::node()/content/node()[name()='P' or name()='p']) = 1">
                     <xsl:value-of select="self::node()/content/node()[name()='P' or name()='p']" />
                     <xsl:text>&#10;</xsl:text>
                  </xsl:when>
                  <xsl:when test="count(self::node()/content/node()[name()='P' or name()='p']) > 1">
                     <xsl:for-each select="self::node()/content/node()[name()='P' or name()='p']">
                        <xsl:if test="position() &gt; 1">
                           <xsl:text>&#10;</xsl:text>
                        </xsl:if>
                        <xsl:value-of select="self::node()/content/node()[name()='P' or name()='p']" />
                     </xsl:for-each>
                     <xsl:text>&#10;</xsl:text>
                  </xsl:when>
              </xsl:choose>
            </xsl:when>
         </xsl:choose>
         
         <xsl:choose>
            <xsl:when test="not(self::node()/short-description/node()[name()='P' or name()='p'])">
               <xsl:value-of select="self::node()/short-description" />
            </xsl:when>
            <xsl:when test="self::node()/short-description/node()[name()='P' or name()='p']">
               <xsl:choose>
                  <xsl:when test="count(self::node()/short-description/node()[name()='P' or name()='p']) = 1">
                     <xsl:value-of select="self::node()/short-description/node()[name()='P' or name()='p']" />
                  </xsl:when>
                  <xsl:when test="count(self::node()/short-description/node()[name()='P' or name()='p']) > 1">
                     <xsl:for-each select="self::node()/short-description/node()[name()='P' or name()='p']">
                        <xsl:if test="position() &gt; 1">
                           <xsl:text>&#10;</xsl:text>
                        </xsl:if>
                        <xsl:value-of select="self::node()/short-description/node()[name()='P' or name()='p']" />
                     </xsl:for-each>
                  </xsl:when>
              </xsl:choose>
            </xsl:when>
         </xsl:choose>
      </xsl:element>
      
		<xsl:call-template name="newLine"/>
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
      </xsl:call-template>
   </xsl:element>
</xsl:template>


<!-- ###################################### -->
<!-- Dieses Template dient zur Ausgabe der  -->
<!-- Tas <AttrDef>. Zu deb <AttrDef>s       -->
<!-- werden auch die zugehoerigen           -->
<!-- <AttrValue>-Tags erzeugt.              -->
<!-- ###################################### -->
<xsl:template name="printAttrDef">
   <xsl:param name="attrDef.Type" />
   <xsl:param name="attrValue.LocalId" />
   <xsl:param name="attrValue.LocalIdValue" />
   <xsl:param name="actualBlanksToPrint" />
   
   <xsl:call-template name="newLine" />
   <xsl:call-template name="loop">
      <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
   </xsl:call-template>
   
   <!-- ################################# -->
   <!-- Erzeugung der Tags <AttrDef>      -->
   <!-- ################################# -->
   <xsl:element name="AttrDef">
      <xsl:attribute name="AttrDef.Type">
         <xsl:value-of select="$attrDef.Type" />
      </xsl:attribute>
      
      <xsl:call-template name="newLine" />
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint + 3" />
      </xsl:call-template>
      
      <!-- ################################# -->
      <!-- Erzeugung der Tags <AttrValue>    -->
      <!-- ################################# -->
      <xsl:element name="AttrValue">
         <xsl:attribute name="LocaleId">
            <xsl:value-of select="$attrValue.LocalId" />
         </xsl:attribute>
         <xsl:value-of select="$attrValue.LocalIdValue" />
      </xsl:element>
      
		<xsl:call-template name="newLine"/>
      <xsl:call-template name="loop">
         <xsl:with-param name="blanksToPrint" select="$actualBlanksToPrint" />
      </xsl:call-template>
   </xsl:element>
</xsl:template>

<!-- ###################################### -->
<!-- Dieses Template dient zur Ausgabe      -->
<!-- einer neuen Zeile                      -->
<!-- ###################################### -->
<xsl:template name="newLine">
   <xsl:text>&#10;</xsl:text>
</xsl:template>

<!-- ###################################### -->
<!-- Dieses Template dient zur Ausgabe von  -->
<!-- Leerzeichen. (Dient zum Einruecken)    -->
<!-- ###################################### -->
<xsl:template name="loop">
   <xsl:param name="blanksToPrint" />
   
   <xsl:choose>
      <xsl:when test="$blanksToPrint &gt; 0">
         <xsl:text> </xsl:text>
         <xsl:call-template name="loop">
            <xsl:with-param name="blanksToPrint" select="$blanksToPrint - 1" />
         </xsl:call-template>
      </xsl:when>
   </xsl:choose>
</xsl:template>

</xsl:stylesheet>