<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:param name="vpackage"/>

<xsl:key name="obj-types" match="object-type" use="@NAME"/>

<xsl:template match="metadata">
/**
 * This interface is generated - do not edit
 */
<xsl:value-of select="concat('package com.idsscheer.aris.server.dlcustom.schema.', @NAME, '.', $vpackage)"/>;

public interface IConstants { <xsl:text>

    // the schema version
    static final int VERSION = </xsl:text> <xsl:value-of select="@VERSION"/><xsl:text>;

    // all object types support an ID field
    static final int COL_OBJECT_ID = 1;</xsl:text>
<xsl:apply-templates select="object-type"/>
}
</xsl:template>


<xsl:template match="object-type">
    <xsl:text>


    //
    // constants for object type </xsl:text> <xsl:value-of select="@NAME"/> <xsl:text>
    //
    static final int </xsl:text> <xsl:value-of select="concat('TABLE_', @CNAME)"/> = <xsl:value-of select="@OTID"/> <xsl:text>;
    // field constants </xsl:text>
    <xsl:variable name="total-number-of-fields">
        <xsl:call-template name="compute-total-number-of-fields">
            <xsl:with-param name="pobjecttype" select="."/>
        </xsl:call-template>
    </xsl:variable>
    <xsl:apply-templates select="fields"> <xsl:with-param name="p-first-field-index" select="$total-number-of-fields - count(./fields/field)"/> </xsl:apply-templates>
    <xsl:text>
    // relation constants </xsl:text>
    <xsl:apply-templates select="relationships"/>
</xsl:template>

<xsl:template match="fields"> <xsl:param name="p-first-field-index"/>
    <xsl:apply-templates select="field"> <xsl:with-param name="p-first-field-index" select="$p-first-field-index"/> </xsl:apply-templates>
</xsl:template>

<xsl:template match="field"> <xsl:param name="p-first-field-index"/>
    static int <xsl:value-of select="concat('COL_', ../../@CNAME, '_', @CNAME)"/> = <xsl:value-of select="$p-first-field-index + position() + 1"/> <xsl:text>;</xsl:text>
</xsl:template>

<!-- this template computes the total number of all fields of an object type
(specified as parameter), inclusively the fields inheried from the base object
type (if any base object type exist for the passed object type).
-->
<xsl:template name="compute-total-number-of-fields"> <xsl:param name="pobjecttype"/>
    <xsl:variable name="var-field-offset-in-parent">
        <xsl:choose>
            <xsl:when test="$pobjecttype/extends-object-type">
                <xsl:for-each select="$pobjecttype/extends-object-type">
                    <xsl:call-template name="compute-total-number-of-fields">
                    <xsl:with-param name="pobjecttype" select="key('obj-types',$pobjecttype/extends-object-type/@NAME)"/>
                    </xsl:call-template>
                </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
                0
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="count($pobjecttype/fields/field) + number($var-field-offset-in-parent)"/>
</xsl:template>

<xsl:template match="relationships">
    <xsl:apply-templates select="one-to-many|many-to-many|compound"/>
</xsl:template>

<xsl:template match="one-to-many|many-to-many|compound">
    static int <xsl:value-of select="@NAME"/> = <xsl:value-of select="@RID"/> <xsl:text>;</xsl:text>
</xsl:template>

</xsl:stylesheet>
