USE [$(database)]
GO

--
-- drop procedures in schema $(adminschema)
--
BEGIN
    DECLARE @procname NVARCHAR(100)

    DECLARE CurAllProc CURSOR FOR
    SELECT specific_name FROM INFORMATION_SCHEMA.ROUTINES WHERE routine_catalog='$(database)' AND routine_schema='$(adminschema)' AND routine_type <> 'FUNCTION'

    OPEN CurAllProc 
    FETCH NEXT FROM CurAllProc INTO @procname

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('DROP PROCEDURE $(adminschema).' + @procname)

        FETCH NEXT FROM CurAllProc INTO @procname
    END

    CLOSE CurAllProc
    DEALLOCATE CurAllProc
END
GO

--
-- drop tables in schema $(adminschema)
--
BEGIN
    DECLARE @tablename NVARCHAR(100)
    DECLARE @constraintname NVARCHAR(100)

    DECLARE CurAllFK CURSOR FOR
    SELECT table_name, constraint_name FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS WHERE TABLE_CATALOG = '$(database)' AND TABLE_SCHEMA = '$(adminschema)' AND constraint_type IN ('FOREIGN KEY','CHECK')

    OPEN CurAllFK 
    FETCH NEXT FROM CurAllFK INTO @tablename, @constraintname

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('ALTER TABLE $(adminschema).' + @tablename + ' DROP CONSTRAINT ' + @constraintname)

        FETCH NEXT FROM CurAllFK INTO @tablename, @constraintname
    END

    CLOSE CurAllFK
    DEALLOCATE CurAllFK
END
GO

BEGIN
    DECLARE @procname NVARCHAR(100)

    DECLARE CurAllProc CURSOR FOR
    SELECT specific_name FROM INFORMATION_SCHEMA.ROUTINES WHERE routine_catalog='$(database)' AND routine_schema='$(adminschema)' AND routine_type = 'FUNCTION'

    OPEN CurAllProc 
    FETCH NEXT FROM CurAllProc INTO @procname

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('DROP FUNCTION $(adminschema).' + @procname)

        FETCH NEXT FROM CurAllProc INTO @procname
    END

    CLOSE CurAllProc
    DEALLOCATE CurAllProc
END
GO

BEGIN
    DECLARE @tablename NVARCHAR(100)

    DECLARE CurAllTables CURSOR FOR
    SELECT TABLE_NAME from INFORMATION_SCHEMA.TABLES WHERE TABLE_CATALOG='$(database)' AND TABLE_SCHEMA='$(adminschema)' AND TABLE_TYPE = 'VIEW'

    OPEN CurAllTables 
    FETCH NEXT FROM CurAllTables INTO @tablename

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('DROP VIEW $(adminschema).' + @tablename)

        FETCH NEXT FROM CurAllTables INTO @tablename
    END

    CLOSE CurAllTables
    DEALLOCATE CurAllTables
END
GO


BEGIN
    DECLARE @tablename NVARCHAR(100)

    DECLARE CurAllTables CURSOR FOR
    SELECT TABLE_NAME from INFORMATION_SCHEMA.TABLES WHERE TABLE_CATALOG='$(database)' AND TABLE_SCHEMA='$(adminschema)' AND TABLE_TYPE <> 'VIEW'

    OPEN CurAllTables 
    FETCH NEXT FROM CurAllTables INTO @tablename

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('DROP TABLE $(adminschema).' + @tablename)

        FETCH NEXT FROM CurAllTables INTO @tablename
    END

    CLOSE CurAllTables
    DEALLOCATE CurAllTables
END
GO

IF 1 = (SELECT COUNT(*) FROM INFORMATION_SCHEMA.SCHEMATA WHERE catalog_name = N'$(database)' and UPPER(schema_name) = UPPER(N'$(adminschema)'))
    DROP SCHEMA [$(adminschema)]
GO

IF 1 = (SELECT COUNT(*) FROM sys.sysusers WHERE name = N'$(username)')
    DROP USER [$(username)]
GO

GO
USE [master]
GO
DROP LOGIN [$(username)]
GO
