USE [$(database)]
GO

CREATE PROCEDURE $(adminschema).new_schema_${SCHEMA-NAME}
AS
    DECLARE @dbid NUMERIC(10)
    DECLARE @db_schema NVARCHAR(100)
    DECLARE @db_schema_arch NVARCHAR(100)
    DECLARE @db_schema_arch_head NVARCHAR(100)
    DECLARE @table_prefix NVARCHAR(100)
    DECLARE @sddl NVARCHAR(max)

    SELECT @dbid=MAX(lastdbid) + 1 FROM $(adminschema).lastdbid;
    UPDATE $(adminschema).lastdbid SET lastdbid = @dbid

    SET @table_prefix = 'DB$' + CONVERT(NVARCHAR(10), @dbid) + '$';
    SET @db_schema = '$(adminschema).' + @table_prefix;
    SET @db_schema_arch = '$(adminschema).' + @table_prefix + 'A$';
    SET @db_schema_arch_head = '$(adminschema).' + @table_prefix + 'H$';

    
    /*
     * system tables
     *
     */

    SET @sddl = 'CREATE TABLE ' + @db_schema + 'arishistory' +
    '( id                  NUMERIC(10) CONSTRAINT ' + @table_prefix + 'arishistory' + '$PK PRIMARY KEY ON $(fgindex)' +
    ', ts                  NUMERIC(20)' +
    ', logtype             NVARCHAR(100) COLLATE Latin1_General_BIN2' +
    ') ON $(fgdata)'
    EXECUTE (@sddl)
    EXECUTE ('GRANT SELECT, UPDATE, INSERT, DELETE ON ' + @db_schema + 'arishistory TO $(username)')

    SET @sddl = 'CREATE TABLE ' + @db_schema + 'arishistoryprops' +
    '( hid                 NUMERIC(10) NOT NULL' +
    ', pkey                NVARCHAR(100) COLLATE Latin1_General_BIN2 NOT NULL' +
    ', pvalue              NVARCHAR(100) COLLATE Latin1_General_BIN2' +
    ') ON $(fgdata)'
    EXECUTE (@sddl)
    EXECUTE ('GRANT SELECT, UPDATE, INSERT, DELETE ON ' + @db_schema + 'arishistoryprops TO $(username)')
    EXECUTE ('CREATE UNIQUE INDEX arishistorypropsuni ON ' + @db_schema + 'arishistoryprops (hid,pkey) ON $(fgindex)')
    EXECUTE ('ALTER TABLE ' + @db_schema + 'arishistoryprops ADD CONSTRAINT ' + @table_prefix + 'arishistoryprops' + '$FK1 FOREIGN KEY (hid) REFERENCES ' + @db_schema + 'arishistory ON DELETE CASCADE')

    SET @sddl = 'CREATE TABLE ' + @db_schema + 'arisproperties' +
    '( name NVARCHAR(100) COLLATE Latin1_General_BIN2 CONSTRAINT ' + @table_prefix + 'arisproperties' + '$PK PRIMARY KEY ON $(fgindex)' +
    ', val NVARCHAR(100) COLLATE Latin1_General_BIN2' +
    ') ON $(fgdata)'
    EXECUTE (@sddl)
    EXECUTE ('GRANT SELECT, UPDATE, INSERT, DELETE ON ' + @db_schema + 'arisproperties TO $(username)')
    
    SET @sddl = 'CREATE TABLE ' + @db_schema + 'idlease' +
    '( hval NUMERIC(10) CONSTRAINT ' + @table_prefix + 'idlease' + '$PK PRIMARY KEY ON $(fgindex)' +
    ', lval NUMERIC(10)' +
    ') ON $(fgdata)'
    EXECUTE (@sddl)
    EXECUTE ('INSERT INTO ' + @db_schema + 'idlease(hval, lval) VALUES (4,0)')
    EXECUTE ('GRANT SELECT, UPDATE, INSERT, DELETE ON ' + @db_schema + 'idlease TO $(username)')

    SET @sddl = 'CREATE TABLE ' + @db_schema + 'dirty_records' +
    '( id             NCHAR(15) COLLATE Latin1_General_BIN2 CONSTRAINT ' + @table_prefix + 'dirty_records' + '$PK PRIMARY KEY ON $(fgindex)' +
    ', tablename      NVARCHAR(100) COLLATE Latin1_General_BIN2 NOT NULL' +
    ', operation      NCHAR(1) COLLATE Latin1_General_BIN2 NOT NULL' +
    ') ON $(fgdata)'
    EXECUTE (@sddl)
    EXECUTE ('GRANT SELECT, UPDATE, INSERT, DELETE ON ' + @db_schema + 'dirty_records TO $(username)')

    SET @sddl = 'CREATE TABLE ' + @db_schema + 'current_arch_seq' +
    '( id             NCHAR(15) COLLATE Latin1_General_BIN2 CONSTRAINT ' + @table_prefix + 'current_arch_seq' + '$PK PRIMARY KEY ON $(fgindex)' +
    ', visited_state  NCHAR(1) COLLATE Latin1_General_BIN2' +
    ') ON $(fgdata)'
    EXECUTE (@sddl)
    EXECUTE ('GRANT SELECT, UPDATE, INSERT, DELETE ON ' + @db_schema + 'current_arch_seq TO $(username)')

    SET @sddl = 'CREATE TABLE ' + @db_schema + 'current_arch_seq_b' +
    '( id             NCHAR(15) COLLATE Latin1_General_BIN2 CONSTRAINT ' + @table_prefix + 'current_arch_seq_b' + '$PK PRIMARY KEY ON $(fgindex)' +
    ', visited_state  NCHAR(1) COLLATE Latin1_General_BIN2' +
    ') ON $(fgdata)'
    EXECUTE (@sddl)
    EXECUTE ('GRANT SELECT, UPDATE, INSERT, DELETE ON ' + @db_schema + 'current_arch_seq_b TO $(username)')

    SET @sddl = 'CREATE TABLE ' + @db_schema + 'archiving_sequences' +
    '( asn            INTEGER CONSTRAINT ' + @table_prefix + 'archiving_sequences' + '$PK PRIMARY KEY ON $(fgindex)' +
    ', guid           NCHAR(36) COLLATE Latin1_General_BIN2 NOT NULL' +
    ', timestamp      NUMERIC(20) NOT NULL' +
    ', userinfo       NVARCHAR(100) COLLATE Latin1_General_BIN2 NOT NULL' +
    ', description    NVARCHAR(2000) COLLATE Latin1_General_BIN2 NOT NULL' +
    ') ON $(fgdata)'
    EXECUTE (@sddl)
    EXECUTE ('GRANT SELECT, UPDATE, INSERT, DELETE ON ' + @db_schema + 'archiving_sequences TO $(username)')

${NEW-SCHEMA-BODY}

    INSERT INTO $(adminschema).db_stock(dbid, vschemaname) VALUES (@dbid,'${SCHEMA-NAME}')

GO

GRANT EXECUTE ON $(adminschema).new_schema_${SCHEMA-NAME} TO [$(username)]
GO

CREATE PROCEDURE $(adminschema).enable_constraints_${SCHEMA-NAME}(@dbid NUMERIC(10))
AS
    DECLARE @db_schema NVARCHAR(100)
    DECLARE @db_schema_arch NVARCHAR(100)
    DECLARE @table_prefix NVARCHAR(100)
    DECLARE @db_type CHAR(1);
    DECLARE @sddl NVARCHAR(max)

    SELECT @db_type=dbtype FROM $(adminschema).dblist WHERE dbid = @dbid;

    SET @table_prefix = 'DB$' + CONVERT(NVARCHAR(10), @dbid) + '$';
    SET @db_schema = '$(adminschema).' + @table_prefix;
    SET @db_schema_arch = '$(adminschema).' + @table_prefix + 'A$';

${ENABLE-CONSTRAINTS-BODY}

GO

CREATE PROCEDURE $(adminschema).disable_constraints_${SCHEMA-NAME}(@dbid NUMERIC(10))
AS
    DECLARE @db_schema NVARCHAR(100)
    DECLARE @db_schema_arch NVARCHAR(100)
    DECLARE @table_prefix NVARCHAR(100)
    DECLARE @db_type CHAR(1);
    DECLARE @sddl NVARCHAR(max)

    SELECT @db_type=dbtype FROM $(adminschema).dblist WHERE dbid = @dbid;

    SET @table_prefix = 'DB$' + CONVERT(NVARCHAR(10), @dbid) + '$';
    SET @db_schema = '$(adminschema).' + @table_prefix;
    SET @db_schema_arch = '$(adminschema).' + @table_prefix + 'A$';

${DISABLE-CONSTRAINTS-BODY}

GO
