USE [master]
GO

CREATE LOGIN $(username) WITH PASSWORD=N'$(password)', DEFAULT_DATABASE=[$(database)]
GO

USE [$(database)]
GO

CREATE USER [$(username)] FOR LOGIN [$(username)]
GO

CREATE SCHEMA [$(adminschema)]
GO

CREATE TABLE $(adminschema).lastdbid (
    lastdbid        NUMERIC(10)   NOT NULL CONSTRAINT lastdbidPK PRIMARY KEY ON $(fgindex)
) ON $(fgdata)
GO
INSERT INTO $(adminschema).lastdbid(lastdbid) VALUES(0)
GO

CREATE TABLE $(adminschema).dblist (
    dbid        NUMERIC(10)   NOT NULL CONSTRAINT dblistPK PRIMARY KEY ON $(fgindex)
  , dbname      NVARCHAR(300) COLLATE Latin1_General_BIN2 NOT NULL
  , vschemaname NVARCHAR(10)  COLLATE Latin1_General_BIN2 NOT NULL
  , dbtype      CHAR(1) NOT NULL
) ON $(fgdata)
GO
CREATE UNIQUE INDEX dblist_uni ON $(adminschema).dblist (dbname, vschemaname) ON $(fgindex)
GO
GRANT DELETE, INSERT, SELECT, UPDATE ON $(adminschema).dblist TO [$(username)]
GO

CREATE TABLE $(adminschema).db_stock (
   dbid        NUMERIC(10)    NOT NULL CONSTRAINT dbstockPK PRIMARY KEY ON $(fgindex)
 , vschemaname NVARCHAR(10)   COLLATE Latin1_General_BIN2 NOT NULL
) ON $(fgdata)
GO
GRANT DELETE, SELECT ON $(adminschema).db_stock TO [$(username)]
GO

CREATE TABLE $(adminschema).db_trash (
  dbid         NUMERIC(10)    NOT NULL CONSTRAINT dbtrashPK PRIMARY KEY ON $(fgindex)
) ON $(fgdata)
GO
GRANT INSERT ON $(adminschema).db_trash TO [$(username)]
GO

CREATE TABLE $(adminschema).lockservice (
  dummy        NUMERIC(10)    NOT NULL CONSTRAINT lockservicePK PRIMARY KEY ON $(fgindex)
) ON $(fgdata)
GO
GRANT SELECT ON $(adminschema).lockservice TO [$(username)]
GO

CREATE PROCEDURE $(adminschema).drop_schema_procedures(@delschema NVARCHAR(100))
AS
    DECLARE @routinename NVARCHAR(100)

    DECLARE CurAllRoutines CURSOR FOR
    SELECT routine_name FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_CATALOG = '$(database)' AND ROUTINE_SCHEMA = '$(adminschema)' AND ROUTINE_TYPE <> 'FUNCTION' AND routine_name LIKE @delschema + '%' 

    OPEN CurAllRoutines 
    FETCH NEXT FROM CurAllRoutines INTO @routinename

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('DROP PROCEDURE $(adminschema).' + @routinename)

        FETCH NEXT FROM CurAllRoutines INTO @routinename
    END

    CLOSE CurAllRoutines
    DEALLOCATE CurAllRoutines
GO

CREATE PROCEDURE $(adminschema).drop_schema_constraints(@delschema NVARCHAR(100))
AS
    DECLARE @tablename NVARCHAR(100)
    DECLARE @constraintname NVARCHAR(100)

    DECLARE CurAllFK CURSOR FOR
    SELECT table_name, constraint_name FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS WHERE TABLE_CATALOG = '$(database)' AND TABLE_SCHEMA = '$(adminschema)' AND constraint_type IN ('FOREIGN KEY','CHECK') AND table_name LIKE @delschema + '%'

    OPEN CurAllFK 
    FETCH NEXT FROM CurAllFK INTO @tablename, @constraintname

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('ALTER TABLE $(adminschema).' + @tablename + ' DROP CONSTRAINT ' + @constraintname)

        FETCH NEXT FROM CurAllFK INTO @tablename, @constraintname
    END

    CLOSE CurAllFK
    DEALLOCATE CurAllFK
GO

CREATE PROCEDURE $(adminschema).drop_schema_functions(@delschema NVARCHAR(100))
AS
    DECLARE @routinename NVARCHAR(100)

    DECLARE CurAllRoutines CURSOR FOR
    SELECT routine_name FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_CATALOG = '$(database)' AND ROUTINE_SCHEMA = '$(adminschema)' AND ROUTINE_TYPE = 'FUNCTION' AND routine_name LIKE @delschema + '%' 

    OPEN CurAllRoutines 
    FETCH NEXT FROM CurAllRoutines INTO @routinename

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('DROP FUNCTION $(adminschema).' + @routinename)

        FETCH NEXT FROM CurAllRoutines INTO @routinename
    END

    CLOSE CurAllRoutines
    DEALLOCATE CurAllRoutines
GO

CREATE PROCEDURE $(adminschema).drop_schema_views(@delschema NVARCHAR(100))
AS
    DECLARE @tablename NVARCHAR(100)

    DECLARE CurAllTables CURSOR FOR
    SELECT TABLE_NAME from INFORMATION_SCHEMA.TABLES WHERE TABLE_CATALOG='$(database)' AND TABLE_SCHEMA='$(adminschema)' AND TABLE_TYPE = 'VIEW' AND TABLE_NAME LIKE @delschema + '%'

    OPEN CurAllTables 
    FETCH NEXT FROM CurAllTables INTO @tablename

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('DROP VIEW $(adminschema).' + @tablename)

        FETCH NEXT FROM CurAllTables INTO @tablename
    END

    CLOSE CurAllTables
    DEALLOCATE CurAllTables
GO

CREATE PROCEDURE $(adminschema).drop_schema_tables(@delschema NVARCHAR(100))
AS
    DECLARE @tablename NVARCHAR(100)

    DECLARE CurAllTables CURSOR FOR
    SELECT TABLE_NAME from INFORMATION_SCHEMA.TABLES WHERE TABLE_CATALOG='$(database)' AND TABLE_SCHEMA='$(adminschema)' AND TABLE_TYPE <> 'VIEW' AND TABLE_NAME LIKE @delschema + '%'

    OPEN CurAllTables 
    FETCH NEXT FROM CurAllTables INTO @tablename

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXECUTE ('DROP TABLE $(adminschema).' + @tablename)

        FETCH NEXT FROM CurAllTables INTO @tablename
    END

    CLOSE CurAllTables
    DEALLOCATE CurAllTables
GO

CREATE PROCEDURE $(adminschema).drop_schema(@dbid NUMERIC(10))
AS
    DECLARE @delschema NVARCHAR(100)

    SET @delschema = 'DB$' + CONVERT(NVARCHAR(10), @dbid) + '$';

    EXEC $(adminschema).drop_schema_procedures @delschema
    EXEC $(adminschema).drop_schema_constraints @delschema
    EXEC $(adminschema).drop_schema_functions @delschema
    EXEC $(adminschema).drop_schema_views @delschema
    EXEC $(adminschema).drop_schema_tables @delschema

    DELETE FROM $(adminschema).db_stock WHERE dbid = @dbid
GO

CREATE PROCEDURE $(adminschema).empty_trash
AS
    DECLARE @dbid NUMERIC(10)

    DECLARE CurAllDbid CURSOR FOR 
    SELECT dbid from $(adminschema).db_trash

    OPEN CurAllDbid 
    FETCH NEXT FROM CurAllDbid INTO @dbid

    WHILE @@FETCH_STATUS = 0
    BEGIN
        EXEC $(adminschema).drop_schema @dbid

        DELETE FROM $(adminschema).db_trash WHERE dbid = @dbid

        FETCH NEXT FROM CurAllDbid INTO @dbid
    END

    CLOSE CurAllDbid
    DEALLOCATE CurAllDbid
GO

CREATE PROCEDURE $(adminschema).new_db(@vschemaname NVARCHAR(10))
AS
    EXECUTE ('$(adminschema).new_schema_' + @vschemaname)
GO
GRANT EXECUTE ON $(adminschema).new_db TO [$(username)]
GO

CREATE PROCEDURE $(adminschema).enable_constraints(@dbid NUMERIC(10))
AS
    DECLARE @vschemaname NVARCHAR(10)

    SELECT @vschemaname=vschemaname FROM $(adminschema).dblist WHERE dbid = @dbid

    EXECUTE ('$(adminschema).enable_constraints_' + @vschemaname + ' ' + @dbid)
GO
GRANT EXECUTE ON $(adminschema).enable_constraints TO [$(username)]
GO

CREATE PROCEDURE $(adminschema).disable_constraints(@dbid NUMERIC(10))
AS
    DECLARE @vschemaname NVARCHAR(10)

    SELECT @vschemaname=vschemaname FROM $(adminschema).dblist WHERE dbid = @dbid

    EXECUTE ('$(adminschema).disable_constraints_' + @vschemaname + ' ' + @dbid)
GO
GRANT EXECUTE ON $(adminschema).disable_constraints TO [$(username)]
GO

GRANT CREATE TABLE TO [$(username)]
GO
GRANT CREATE VIEW TO [$(username)]
GO
GRANT CREATE FUNCTION TO [$(username)]
GO
GRANT CONTROL ON SCHEMA::$(adminschema) TO [$(username)]
GO

USE [master]
GO
