set verify off

--
-- create schema dladm_schema
--
DECLARE
    dladm_schema VARCHAR2(100) := '&1';
    dlapp_user VARCHAR2(100) := '&2';
    dladm_default_ts   VARCHAR2(100) := '&3';
    dladm_index_ts   VARCHAR2(100) := '&4';
    dladm_lob_ts   VARCHAR2(100) := '&5';
    dladm_temp_ts   VARCHAR2(100) := '&6';
BEGIN
    /* dladm_schema ist not supposed to have CREATE SESSION privilege. It serves as pure schema, no connections */
    EXECUTE IMMEDIATE 'CREATE USER ' || dladm_schema || ' IDENTIFIED BY VALUES ''Y''' ||
        ' DEFAULT TABLESPACE ' || dladm_default_ts ||
        ' TEMPORARY TABLESPACE ' || dladm_temp_ts ||
        ' QUOTA UNLIMITED ON ' || dladm_default_ts ||
        ' QUOTA UNLIMITED ON ' || dladm_lob_ts ||
        ' QUOTA UNLIMITED ON ' || dladm_index_ts;

    /* This table is used to prevent two ARIS Site Managers to use the same Oracle dladm_schema schema */
    EXECUTE IMMEDIATE 'CREATE TABLE ' || dladm_schema || '.lockservice (dummy VARCHAR2(10))';
    EXECUTE IMMEDIATE 'GRANT SELECT ON ' || dladm_schema || '.lockservice TO ' || dlapp_user;

    EXECUTE IMMEDIATE 'CREATE TABLE ' || dladm_schema || '.props ('
      || '  name        VARCHAR2(100) CONSTRAINT props$pk PRIMARY KEY USING INDEX TABLESPACE ' || dladm_index_ts
      || ', value       VARCHAR2(100)'
      || ')';
    EXECUTE IMMEDIATE 'GRANT SELECT ON ' || dladm_schema || '.props TO ' || dlapp_user;

    /* This table maintains the set of all ARIS databases that are currently visible to the ARIS Business server*/
    /* dlapp_user insertes/deletes a row in/from this table when an ARIS database is going to be created/deleted */
    EXECUTE IMMEDIATE 'CREATE TABLE ' || dladm_schema || '.dblist ('
      || '  dbid        number(10) CONSTRAINT dblist$pk PRIMARY KEY USING INDEX TABLESPACE ' || dladm_index_ts
      || ', dbname      VARCHAR2(300)'
      || ', vschemaname VARCHAR2(10)'
      || ', dbtype      CHAR(1)'
      || ', catalog_version  number(10)'
      || ', statistics  number(10)'
      || ')';
    EXECUTE IMMEDIATE 'CREATE UNIQUE INDEX ' || dladm_schema || '.dblist$uni ON ' || dladm_schema || '.dblist (dbname, vschemaname) TABLESPACE ' || dladm_index_ts;
    EXECUTE IMMEDIATE 'GRANT SELECT, INSERT, UPDATE, DELETE ON ' || dladm_schema || '.dblist TO ' || dlapp_user;

    /* dlapp_user deletes a row from this table when an ARIS database is going to be created */
    /* Inserting rows in this table is the task of the Oracle administrator */
    EXECUTE IMMEDIATE 'CREATE TABLE ' || dladm_schema || '.db_stock ('
      || '  dbid        number(10) CONSTRAINT db_stock$pk PRIMARY KEY USING INDEX TABLESPACE ' || dladm_index_ts
      || ', vschemaname VARCHAR2(10)'
      || ')';
    EXECUTE IMMEDIATE 'GRANT SELECT, DELETE ON ' || dladm_schema || '.db_stock TO ' || dlapp_user;

    /* dlapp_user inserts a row in this table when an ARIS database has been deleted */
    /* Deleting rows from this table is the task of the Oracle administrator */
    EXECUTE IMMEDIATE 'CREATE TABLE ' || dladm_schema || '.db_trash ('
      || '  dbid        number(10) CONSTRAINT db_trash$pk PRIMARY KEY USING INDEX TABLESPACE ' || dladm_index_ts
      || ')';
    EXECUTE IMMEDIATE 'GRANT SELECT, INSERT ON ' || dladm_schema || '.db_trash TO ' || dlapp_user;

    /* This sequence is used to build the DBID sequences */
    EXECUTE IMMEDIATE 'CREATE SEQUENCE ' || dladm_schema || '.dbcounter NOCACHE';
    EXECUTE IMMEDIATE 'GRANT SELECT ON ' || dladm_schema || '.dbcounter TO ' || dlapp_user;

    /* This function is used to create function-based indexes */
    EXECUTE IMMEDIATE 'CREATE FUNCTION ' || dladm_schema || '.STRTNF(s VARCHAR2) RETURN VARCHAR2 DETERMINISTIC IS '
      || ' BEGIN '
      || '   RETURN UPPER(TRANSLATE(s, ''A- '' ||CHR(9)||CHR(10)||CHR(11)||CHR(12)||CHR(13)||CHR(14)||CHR(15) , ''A'')); '
      || ' END;';
    EXECUTE IMMEDIATE 'GRANT EXECUTE ON ' || dladm_schema || '.STRTNF TO ' || dlapp_user;

    EXECUTE IMMEDIATE 'GRANT CREATE TABLE TO ' || dladm_schema;
    EXECUTE IMMEDIATE 'GRANT CREATE VIEW TO ' || dladm_schema;
    EXECUTE IMMEDIATE 'GRANT CREATE TRIGGER TO ' || dladm_schema;
    
    EXECUTE IMMEDIATE 'INSERT INTO ' || dladm_schema || '.props(name,value) VALUES (''data_tablespace'',''' || UPPER(dladm_default_ts) || ''')';
    EXECUTE IMMEDIATE 'INSERT INTO ' || dladm_schema || '.props(name,value) VALUES (''index_tablespace'',''' || UPPER(dladm_index_ts) || ''')';
    EXECUTE IMMEDIATE 'INSERT INTO ' || dladm_schema || '.props(name,value) VALUES (''lob_tablespace'',''' || UPPER(dladm_lob_ts) || ''')';

    COMMIT WORK;

END;
/

EXIT

