set verify off

CREATE OR REPLACE PROCEDURE &1 .new_db(p_schemaname IN VARCHAR2) AUTHID DEFINER IS
   tablespace_data  VARCHAR2(100);
   tablespace_index  VARCHAR2(100);
   CURSOR datatsc IS SELECT value FROM &1 .props WHERE name = 'data_tablespace';
   CURSOR indextsc IS SELECT value FROM &1 .props WHERE name = 'index_tablespace';
BEGIN
    OPEN datatsc;
    FETCH datatsc INTO tablespace_data;
    CLOSE datatsc;
  
    OPEN indextsc;
    FETCH indextsc INTO tablespace_index;
    CLOSE indextsc;
   
${BASEMGR-TEXT-MODULE-NEWDB-PROC-IF}
    ELSE
        raise_application_error(-20101, 'unknown schema type ' || p_schemaname);
    END IF;
END new_db;
/

GRANT EXECUTE ON &1 .new_db TO &2 ;

/*
 * The stored procedure fill_db_stock ensures that there are p_maxcount schemata of
 * schema type p_schemaname left within the dbstock table.
 * At the moment we support these schema types: 
${BASEMGR-TEXT-MODULE-FILLDBSTOCK-PROC-COMMENT} 
 *
 * If you want that there are "ALWAYS" p_maxcount schemata of schema type p_schemaname left within 
 * the db_stock table, you may consider to run this procedure within a DBMS_JOB job. See below.
 */
CREATE OR REPLACE PROCEDURE &1 .fill_db_stock(p_schemaname IN VARCHAR2, p_maxcount IN NUMBER) AUTHID DEFINER IS
   numSchemaInDbSTock NUMBER(10);
   CURSOR numc IS SELECT count(*) FROM &1 .db_stock WHERE vschemaname = p_schemaname;
BEGIN
    OPEN numc;
    FETCH numc INTO numSchemaInDbSTock;
    CLOSE numc;

    WHILE numSchemaInDbSTock < p_maxcount
    LOOP

      &1 .new_db(p_schemaname);
     
      OPEN numc;
      FETCH numc INTO numSchemaInDbSTock;
      CLOSE numc;

    END LOOP;
END fill_db_stock;
/

CREATE OR REPLACE PROCEDURE &1 .enable_constraints(p_dbid IN NUMBER) AUTHID DEFINER IS
   schemaname  VARCHAR2(100);

   CURSOR schemanamec IS SELECT vschemaname FROM &1 .dblist WHERE dbid = p_dbid;
BEGIN
    OPEN schemanamec;
    FETCH schemanamec INTO schemaname;
    CLOSE schemanamec;
  
${BASEMGR-TEXT-MODULE-ENABLECONSTRAINTS-PROC-IF}
    ELSE
        raise_application_error(-20101, 'unknown schema type ' || schemaname);
    END IF;
     
END enable_constraints;
/

GRANT EXECUTE ON &1 .enable_constraints TO &2 ;

CREATE OR REPLACE PROCEDURE &1 .disable_constraints(p_dbid IN NUMBER) AUTHID DEFINER IS
   schemaname  VARCHAR2(100);

   CURSOR schemanamec IS SELECT vschemaname FROM &1 .dblist WHERE dbid = p_dbid;
BEGIN
    OPEN schemanamec;
    FETCH schemanamec INTO schemaname;
    CLOSE schemanamec;
  
${BASEMGR-TEXT-MODULE-DISABLECONSTRAINTS-PROC-IF}
    ELSE
        raise_application_error(-20101, 'unknown schema type ' || schemaname);
    END IF;
     
END disable_constraints;
/

GRANT EXECUTE ON &1 .disable_constraints TO &2 ;

CREATE OR REPLACE PROCEDURE &1 .drop_db(p_dbid IN NUMBER) AUTHID DEFINER IS
    CURSOR cc IS SELECT table_name, constraint_name FROM all_constraints WHERE owner = '&1' and table_name like 'DB$' || TO_CHAR(p_dbid) || '$%' and constraint_type = 'R';
    CURSOR uc IS SELECT table_name from all_tables where owner = '&1' and table_name like 'DB$' || TO_CHAR(p_dbid) || '$%';
    CURSOR vc IS SELECT view_name from all_views where owner = '&1' and view_name like 'DB$' || TO_CHAR(p_dbid) || '$%';
BEGIN
    FOR vr IN vc
    LOOP
        EXECUTE IMMEDIATE 'DROP VIEW ' || vr.view_name;
    END LOOP; 

    FOR cr IN cc
    LOOP
        EXECUTE IMMEDIATE 'ALTER TABLE ' || cr.table_name || ' DROP CONSTRAINT ' || cr.constraint_name;
    END LOOP; 

    FOR ur IN uc
    LOOP
        EXECUTE IMMEDIATE 'DROP TABLE ' || ur.table_name;
    END LOOP; 

    DELETE FROM &1 .db_trash WHERE dbid = p_dbid;
    COMMIT;   
END drop_db;
/

GRANT EXECUTE ON &1 .drop_db TO &2 ;

CREATE OR REPLACE PROCEDURE &1 .empty_db_trash AUTHID DEFINER IS
    CURSOR dbc IS SELECT dbid from &1 .db_trash;
BEGIN
    FOR dbr IN dbc
    LOOP
        &1 .drop_db(dbr.dbid);
    END LOOP; 
END empty_db_trash;
/

CREATE OR REPLACE PROCEDURE &1 .refresh_db_stats AUTHID DEFINER IS
  CURSOR dbc IS SELECT dbid from &1 .dblist where statistics > 0;
BEGIN
  FOR dbr IN dbc
  LOOP
    &1 .gather_db_stats(dbr.dbid);
  END LOOP; 
END refresh_db_stats;
/

--
-- update tablespace specs
--
DECLARE
    dladm_schema VARCHAR2(100) := '&1';
    dladm_default_ts   VARCHAR2(100) := '&3';
    dladm_index_ts   VARCHAR2(100) := '&4';
    dladm_lob_ts   VARCHAR2(100) := '&5';
    dladm_temp_ts   VARCHAR2(100) := '&6';
    
    cnt pls_integer;
BEGIN
    SELECT COUNT(*) INTO cnt FROM &1 .props WHERE name = 'lob_tablespace';

    IF cnt = 0 THEN
        EXECUTE IMMEDIATE 'INSERT INTO ' || dladm_schema || '.props(name,value) VALUES (''lob_tablespace'',''' || UPPER(dladm_lob_ts) || ''')';
    ELSE
        EXECUTE IMMEDIATE 'UPDATE ' || dladm_schema || '.props SET value = ''' || UPPER(dladm_lob_ts) || ''' WHERE name = ''lob_tablespace''';   
    END IF;

    EXECUTE IMMEDIATE 'UPDATE ' || dladm_schema || '.props SET value = ''' || UPPER(dladm_default_ts) || ''' WHERE name = ''data_tablespace''';   
    EXECUTE IMMEDIATE 'UPDATE ' || dladm_schema || '.props SET value = ''' || UPPER(dladm_index_ts) || ''' WHERE name = ''index_tablespace''';   
    
    COMMIT WORK;

END;
/

--
-- insert DL catalog version
--
DECLARE
    dladm_schema VARCHAR2(100) := '&1';
    cnt pls_integer;
BEGIN
    SELECT COUNT(*) INTO cnt FROM &1 .props WHERE name = 'catalog_version';

    IF cnt = 0 THEN
        EXECUTE IMMEDIATE 'INSERT INTO ' || dladm_schema || '.props(name,value) VALUES (''catalog_version'',''${BASEMGR-TEXT-MODULE-CATALOG-VERSION}'')';
    ELSE
        EXECUTE IMMEDIATE 'UPDATE ' || dladm_schema || '.props SET value = ''${BASEMGR-TEXT-MODULE-CATALOG-VERSION}'' WHERE name = ''catalog_version''';   
    END IF;
    
    COMMIT WORK;

END;
/

EXIT
