set verify off

CREATE OR REPLACE PACKAGE &1 .schema_${SCHEMA-NAME} AUTHID DEFINER
IS
  /* creates a new application database */
  PROCEDURE new_schema;

  /* creates indexes and constraints */
  PROCEDURE enable_constraints (p_dbid IN NUMBER);

  /* drops indexes and constraints */
  PROCEDURE disable_constraints (p_dbid IN NUMBER);

END schema_${SCHEMA-NAME};
/
SHOW ERRORS

CREATE OR REPLACE PACKAGE BODY &1 .schema_${SCHEMA-NAME}
IS
  PROCEDURE new_schema IS
    db_schema           VARCHAR2(100);
    db_schema_arch      VARCHAR2(100);
    db_schema_arch_head VARCHAR2(100);
    table_prefix        VARCHAR2(100);
    sddl                VARCHAR2(1000);
    dladm_schema        VARCHAR2(100) := '&1';
    dlapp_user          VARCHAR2(100) := '&2';
    dattblspace         VARCHAR2(100);
    idxtblspace         VARCHAR2(100);
    lobtblspace         VARCHAR2(100);
    dbid NUMBER;

    CURSOR datatsc IS SELECT value FROM &1 .props WHERE name = 'data_tablespace';
    CURSOR indextsc IS SELECT value FROM &1 .props WHERE name = 'index_tablespace';
    CURSOR lobtsc IS SELECT value FROM &1 .props WHERE name = 'lob_tablespace' OR (name = 'data_tablespace' AND NOT EXISTS(SELECT 1 FROM &1 .props WHERE name = 'lob_tablespace'));
    CURSOR dbidc IS SELECT &1 .dbcounter.nextval FROM dual;
  BEGIN
    OPEN datatsc;
    FETCH datatsc INTO dattblspace;
    CLOSE datatsc;
  
    OPEN indextsc;
    FETCH indextsc INTO idxtblspace;
    CLOSE indextsc;

    OPEN lobtsc;
    FETCH lobtsc INTO lobtblspace;
    CLOSE lobtsc;
    
    OPEN dbidc;
    FETCH dbidc INTO dbid;
    CLOSE dbidc;

    table_prefix := 'DB$' || TO_CHAR(dbid) || '$';
    db_schema := dladm_schema || '.' || table_prefix;
    db_schema_arch := dladm_schema || '.' || table_prefix || 'A$';
    db_schema_arch_head := dladm_schema || '.' || table_prefix || 'H$';

    /*
     * system tables
     *
     */

    sddl := 'CREATE TABLE ' || db_schema || 'arishistory' ||
    '( id                  NUMBER(10) CONSTRAINT ' || table_prefix || 'arishistoryPK PRIMARY KEY USING INDEX TABLESPACE ' || idxtblspace ||
    ', ts                  NUMBER(20)' ||
    ', logtype             VARCHAR2(100)' ||
    ') TABLESPACE ' || dattblspace;
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'arishistory TO ' || dlapp_user;

    sddl := 'CREATE TABLE ' || db_schema || 'arishistoryprops' ||
    '( hid                 NUMBER(10) NOT NULL' ||
    ', pkey                VARCHAR2(100) NOT NULL' ||
    ', pvalue              VARCHAR2(100)' ||
    ') TABLESPACE ' || dattblspace;
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'arishistoryprops TO ' || dlapp_user;
    sddl := 'ALTER TABLE ' || db_schema || 'arishistoryprops ADD CONSTRAINT ' || table_prefix || 'arishprops$FK$1 FOREIGN KEY (hid) references ' || db_schema || 'arishistory ON DELETE CASCADE';
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    sddl := 'CREATE UNIQUE INDEX ' || db_schema || 'arishpropsuni ON ' || db_schema || 'arishistoryprops (hid,pkey) TABLESPACE ' || idxtblspace;
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);

    sddl := 'CREATE TABLE ' || db_schema || 'ArisProperties' ||
    '( name VARCHAR2(100) CONSTRAINT ' || table_prefix || 'arispropPK PRIMARY KEY USING INDEX TABLESPACE ' || idxtblspace ||
    ', val VARCHAR2(100)' ||
    ') TABLESPACE ' || dattblspace;
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'ArisProperties TO ' || dlapp_user;

    sddl := 'CREATE TABLE ' || db_schema || 'idlease' ||
    '( hval                NUMBER(10) CONSTRAINT ' || table_prefix || 'idleasePK PRIMARY KEY USING INDEX TABLESPACE ' || idxtblspace ||
    ', lval                NUMBER(10)' ||
    ') TABLESPACE ' || dattblspace;
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'INSERT INTO ' || db_schema || 'idlease VALUES (4,0)';
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'idlease TO ' || dlapp_user;

    sddl := 'CREATE TABLE ' || db_schema || 'dirty_records' ||
    '( id                  CHAR(15) CONSTRAINT ' || table_prefix || 'drPK PRIMARY KEY USING INDEX TABLESPACE ' || idxtblspace ||
    ', tablename           VARCHAR2(100) NOT NULL' ||
    ', operation           CHAR(1) NOT NULL' ||
    ') TABLESPACE ' || dattblspace;
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'dirty_records TO ' || dlapp_user;

    sddl := 'CREATE GLOBAL TEMPORARY TABLE ' || db_schema || 'current_arch_seq' ||
    '( id                  CHAR(15) CONSTRAINT ' || table_prefix || 'casPK PRIMARY KEY' ||
    ', visited_state       CHAR(1)' ||
    ')';
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'current_arch_seq TO ' || dlapp_user;

    sddl := 'CREATE GLOBAL TEMPORARY TABLE ' || db_schema || 'current_arch_seq_b' ||
    '( id                  CHAR(15) CONSTRAINT ' || table_prefix || 'casbPK PRIMARY KEY' ||
    ', visited_state       CHAR(1)' ||
    ')';
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'current_arch_seq_b TO ' || dlapp_user;

    sddl := 'CREATE TABLE ' || db_schema || 'archiving_sequences' ||
    '( asn                 NUMBER(10) CONSTRAINT ' || table_prefix || 'archseqPK PRIMARY KEY USING INDEX TABLESPACE ' || idxtblspace ||
    ', guid                CHAR(36) NOT NULL' ||
    ', timestamp           NUMBER(20) NOT NULL' ||
    ', userinfo            VARCHAR2(100) NOT NULL' ||
    ', description         VARCHAR2(2000) NOT NULL' ||
    ') TABLESPACE ' || dattblspace;
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'archiving_sequences TO ' || dlapp_user;

    sddl := 'CREATE GLOBAL TEMPORARY TABLE ' || db_schema || 'QPLIDPARAM' ||
    '( ID                  CHAR(15) NOT NULL' ||
    ', ParamNum            NUMBER(5) NOT NULL' ||
    ', SeqNum              NUMBER(10) NOT NULL' ||
    ')';
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'QPLIDPARAM TO ' || dlapp_user;

    sddl := 'CREATE GLOBAL TEMPORARY TABLE ' || db_schema || 'QPLINTPARAM' ||
    '( val                 NUMBER(10) NOT NULL' ||
    ', ParamNum            NUMBER(5) NOT NULL' ||
    ')';
    DBMS_UTILITY.EXEC_DDL_STATEMENT (sddl);
    EXECUTE IMMEDIATE 'GRANT SELECT, UPDATE, INSERT, DELETE ON ' || db_schema || 'QPLINTPARAM TO ' || dlapp_user;
    
${NEW-SCHEMA-BODY}

    COMMIT WORK;
    
    /* compute initial statistics */
    &1 .gather_db_stats(dbid);
    
    /* make new db_schema schema visible to the application through table dblist */
    EXECUTE IMMEDIATE 'INSERT INTO ' || dladm_schema || '.db_stock (dbid, vschemaname) VALUES (' || TO_CHAR(dbid) || ',' || '''${SCHEMA-NAME}'')';

    COMMIT WORK;

  END;

  PROCEDURE enable_constraints(p_dbid IN NUMBER) IS
    db_schema      VARCHAR2(100);
    db_schema_arch VARCHAR2(100);
    table_prefix   VARCHAR2(100);
    sddl           VARCHAR2(1000);
    dladm_schema   VARCHAR2(100) := '&1';
    dlapp_user     VARCHAR2(100) := '&2';
    dattblspace    VARCHAR2(100);
    idxtblspace    VARCHAR2(100);
    db_type        CHAR(1);

    CURSOR datatsc IS SELECT value FROM &1 .props WHERE name = 'data_tablespace';
    CURSOR indextsc IS SELECT value FROM &1 .props WHERE name = 'index_tablespace';
    CURSOR dbtypec IS SELECT dbtype FROM &1 .dblist WHERE dbid = p_dbid;
  BEGIN
    OPEN datatsc;
    FETCH datatsc INTO dattblspace;
    CLOSE datatsc;
  
    OPEN indextsc;
    FETCH indextsc INTO idxtblspace;
    CLOSE indextsc;

    OPEN dbtypec;
    FETCH dbtypec INTO db_type;
    CLOSE dbtypec;

    table_prefix := 'DB$' || TO_CHAR(p_dbid) || '$';
    db_schema := dladm_schema || '.' || table_prefix;
    db_schema_arch := dladm_schema || '.' || table_prefix || 'A$';

${ENABLE-CONSTRAINTS-BODY}

  END;

  PROCEDURE disable_constraints(p_dbid IN NUMBER) IS
    db_schema      VARCHAR2(100);
    db_schema_arch VARCHAR2(100);
    table_prefix   VARCHAR2(100);
    sddl           VARCHAR2(1000);
    dladm_schema   VARCHAR2(100) := '&1';
    dlapp_user     VARCHAR2(100) := '&2';
    dattblspace    VARCHAR2(100);
    idxtblspace    VARCHAR2(100);
    db_type        CHAR(1);

    CURSOR dbtypec IS SELECT dbtype FROM &1 .dblist WHERE dbid = p_dbid;
  BEGIN

    OPEN dbtypec;
    FETCH dbtypec INTO db_type;
    CLOSE dbtypec;

    table_prefix := 'DB$' || TO_CHAR(p_dbid) || '$';
    db_schema := dladm_schema || '.' || table_prefix;
    db_schema_arch := dladm_schema || '.' || table_prefix || 'A$';

${DISABLE-CONSTRAINTS-BODY}

  END;

END schema_${SCHEMA-NAME};
/
SHOW ERRORS

EXIT
