<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0"
    xmlns:lxslt="http://xml.apache.org/xslt"
    xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
    extension-element-prefixes="redirect">

<xsl:param name="output-dir"/>

<xsl:key name="obj-types" match="object-type" use="@NAME"/>

<xsl:template match="metadata">
      <xsl:apply-templates select="object-type[not(object-type-prop[@NAME='ABSTRACT' and (@VALUE='yes' or @VALUE='YES')])]"/>
</xsl:template>

<xsl:template match="object-type">
    <redirect:write select="concat($output-dir, '/', translate(/metadata/@RECORD-IMPL-PACKAGE, '.', '/'), '/A' , ./@NAME, 'Rec.java')">

    <xsl:call-template name="create-header"/>
    <xsl:call-template name="create-class-line"/>
    // fields are public member;
    <xsl:call-template name="create-field-member">
        <xsl:with-param name="pobjecttype" select="."/>
    </xsl:call-template>
    <xsl:call-template name="create-static-field_array"/>

    public int getTableID() {
        return <xsl:value-of select="concat('I', @NAME, 'Rec.TABLE_ID')"/>;
    }

    <xsl:call-template name="create-init-if-new-method"/>
    <xsl:call-template name="create-field-getter-setter">
        <xsl:with-param name="pobjecttype" select="."/>
    </xsl:call-template>
}
  </redirect:write>
</xsl:template>


<xsl:template name="create-header">
/**
 * generated file - do not edit
 */

<xsl:text>package </xsl:text><xsl:value-of select="/metadata/@RECORD-IMPL-PACKAGE"/>;

import java.lang.reflect.Field;
import com.idsscheer.dl.IDLOID;
import com.idsscheer.dl.logic.ARecord;
<xsl:call-template name="create-imports"/>

<xsl:text>import </xsl:text><xsl:value-of select="concat(substring-before(/metadata/@RECORD-IMPL-PACKAGE, '.logic'), '.I', @NAME, 'Rec')"/>;

</xsl:template>

<!-- create class line -->
<xsl:template name="create-class-line">
public class <xsl:value-of select="concat('A', @NAME, 'Rec')"/>
    <xsl:text> extends </xsl:text><xsl:call-template name="base-class"/>
    <xsl:text> implements </xsl:text> <xsl:value-of select="concat('I', @NAME, 'Rec')"/> {
</xsl:template>

<xsl:template name="base-class">ARecord</xsl:template>

<xsl:template name="create-static-field_array">
    private static Field[] g_arrayField = null;

    static {
        try {
            String arrayFieldNames[] = {"ID"
                <xsl:call-template name="list-all-field-names">
                    <xsl:with-param name="pobjecttype" select="."/>
                </xsl:call-template>
            };
            g_arrayField = new Field[arrayFieldNames.length];
            for (int i = 0; i &lt; arrayFieldNames.length; ++i) {
                g_arrayField[i] = <xsl:value-of select="concat('A', @NAME, 'Rec.class.getField')"/>("m_" + arrayFieldNames[i]);
            }
        }
        catch(NoSuchFieldException e) {
            e.printStackTrace();
        }
    }

    protected Field getField(int p_nFieldId) {
        return g_arrayField[p_nFieldId - 1];
    }
</xsl:template>

<xsl:template name="create-field-member">
<xsl:param name="pobjecttype"/>
    <!-- recursive call if there is a base object type-->
    <xsl:for-each select="$pobjecttype/extends-object-type">
        <xsl:call-template name="create-field-member">
            <xsl:with-param name="pobjecttype" select="key('obj-types',$pobjecttype/extends-object-type/@NAME)"/>
        </xsl:call-template>
    </xsl:for-each>
    <!-- add the fields of the CURRENT object type -->
    <xsl:for-each select="$pobjecttype/fields/field">
        <xsl:text>public </xsl:text> 
        <xsl:choose>
           <xsl:when test="@DATATYPE='IOID'">IDLOID</xsl:when>
		   <xsl:otherwise><xsl:value-of select="@DATATYPE"/></xsl:otherwise>
		</xsl:choose>
			
        <xsl:text> </xsl:text> <xsl:value-of select="concat('m_', @NAME)"/>;
    </xsl:for-each>
</xsl:template>

<xsl:template name="list-all-field-names">
<xsl:param name="pobjecttype"/>
    <!-- recursive call if there is a base object type-->
    <xsl:for-each select="$pobjecttype/extends-object-type">
        <xsl:call-template name="list-all-field-names">
            <xsl:with-param name="pobjecttype" select="key('obj-types',$pobjecttype/extends-object-type/@NAME)"/>
        </xsl:call-template>
    </xsl:for-each>
    <!-- add the fields of the CURRENT object type -->
    <xsl:for-each select="$pobjecttype/fields/field">
        <xsl:text>, </xsl:text> <xsl:value-of select="concat('&#x22;', @NAME, '&#x22;')"/>
    </xsl:for-each>
</xsl:template>

<xsl:template name="create-field-getter-setter">
<xsl:param name="pobjecttype"/>
    <!-- recursive call if there is a base object type-->
    <xsl:for-each select="$pobjecttype/extends-object-type">
        <xsl:call-template name="create-field-getter-setter">
            <xsl:with-param name="pobjecttype" select="key('obj-types',$pobjecttype/extends-object-type/@NAME)"/>
        </xsl:call-template>
    </xsl:for-each>
    <!-- add the fields of the CURRENT object type -->
    <xsl:for-each select="$pobjecttype/fields/field">
<xsl:text>
    // field </xsl:text><xsl:value-of select="@NAME" /><xsl:text>
    public </xsl:text>
        <xsl:call-template name="create-datatype-spec">
            <xsl:with-param name="pdatatype" select="@DATATYPE"/>
        </xsl:call-template><xsl:text> </xsl:text>
        <xsl:call-template name="create-method-prefix">
            <xsl:with-param name="pdatatype" select="@DATATYPE"/>
        </xsl:call-template>
        <xsl:value-of select="concat(@NAME, '()')" /><xsl:text> {
        return </xsl:text>
        <xsl:choose>
            <xsl:when test="contains(@DATATYPE,'[]')">
                <xsl:value-of select="concat('(m_', @NAME, ' == null) ? null : ', '(', @DATATYPE, ')', 'm_', @NAME, '.clone()')"/>
            </xsl:when>
		    <xsl:otherwise>
                <xsl:call-template name="create-field-getter-simple-return"/>
            </xsl:otherwise>
		</xsl:choose><xsl:text>;
    }
    public void </xsl:text>
        <xsl:value-of select="concat('set', @NAME, '(')" />
        <xsl:call-template name="create-datatype-spec">
            <xsl:with-param name="pdatatype" select="@DATATYPE"/>
        </xsl:call-template><xsl:text> p) {
        </xsl:text>
        <xsl:value-of select="concat('m_', @NAME, ' = ')"/>
        <xsl:choose>
            <xsl:when test="contains(@DATATYPE,'[]')"><xsl:value-of select="concat('(p == null) ? null : (', @DATATYPE, ')p.clone()')"/></xsl:when>
		    <xsl:otherwise>
                <xsl:call-template name="create-field-setter-simple-assignment"/>
            </xsl:otherwise>
		</xsl:choose><xsl:text>;
        onSetValue();
    }
</xsl:text>
    </xsl:for-each>
</xsl:template>

<xsl:template name="create-field-getter-simple-return">
    <xsl:value-of select="concat('m_', @NAME)"/>
</xsl:template>

<xsl:template name="create-field-setter-simple-assignment">
    <xsl:text>p</xsl:text>
</xsl:template>

<xsl:template name="create-init-if-new-method">
<xsl:text>
    public void initializeIfNew() {
        super.initializeIfNew();
        </xsl:text>
        <xsl:call-template name="lookup-init-if-new-field">
            <xsl:with-param name="pobjecttype" select="."/>
        </xsl:call-template><xsl:text>
    }
</xsl:text>
</xsl:template>

<xsl:template name="lookup-init-if-new-field">
<xsl:param name="pobjecttype"/>
    <!-- recursive call if there is a base object type-->
    <xsl:for-each select="$pobjecttype/extends-object-type">
        <xsl:call-template name="lookup-init-if-new-field">
            <xsl:with-param name="pobjecttype" select="key('obj-types',$pobjecttype/extends-object-type/@NAME)"/>
        </xsl:call-template>
    </xsl:for-each>
    <!-- add the fields of the CURRENT object type -->
    <xsl:for-each select="$pobjecttype/fields/field">
        <xsl:call-template name="create-init-if-new-field"/>
    </xsl:for-each>
</xsl:template>

<xsl:template name="create-init-if-new-field">
</xsl:template>

<xsl:template name="create-datatype-spec">
<xsl:param name="pdatatype"/>
    <xsl:choose>
        <xsl:when test="$pdatatype='IOID'">IDLOID</xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$pdatatype" />
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>


<xsl:template name="create-method-prefix">
<xsl:param name="pdatatype"/>
    <xsl:choose>
        <xsl:when test="$pdatatype='boolean'">is</xsl:when>
        <xsl:otherwise>get</xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="create-imports">
</xsl:template>

</xsl:stylesheet>
